#!/bin/sh
# the next line restarts using wish\
exec wish "$0" "$@" 

if {![info exists vTcl(sourcing)]} {

    switch $tcl_platform(platform) {
	windows {
            option add *Button.padY 0
	}
	default {
	    option add *Scrollbar.width 10
            option add *Scrollbar.highlightThickness 0
            option add *Scrollbar.elementBorderWidth 2
            option add *Scrollbar.borderWidth 2
	}
    }
    
}

#############################################################################
# Visual Tcl v1.60 Project
#

#############################################################################
# vTcl Code to Load Stock Fonts


if {![info exist vTcl(sourcing)]} {
set vTcl(fonts,counter) 0
#############################################################################
## Procedure:  vTcl:font:add_font

proc {vTcl:font:add_font} {font_descr font_type {newkey {}}} {
     global vTcl

     incr vTcl(fonts,counter)
     set newfont [eval font create $font_descr]

     lappend vTcl(fonts,objects) $newfont

     # each font has its unique key so that when a project is
     # reloaded, the key is used to find the font description

     if {$newkey == ""} {
          set newkey vTcl:font$vTcl(fonts,counter)

          # let's find an unused font key
          while {[vTcl:font:get_font $newkey] != ""} {
             incr vTcl(fonts,counter)
             set newkey vTcl:font$vTcl(fonts,counter)
          }
     }

     set vTcl(fonts,$newfont,type)                      $font_type
     set vTcl(fonts,$newfont,key)                       $newkey
     set vTcl(fonts,$vTcl(fonts,$newfont,key),object)   $newfont

     lappend vTcl(fonts,$font_type) $newfont

     # in case caller needs it
     return $newfont
}

#############################################################################
## Procedure:  vTcl:font:get_font

proc {vTcl:font:get_font} {key} {
    global vTcl
    if {[info exists vTcl(fonts,$key,object)]} then {
        return $vTcl(fonts,$key,object)
    } else {
        return ""
    }
}

vTcl:font:add_font \
    "-family helvetica -size 12 -weight normal -slant roman -underline 0 -overstrike 0" \
    stock \
    vTcl:font1
vTcl:font:add_font \
    "-family helvetica -size 12 -weight bold -slant roman -underline 0 -overstrike 0" \
    stock \
    vTcl:font5
}
#################################
# VTCL LIBRARY PROCEDURES
#

if {![info exists vTcl(sourcing)]} {
#############################################################################
## Library Procedure:  Window

proc {Window} {args} {
    global vTcl
    set cmd     [lindex $args 0]
    set name    [lindex $args 1]
    set newname [lindex $args 2]
    set rest    [lrange $args 3 end]
    if {$name == "" || $cmd == ""} { return }
    if {$newname == ""} { set newname $name }
    if {$name == "."} { wm withdraw $name; return }
    set exists [winfo exists $newname]
    switch $cmd {
        show {
            if {$exists} {
                wm deiconify $newname
            } elseif {[info procs vTclWindow$name] != ""} {
                eval "vTclWindow$name $newname $rest"
            }
            if {[winfo exists $newname] && [wm state $newname] == "normal"} {
                vTcl:FireEvent $newname <<Show>>
            }
        }
        hide    {
            if {$exists} {
                wm withdraw $newname
                vTcl:FireEvent $newname <<Hide>>
                return}
        }
        iconify { if $exists {wm iconify $newname; return} }
        destroy { if $exists {destroy $newname; return} }
    }
}
#############################################################################
## Library Procedure:  vTcl:DefineAlias

proc {vTcl:DefineAlias} {target alias widgetProc top_or_alias cmdalias} {
    global widget
    set widget($alias) $target
    set widget(rev,$target) $alias
    if {$cmdalias} {
        interp alias {} $alias {} $widgetProc $target
    }
    if {$top_or_alias != ""} {
        set widget($top_or_alias,$alias) $target
        if {$cmdalias} {
            interp alias {} $top_or_alias.$alias {} $widgetProc $target
        }
    }
}
#############################################################################
## Library Procedure:  vTcl:DoCmdOption

proc {vTcl:DoCmdOption} {target cmd} {

    ## menus are considered toplevel windows
    set parent $target
    while {[winfo class $parent] == "Menu"} {
        set parent [winfo parent $parent]
    }

    regsub -all {\%widget} $cmd $target cmd
    regsub -all {\%top} $cmd [winfo toplevel $parent] cmd

    uplevel #0 [list eval $cmd]
}
#############################################################################
## Library Procedure:  vTcl:FireEvent

proc {vTcl:FireEvent} {target event {params {}}} {
    ## The window may have disappeared
    if {![winfo exists $target]} return
    ## Process each binding tag, looking for the event
    foreach bindtag [bindtags $target] {
        set tag_events [bind $bindtag]
        set stop_processing 0
        foreach tag_event $tag_events {
            if {$tag_event == $event} {
                set bind_code [bind $bindtag $tag_event]
                foreach rep "\{%W $target\} $params" {
                    regsub -all [lindex $rep 0] $bind_code [lindex $rep 1] bind_code
                }
                set result [catch {uplevel #0 $bind_code} errortext]
                if {$result == 3} {
                    ## break exception, stop processing
                    set stop_processing 1
                } elseif {$result != 0} {
                    bgerror $errortext
                }
                break
            }
        }
        if {$stop_processing} {break}
    }
}
#############################################################################
## Library Procedure:  vTcl:Toplevel:WidgetProc

proc {vTcl:Toplevel:WidgetProc} {w args} {
    if {[llength $args] == 0} {
        ## If no arguments, returns the path the alias points to
        return $w
    }
    ## The first argument is a switch, they must be doing a configure.
    if {[string index $args 0] == "-"} {
        set command configure
        ## There's only one argument, must be a cget.
        if {[llength $args] == 1} {
            set command cget
        }
    } else {
        set command [lindex $args 0]
        set args [lrange $args 1 end]
    }
    switch -- $command {
        "hide" - "Hide" - "show" - "Show" {
            Window [string tolower $command] $w
        }
        "ShowModal" {
            Window show $w
            raise $w
            grab $w
            tkwait window $w
            grab release $w
        }
        default {
            uplevel $w $command $args
        }
    }
}
#############################################################################
## Library Procedure:  vTcl:WidgetProc

proc {vTcl:WidgetProc} {w args} {
    if {[llength $args] == 0} {
        ## If no arguments, returns the path the alias points to
        return $w
    }
    ## The first argument is a switch, they must be doing a configure.
    if {[string index $args 0] == "-"} {
        set command configure
        ## There's only one argument, must be a cget.
        if {[llength $args] == 1} {
            set command cget
        }
    } else {
        set command [lindex $args 0]
        set args [lrange $args 1 end]
    }
    uplevel $w $command $args
}
#############################################################################
## Library Procedure:  vTcl:toplevel

proc {vTcl:toplevel} {args} {
    uplevel #0 eval toplevel $args
    set target [lindex $args 0]
    namespace eval ::$target {}
}
}


if {[info exists vTcl(sourcing)]} {

proc vTcl:project:info {} {
    namespace eval ::widgets::.top43 {
        array set save {-background 1 -highlightthickness 1}
        set set,origin 1
        set set,size 1
    }
    namespace eval ::widgets::.top43.fra44 {
        array set save {-background 1 -borderwidth 1 -height 1 -highlightcolor 1 -highlightthickness 1 -relief 1 -width 1}
    }
    namespace eval ::widgets::.top43.fra44.men45 {
        array set save {-activeforeground 1 -background 1 -disabledforeground 1 -font 1 -foreground 1 -highlightthickness 1 -menu 1 -padx 1 -pady 1 -relief 1 -text 1 -textvariable 1}
    }
    namespace eval ::widgets::.top43.fra44.men45.m {
        array set save {-disabledforeground 1 -tearoff 1}
    }
    namespace eval ::widgets::.top43.fra44.but46 {
        array set save {-background 1 -command 1 -disabledforeground 1 -font 1 -foreground 1 -highlightcolor 1 -highlightthickness 1 -text 1 -textvariable 1}
    }
    namespace eval ::widgets::.top43.fra44.cpd47 {
        array set save {-background 1 -borderwidth 1 -height 1 -highlightthickness 1 -relief 1 -width 1}
    }
    namespace eval ::widgets::.top43.fra44.cpd47.01 {
        array set save {-activebackground 1 -activeforeground 1 -anchor 1 -background 1 -disabledforeground 1 -font 1 -foreground 1 -highlightthickness 1 -relief 1 -text 1 -textvariable 1}
    }
    namespace eval ::widgets::.top43.fra44.cpd47.02 {
        array set save {-background 1 -cursor 1 -highlightthickness 1 -insertbackground 1 -textvariable 1}
    }
    namespace eval ::widgets::.top43.fra48 {
        array set save {-background 1 -borderwidth 1 -height 1 -highlightthickness 1 -relief 1 -width 1}
    }
    namespace eval ::widgets::.top43.fra48.can49 {
        array set save {-background 1 -borderwidth 1 -closeenough 1 -height 1 -highlightthickness 1 -insertbackground 1 -relief 1 -selectbackground 1 -selectforeground 1 -width 1}
    }
    namespace eval ::widgets::.top43.fra48.sca50 {
        array set save {-background 1 -bigincrement 1 -command 1 -from 1 -highlightthickness 1 -relief 1 -resolution 1 -showvalue 1 -tickinterval 1 -to 1 -troughcolor 1 -variable 1}
    }
    namespace eval ::widgets::.top43.fra48.sca51 {
        array set save {-background 1 -bigincrement 1 -command 1 -from 1 -highlightthickness 1 -orient 1 -relief 1 -resolution 1 -showvalue 1 -tickinterval 1 -to 1 -troughcolor 1 -variable 1}
    }
    namespace eval ::widgets::.top43.fra52 {
        array set save {-background 1 -borderwidth 1 -height 1 -highlightthickness 1 -relief 1 -width 1}
    }
    namespace eval ::widgets::.top43.fra52.lab53 {
        array set save {-activebackground 1 -background 1 -borderwidth 1 -disabledforeground 1 -font 1 -highlightthickness 1 -text 1 -textvariable 1}
    }
    namespace eval ::widgets::.top43.fra54 {
        array set save {-background 1 -borderwidth 1 -height 1 -highlightthickness 1 -relief 1 -width 1}
    }
    namespace eval ::widgets::.top43.fra54.men57 {
        array set save {-activeforeground 1 -background 1 -disabledforeground 1 -font 1 -foreground 1 -highlightthickness 1 -menu 1 -padx 1 -pady 1 -relief 1 -text 1 -textvariable 1}
    }
    namespace eval ::widgets::.top43.fra54.men57.m {
        array set save {-disabledforeground 1 -tearoff 1}
    }
    namespace eval ::widgets::.top43.fra54.men58 {
        array set save {-activeforeground 1 -background 1 -disabledforeground 1 -font 1 -foreground 1 -highlightthickness 1 -menu 1 -padx 1 -pady 1 -relief 1 -text 1 -textvariable 1}
    }
    namespace eval ::widgets::.top43.fra54.men58.m {
        array set save {-disabledforeground 1 -tearoff 1}
    }
    namespace eval ::widgets::.top43.fra54.but59 {
        array set save {-activeforeground 1 -background 1 -command 1 -disabledforeground 1 -font 1 -foreground 1 -height 1 -highlightthickness 1 -text 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::.top43.fra54.fra43 {
        array set save {-background 1 -borderwidth 1 -height 1 -highlightthickness 1 -relief 1 -width 1}
    }
    namespace eval ::widgets::.top43.fra54.fra43.cpd46 {
        array set save {-background 1 -borderwidth 1 -height 1 -highlightthickness 1 -relief 1 -width 1}
    }
    namespace eval ::widgets::.top43.fra54.fra43.cpd46.01 {
        array set save {-anchor 1 -background 1 -disabledforeground 1 -font 1 -highlightthickness 1 -relief 1 -text 1}
    }
    namespace eval ::widgets::.top43.fra54.fra43.cpd46.02 {
        array set save {-background 1 -cursor 1 -highlightthickness 1 -insertbackground 1 -textvariable 1}
    }
    namespace eval ::widgets::.top43.fra54.fra43.fra47 {
        array set save {-background 1 -borderwidth 1 -height 1 -highlightthickness 1 -relief 1 -width 1}
    }
    namespace eval ::widgets::.top43.fra54.fra43.fra47.01 {
        array set save {-anchor 1 -background 1 -disabledforeground 1 -font 1 -highlightthickness 1 -relief 1 -text 1}
    }
    namespace eval ::widgets::.top43.fra54.fra43.fra47.02 {
        array set save {-background 1 -cursor 1 -highlightthickness 1 -insertbackground 1 -textvariable 1}
    }
    namespace eval ::widgets::.top43.fra54.fra43.fra48 {
        array set save {-background 1 -borderwidth 1 -height 1 -highlightthickness 1 -relief 1 -width 1}
    }
    namespace eval ::widgets::.top43.fra54.fra43.fra48.01 {
        array set save {-anchor 1 -background 1 -disabledforeground 1 -font 1 -highlightthickness 1 -relief 1 -text 1}
    }
    namespace eval ::widgets::.top43.fra54.fra43.fra48.02 {
        array set save {-background 1 -cursor 1 -highlightthickness 1 -insertbackground 1 -textvariable 1}
    }
    namespace eval ::widgets::.top43.fra54.fra43.fra49 {
        array set save {-background 1 -borderwidth 1 -height 1 -highlightthickness 1 -relief 1 -width 1}
    }
    namespace eval ::widgets::.top43.fra54.fra43.fra49.01 {
        array set save {-anchor 1 -background 1 -disabledforeground 1 -font 1 -highlightthickness 1 -relief 1 -text 1}
    }
    namespace eval ::widgets::.top43.fra54.fra43.fra49.02 {
        array set save {-background 1 -cursor 1 -highlightthickness 1 -insertbackground 1 -textvariable 1}
    }
    namespace eval ::widgets::.top43.fra54.fra43.fra50 {
        array set save {-background 1 -borderwidth 1 -height 1 -highlightthickness 1 -relief 1 -width 1}
    }
    namespace eval ::widgets::.top43.fra54.fra43.fra50.01 {
        array set save {-anchor 1 -background 1 -disabledforeground 1 -font 1 -highlightthickness 1 -relief 1 -text 1}
    }
    namespace eval ::widgets::.top43.fra54.fra43.fra50.02 {
        array set save {-background 1 -cursor 1 -highlightthickness 1 -insertbackground 1 -textvariable 1}
    }
    namespace eval ::widgets::.top43.fra54.fra43.fra51 {
        array set save {-background 1 -borderwidth 1 -height 1 -highlightthickness 1 -relief 1 -width 1}
    }
    namespace eval ::widgets::.top43.fra54.fra43.fra51.01 {
        array set save {-anchor 1 -background 1 -disabledforeground 1 -font 1 -highlightthickness 1 -relief 1 -text 1}
    }
    namespace eval ::widgets::.top43.fra54.fra43.fra51.02 {
        array set save {-background 1 -cursor 1 -highlightthickness 1 -insertbackground 1 -textvariable 1}
    }
    namespace eval ::widgets::.top43.fra54.fra43.but53 {
        array set save {-background 1 -command 1 -disabledforeground 1 -font 1 -foreground 1 -highlightthickness 1 -text 1 -textvariable 1}
    }
    namespace eval ::widgets::.top43.fra54.fra43.but52 {
        array set save {-background 1 -command 1 -disabledforeground 1 -font 1 -foreground 1 -highlightthickness 1 -text 1 -textvariable 1}
    }
    namespace eval ::widgets::.top43.fra54.lab52 {
        array set save {-background 1 -disabledforeground 1 -font 1 -foreground 1 -highlightcolor 1 -highlightthickness 1 -relief 1 -text 1 -textvariable 1}
    }
    namespace eval ::widgets::.top43.fra54.men43 {
        array set save {-activeforeground 1 -background 1 -disabledforeground 1 -font 1 -foreground 1 -highlightthickness 1 -menu 1 -padx 1 -pady 1 -relief 1 -text 1}
    }
    namespace eval ::widgets::.top43.fra54.men43.m {
        array set save {-activebackground 1 -activeforeground 1 -disabledforeground 1 -foreground 1 -tearoff 1}
    }
    namespace eval ::widgets::.top43.fra54.men44 {
        array set save {-activeforeground 1 -background 1 -disabledforeground 1 -font 1 -foreground 1 -highlightthickness 1 -menu 1 -padx 1 -pady 1 -relief 1 -text 1 -textvariable 1}
    }
    namespace eval ::widgets::.top43.fra54.men44.m {
        array set save {-disabledforeground 1 -tearoff 1}
    }
    namespace eval ::widgets::.top43.fra54.men45 {
        array set save {-activeforeground 1 -background 1 -disabledforeground 1 -font 1 -foreground 1 -highlightthickness 1 -menu 1 -padx 1 -pady 1 -relief 1 -text 1 -textvariable 1}
    }
    namespace eval ::widgets::.top43.fra54.men45.m {
        array set save {-disabledforeground 1 -tearoff 1}
    }
    namespace eval ::widgets::.top43.fra54.fra44 {
        array set save {-background 1 -borderwidth 1 -height 1 -highlightthickness 1 -relief 1 -width 1}
    }
    namespace eval ::widgets::.top43.fra54.fra44.sca48 {
        array set save {-background 1 -bigincrement 1 -command 1 -font 1 -from 1 -highlightthickness 1 -orient 1 -relief 1 -resolution 1 -tickinterval 1 -to 1 -troughcolor 1 -variable 1}
    }
    namespace eval ::widgets::.top43.fra54.fra44.sca49 {
        array set save {-background 1 -bigincrement 1 -command 1 -font 1 -from 1 -highlightthickness 1 -orient 1 -relief 1 -resolution 1 -tickinterval 1 -to 1 -troughcolor 1 -variable 1}
    }
    namespace eval ::widgets::.top43.fra54.fra44.lab50 {
        array set save {-background 1 -disabledforeground 1 -font 1 -highlightthickness 1 -text 1 -textvariable 1}
    }
    namespace eval ::widgets::.top43.fra54.fra44.lab51 {
        array set save {-background 1 -disabledforeground 1 -font 1 -highlightthickness 1 -text 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::.top43.fra54.lab46 {
        array set save {-activebackground 1 -background 1 -disabledforeground 1 -font 1 -foreground 1 -highlightthickness 1 -relief 1 -text 1 -textvariable 1}
    }
    namespace eval ::widgets::.top43.fra54.but47 {
        array set save {-activeforeground 1 -command 1 -disabledforeground 1 -font 1 -foreground 1 -text 1 -textvariable 1}
    }
    namespace eval ::widgets::.top44 {
        array set save {-background 1 -highlightthickness 1}
        set set,origin 1
        set set,size 1
    }
    namespace eval ::widgets::.top44.fra45 {
        array set save {-background 1 -borderwidth 1 -height 1 -highlightthickness 1 -relief 1 -width 1}
    }
    namespace eval ::widgets::.top44.fra45.mes46 {
        array set save {-background 1 -font 1 -foreground 1 -highlightcolor 1 -highlightthickness 1 -justify 1 -padx 1 -pady 1 -text 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::.top44.fra47 {
        array set save {-background 1 -borderwidth 1 -height 1 -highlightthickness 1 -relief 1 -width 1}
    }
    namespace eval ::widgets::.top44.fra47.but48 {
        array set save {-background 1 -command 1 -disabledforeground 1 -font 1 -highlightthickness 1 -text 1 -textvariable 1}
    }
    namespace eval ::widgets::.top45 {
        array set save {-highlightthickness 1}
        set set,origin 1
        set set,size 1
    }
    namespace eval ::widgets::.top45.fra46 {
        array set save {-background 1 -borderwidth 1 -height 1 -highlightthickness 1 -relief 1 -width 1}
    }
    namespace eval ::widgets::.top45.fra46.ent47 {
        array set save {-_tooltip 1 -background 1 -highlightthickness 1 -insertbackground 1 -textvariable 1}
    }
    namespace eval ::widgets::.top46 {
        array set save {-background 1 -highlightthickness 1}
        set set,origin 1
        set set,size 1
    }
    namespace eval ::widgets::.top46.fra47 {
        array set save {-background 1 -borderwidth 1 -height 1 -highlightthickness 1 -relief 1 -width 1}
    }
    namespace eval ::widgets::.top46.fra47.cpd48 {
        array set save {-background 1 -borderwidth 1 -height 1 -highlightthickness 1 -relief 1 -width 1}
    }
    namespace eval ::widgets::.top46.fra47.cpd48.01 {
        array set save {-activebackground 1 -anchor 1 -background 1 -disabledforeground 1 -highlightthickness 1 -relief 1 -text 1}
    }
    namespace eval ::widgets::.top46.fra47.cpd48.02 {
        array set save {-background 1 -cursor 1 -highlightthickness 1 -insertbackground 1 -textvariable 1}
    }
    namespace eval ::widgets::.top46.fra47.cpd49 {
        array set save {-background 1 -borderwidth 1 -height 1 -highlightthickness 1 -relief 1 -width 1}
    }
    namespace eval ::widgets::.top46.fra47.cpd49.01 {
        array set save {-anchor 1 -background 1 -disabledforeground 1 -highlightthickness 1 -relief 1 -text 1}
    }
    namespace eval ::widgets::.top46.fra47.cpd49.02 {
        array set save {-background 1 -cursor 1 -highlightthickness 1 -insertbackground 1 -textvariable 1}
    }
    namespace eval ::widgets::.top46.fra47.cpd50 {
        array set save {-background 1 -borderwidth 1 -height 1 -highlightthickness 1 -relief 1 -width 1}
    }
    namespace eval ::widgets::.top46.fra47.cpd50.01 {
        array set save {-anchor 1 -background 1 -disabledforeground 1 -highlightthickness 1 -relief 1 -text 1}
    }
    namespace eval ::widgets::.top46.fra47.cpd50.02 {
        array set save {-background 1 -cursor 1 -highlightthickness 1 -insertbackground 1 -textvariable 1}
    }
    namespace eval ::widgets::.top46.fra47.cpd51 {
        array set save {-background 1 -borderwidth 1 -height 1 -highlightthickness 1 -relief 1 -width 1}
    }
    namespace eval ::widgets::.top46.fra47.cpd51.01 {
        array set save {-anchor 1 -background 1 -disabledforeground 1 -highlightthickness 1 -relief 1 -text 1}
    }
    namespace eval ::widgets::.top46.fra47.cpd51.02 {
        array set save {-background 1 -cursor 1 -highlightthickness 1 -insertbackground 1 -textvariable 1}
    }
    namespace eval ::widgets::.top46.fra47.fra52 {
        array set save {-background 1 -borderwidth 1 -height 1 -highlightthickness 1 -relief 1 -width 1}
    }
    namespace eval ::widgets::.top46.fra47.fra52.but53 {
        array set save {-activeforeground 1 -background 1 -command 1 -disabledforeground 1 -font 1 -foreground 1 -highlightthickness 1 -text 1 -textvariable 1}
    }
    namespace eval ::widgets::.top46.fra47.fra52.but54 {
        array set save {-activeforeground 1 -background 1 -command 1 -disabledforeground 1 -font 1 -foreground 1 -highlightthickness 1 -text 1 -textvariable 1}
    }
    namespace eval ::widgets::.top46.fra47.fra52.but55 {
        array set save {-activeforeground 1 -background 1 -command 1 -disabledforeground 1 -font 1 -foreground 1 -highlightthickness 1 -text 1 -textvariable 1}
    }
    namespace eval ::widgets::.top47 {
        array set save {-background 1 -highlightthickness 1}
        set set,origin 1
        set set,size 1
    }
    namespace eval ::widgets::.top47.fra48 {
        array set save {-background 1 -borderwidth 1 -height 1 -highlightthickness 1 -relief 1 -width 1}
    }
    namespace eval ::widgets::.top47.fra48.lis50 {
        array set save {-_tooltip 1 -background 1 -font 1 -foreground 1 -highlightbackground 1 -highlightthickness 1 -listvariable 1 -selectbackground 1 -selectforeground 1}
    }
    namespace eval ::widgets::.top47.fra48.fra51 {
        array set save {-background 1 -borderwidth 1 -height 1 -highlightthickness 1 -relief 1 -width 1}
    }
    namespace eval ::widgets::.top47.fra48.fra51.but52 {
        array set save {-background 1 -command 1 -disabledforeground 1 -font 1 -highlightthickness 1 -text 1}
    }
    namespace eval ::widgets::.top47.fra48.fra51.cpd53 {
        array set save {-background 1 -borderwidth 1 -height 1 -highlightthickness 1 -relief 1 -width 1}
    }
    namespace eval ::widgets::.top47.fra48.fra51.cpd53.01 {
        array set save {-anchor 1 -background 1 -disabledforeground 1 -font 1 -highlightthickness 1 -relief 1 -text 1}
    }
    namespace eval ::widgets::.top47.fra48.fra51.cpd53.02 {
        array set save {-_tooltip 1 -background 1 -cursor 1 -highlightthickness 1 -insertbackground 1 -textvariable 1}
    }
    namespace eval ::widgets::.top47.fra48.fra62 {
        array set save {-background 1 -borderwidth 1 -height 1 -highlightthickness 1 -relief 1 -width 1}
    }
    namespace eval ::widgets::.top47.fra48.fra62.but64 {
        array set save {-background 1 -command 1 -disabledforeground 1 -font 1 -highlightthickness 1 -text 1}
    }
    namespace eval ::widgets::.top47.fra48.fra62.but65 {
        array set save {-background 1 -command 1 -disabledforeground 1 -font 1 -highlightthickness 1 -text 1}
    }
    namespace eval ::widgets::.top47.fra48.lab66 {
        array set save {-background 1 -disabledforeground 1 -font 1 -highlightthickness 1 -text 1 -textvariable 1}
    }
    namespace eval ::widgets::.top47.lab49 {
        array set save {-background 1 -disabledforeground 1 -font 1 -highlightthickness 1 -text 1}
    }
    namespace eval ::widgets::.top47.but63 {
        array set save {-background 1 -command 1 -disabledforeground 1 -font 1 -highlightthickness 1 -text 1}
    }
    namespace eval ::widgets::.top48 {
        array set save {-background 1 -highlightthickness 1}
        set set,origin 1
        set set,size 1
    }
    namespace eval ::widgets::.top48.cpd49 {
        array set save {-background 1 -borderwidth 1 -height 1 -highlightthickness 1 -relief 1 -width 1}
    }
    namespace eval ::widgets::.top48.cpd49.01 {
        array set save {-_tooltip 1 -background 1 -font 1 -highlightbackground 1 -highlightcolor 1 -highlightthickness 1 -selectbackground 1 -xscrollcommand 1 -yscrollcommand 1}
    }
    namespace eval ::widgets::.top48.cpd49.02 {
        array set save {-command 1 -highlightthickness 1 -orient 1}
    }
    namespace eval ::widgets::.top48.cpd49.03 {
        array set save {-activebackground 1 -command 1 -highlightthickness 1}
    }
    namespace eval ::widgets::.top48.but50 {
        array set save {-activebackground 1 -background 1 -command 1 -disabledforeground 1 -font 1 -highlightthickness 1 -text 1 -textvariable 1}
    }
    namespace eval ::widgets::.top48.lab51 {
        array set save {-background 1 -disabledforeground 1 -highlightthickness 1 -text 1 -textvariable 1}
    }
    namespace eval ::widgets::.top48.cpd43 {
        array set save {-background 1 -borderwidth 1 -height 1 -highlightthickness 1 -relief 1 -width 1}
    }
    namespace eval ::widgets::.top48.cpd43.01 {
        array set save {-anchor 1 -background 1 -disabledforeground 1 -font 1 -highlightthickness 1 -relief 1 -text 1 -textvariable 1}
    }
    namespace eval ::widgets::.top48.cpd43.02 {
        array set save {-_tooltip 1 -background 1 -cursor 1 -highlightthickness 1 -insertbackground 1 -textvariable 1}
    }
    namespace eval ::widgets::.top48.lab45 {
        array set save {-background 1 -disabledforeground 1 -highlightthickness 1 -text 1 -textvariable 1}
    }
    namespace eval ::widgets::.top48.but46 {
        array set save {-command 1 -disabledforeground 1 -font 1 -highlightthickness 1 -text 1 -textvariable 1}
    }
    namespace eval ::widgets::.top48.but47 {
        array set save {-command 1 -disabledforeground 1 -font 1 -height 1 -highlightthickness 1 -text 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::.top48.but48 {
        array set save {-command 1 -disabledforeground 1 -font 1 -height 1 -highlightthickness 1 -text 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::.top48.but49 {
        array set save {-command 1 -disabledforeground 1 -font 1 -height 1 -highlightthickness 1 -text 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::.top48.but43 {
        array set save {-command 1 -disabledforeground 1 -font 1 -height 1 -highlightthickness 1 -text 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::.top48.but44 {
        array set save {-command 1 -disabledforeground 1 -font 1 -height 1 -highlightthickness 1 -text 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::.top49 {
        array set save {}
        set set,origin 1
        set set,size 1
    }
    namespace eval ::widgets::.top49.che50 {
        array set save {-disabledforeground 1 -font 1 -text 1 -textvariable 1 -variable 1}
    }
    namespace eval ::widgets::.top49.but51 {
        array set save {-command 1 -disabledforeground 1 -font 1 -text 1 -textvariable 1}
    }
    namespace eval ::widgets::.top49.sca54 {
        array set save {-bigincrement 1 -from 1 -orient 1 -resolution 1 -tickinterval 1 -to 1 -variable 1}
    }
    namespace eval ::widgets::.top49.lab55 {
        array set save {-disabledforeground 1 -font 1 -text 1 -textvariable 1}
    }
    namespace eval ::widgets::.top49.mes56 {
        array set save {-highlightcolor 1 -padx 1 -pady 1 -text 1 -width 1}
    }
    namespace eval ::widgets_bindings {
        set tagslist {_TopLevel _vTclBalloon}
    }
}
}

#################################
# USER DEFINED PROCEDURES
#
#############################################################################
## Procedure:  ISOS

proc {ISOS} {isox isoy} {
global widget
global X11
global ISOSAMPLES
puts $X11 "set isosamples $isox, $isoy;\n"
set ISOSAMPLES "set isosample $isox, $isoy;\n"
puts $X11 "replot;\n"
flush $X11
}
#############################################################################
## Procedure:  ISOX

proc {ISOX} {wm val} {
global widget
global isoy
global isox
set isox $val

ISOS $isox $isoy
}
#############################################################################
## Procedure:  ISOY

proc {ISOY} {wm val} {
global widget
global isox
global isoy
set isoy $val

ISOS $isox $isoy
}
#############################################################################
## Procedure:  XTERM

proc {XTERM} {} {
global widget
global X11
global widget
global CMD
global STAT
global RVIEW

global plottype
global linetype
global smooth
global mlabels
global ranges
global LABEL
global marks
global UCONTOUR
global CNTRPARAM
global expresion
set CMD "$plottype $expresion $smooth $linetype;"

set CONST "set term x11;"

puts $X11 $CONST
puts $X11 $LABEL
puts $X11 $mlabels
puts $X11 $ranges
puts $X11 $marks
puts $X11 $UCONTOUR
puts $X11 $CNTRPARAM
puts $X11 $CMD

puts $X11 $RVIEW 

flush $X11
}
#############################################################################
## Procedure:  about

proc {about} {} {
global widget
Window show $widget(Toplevel4)
}
#############################################################################
## Procedure:  axis

proc {axis} {value action deactivate} {
global widget
global marks

if { $value != 0 } {
append marks "$action"
} else {
append marks "$deactivate"
} 
}
#############################################################################
## Procedure:  export

proc {export} {tt ff} {
global widget

global CMD
global STAT
global RVIEW
global expresion

global plottype
global linetype
global smooth
global mlabels
global ranges
global LABEL
global marks
global ISOSAMPLES
global ZOOM

set CMD "$plottype $expresion $smooth $linetype;"

set CONST "set term $tt;
set output '$ff';
"


set FP [open "| gnuplot" w+]
puts $FP $CONST
puts $FP $LABEL
puts $FP $mlabels
puts $FP $ranges
puts $FP $marks
puts $FP $RVIEW 
puts $FP $ISOSAMPLES
puts $FP $ZOOM
puts $FP $CMD

close $FP
}
#############################################################################
## Procedure:  gnuplot

proc {gnuplot} {can} {
$can delete all
set cmx [expr [winfo width $can]-2*[$can cget -border]-2*[$can cget -highlightthickness]]
if {$cmx <= 1} {set cmx [$can cget -width]}
set cmy [expr [winfo height $can]-2*[$can cget -border]-2*[$can cget -highlightthickness]]
if {$cmy <= 1} {set cmy [$can cget -height]}
eval $can create text [expr $cmx * 836 /1000] [expr $cmy * 94 /1000] -text \{x**2*y**2\} -fill red -anchor e [expr [info exists font]?"-font \$font":{}]
$can create line [expr $cmx * 852 /1000] [expr $cmy * 94 /1000] [expr $cmx * 934 /1000] [expr $cmy * 94 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 148 /1000] [expr $cmy * 232 /1000] [expr $cmx * 153 /1000] [expr $cmy * 240 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 153 /1000] [expr $cmy * 240 /1000] [expr $cmx * 157 /1000] [expr $cmy * 249 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 157 /1000] [expr $cmy * 249 /1000] [expr $cmx * 162 /1000] [expr $cmy * 257 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 162 /1000] [expr $cmy * 257 /1000] [expr $cmx * 166 /1000] [expr $cmy * 266 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 166 /1000] [expr $cmy * 266 /1000] [expr $cmx * 171 /1000] [expr $cmy * 274 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 171 /1000] [expr $cmy * 274 /1000] [expr $cmx * 175 /1000] [expr $cmy * 281 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 175 /1000] [expr $cmy * 281 /1000] [expr $cmx * 180 /1000] [expr $cmy * 289 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 180 /1000] [expr $cmy * 289 /1000] [expr $cmx * 184 /1000] [expr $cmy * 296 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 184 /1000] [expr $cmy * 296 /1000] [expr $cmx * 189 /1000] [expr $cmy * 303 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 189 /1000] [expr $cmy * 303 /1000] [expr $cmx * 193 /1000] [expr $cmy * 310 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 193 /1000] [expr $cmy * 310 /1000] [expr $cmx * 198 /1000] [expr $cmy * 317 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 198 /1000] [expr $cmy * 317 /1000] [expr $cmx * 202 /1000] [expr $cmy * 323 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 202 /1000] [expr $cmy * 323 /1000] [expr $cmx * 207 /1000] [expr $cmy * 330 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 207 /1000] [expr $cmy * 330 /1000] [expr $cmx * 211 /1000] [expr $cmy * 336 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 211 /1000] [expr $cmy * 336 /1000] [expr $cmx * 216 /1000] [expr $cmy * 341 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 216 /1000] [expr $cmy * 341 /1000] [expr $cmx * 220 /1000] [expr $cmy * 347 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 220 /1000] [expr $cmy * 347 /1000] [expr $cmx * 225 /1000] [expr $cmy * 352 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 225 /1000] [expr $cmy * 352 /1000] [expr $cmx * 229 /1000] [expr $cmy * 358 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 229 /1000] [expr $cmy * 358 /1000] [expr $cmx * 234 /1000] [expr $cmy * 363 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 234 /1000] [expr $cmy * 363 /1000] [expr $cmx * 238 /1000] [expr $cmy * 367 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 238 /1000] [expr $cmy * 367 /1000] [expr $cmx * 243 /1000] [expr $cmy * 372 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 243 /1000] [expr $cmy * 372 /1000] [expr $cmx * 247 /1000] [expr $cmy * 376 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 247 /1000] [expr $cmy * 376 /1000] [expr $cmx * 252 /1000] [expr $cmy * 380 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 252 /1000] [expr $cmy * 380 /1000] [expr $cmx * 256 /1000] [expr $cmy * 384 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 256 /1000] [expr $cmy * 384 /1000] [expr $cmx * 261 /1000] [expr $cmy * 388 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 261 /1000] [expr $cmy * 388 /1000] [expr $cmx * 265 /1000] [expr $cmy * 391 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 265 /1000] [expr $cmy * 391 /1000] [expr $cmx * 270 /1000] [expr $cmy * 395 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 270 /1000] [expr $cmy * 395 /1000] [expr $cmx * 274 /1000] [expr $cmy * 398 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 274 /1000] [expr $cmy * 398 /1000] [expr $cmx * 279 /1000] [expr $cmy * 400 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 279 /1000] [expr $cmy * 400 /1000] [expr $cmx * 283 /1000] [expr $cmy * 403 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 283 /1000] [expr $cmy * 403 /1000] [expr $cmx * 288 /1000] [expr $cmy * 405 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 288 /1000] [expr $cmy * 405 /1000] [expr $cmx * 292 /1000] [expr $cmy * 408 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 292 /1000] [expr $cmy * 408 /1000] [expr $cmx * 297 /1000] [expr $cmy * 410 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 297 /1000] [expr $cmy * 410 /1000] [expr $cmx * 301 /1000] [expr $cmy * 411 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 301 /1000] [expr $cmy * 411 /1000] [expr $cmx * 306 /1000] [expr $cmy * 413 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 306 /1000] [expr $cmy * 413 /1000] [expr $cmx * 310 /1000] [expr $cmy * 414 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 310 /1000] [expr $cmy * 414 /1000] [expr $cmx * 315 /1000] [expr $cmy * 415 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 315 /1000] [expr $cmy * 415 /1000] [expr $cmx * 319 /1000] [expr $cmy * 416 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 319 /1000] [expr $cmy * 416 /1000] [expr $cmx * 324 /1000] [expr $cmy * 417 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 324 /1000] [expr $cmy * 417 /1000] [expr $cmx * 328 /1000] [expr $cmy * 417 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 328 /1000] [expr $cmy * 417 /1000] [expr $cmx * 333 /1000] [expr $cmy * 418 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 333 /1000] [expr $cmy * 418 /1000] [expr $cmx * 337 /1000] [expr $cmy * 418 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 337 /1000] [expr $cmy * 418 /1000] [expr $cmx * 342 /1000] [expr $cmy * 418 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 342 /1000] [expr $cmy * 418 /1000] [expr $cmx * 346 /1000] [expr $cmy * 417 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 346 /1000] [expr $cmy * 417 /1000] [expr $cmx * 351 /1000] [expr $cmy * 417 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 351 /1000] [expr $cmy * 417 /1000] [expr $cmx * 355 /1000] [expr $cmy * 416 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 355 /1000] [expr $cmy * 416 /1000] [expr $cmx * 360 /1000] [expr $cmy * 415 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 360 /1000] [expr $cmy * 415 /1000] [expr $cmx * 364 /1000] [expr $cmy * 413 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 364 /1000] [expr $cmy * 413 /1000] [expr $cmx * 369 /1000] [expr $cmy * 412 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 369 /1000] [expr $cmy * 412 /1000] [expr $cmx * 373 /1000] [expr $cmy * 410 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 373 /1000] [expr $cmy * 410 /1000] [expr $cmx * 378 /1000] [expr $cmy * 408 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 378 /1000] [expr $cmy * 408 /1000] [expr $cmx * 382 /1000] [expr $cmy * 406 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 382 /1000] [expr $cmy * 406 /1000] [expr $cmx * 387 /1000] [expr $cmy * 404 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 387 /1000] [expr $cmy * 404 /1000] [expr $cmx * 391 /1000] [expr $cmy * 402 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 391 /1000] [expr $cmy * 402 /1000] [expr $cmx * 396 /1000] [expr $cmy * 399 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 396 /1000] [expr $cmy * 399 /1000] [expr $cmx * 400 /1000] [expr $cmy * 396 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 400 /1000] [expr $cmy * 396 /1000] [expr $cmx * 405 /1000] [expr $cmy * 393 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 405 /1000] [expr $cmy * 393 /1000] [expr $cmx * 409 /1000] [expr $cmy * 389 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 409 /1000] [expr $cmy * 389 /1000] [expr $cmx * 414 /1000] [expr $cmy * 386 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 414 /1000] [expr $cmy * 386 /1000] [expr $cmx * 418 /1000] [expr $cmy * 382 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 418 /1000] [expr $cmy * 382 /1000] [expr $cmx * 423 /1000] [expr $cmy * 378 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 423 /1000] [expr $cmy * 378 /1000] [expr $cmx * 427 /1000] [expr $cmy * 374 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 427 /1000] [expr $cmy * 374 /1000] [expr $cmx * 432 /1000] [expr $cmy * 369 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 432 /1000] [expr $cmy * 369 /1000] [expr $cmx * 436 /1000] [expr $cmy * 365 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 436 /1000] [expr $cmy * 365 /1000] [expr $cmx * 441 /1000] [expr $cmy * 360 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 441 /1000] [expr $cmy * 360 /1000] [expr $cmx * 445 /1000] [expr $cmy * 355 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 445 /1000] [expr $cmy * 355 /1000] [expr $cmx * 450 /1000] [expr $cmy * 349 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 450 /1000] [expr $cmy * 349 /1000] [expr $cmx * 454 /1000] [expr $cmy * 344 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 454 /1000] [expr $cmy * 344 /1000] [expr $cmx * 459 /1000] [expr $cmy * 338 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 459 /1000] [expr $cmy * 338 /1000] [expr $cmx * 463 /1000] [expr $cmy * 332 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 463 /1000] [expr $cmy * 332 /1000] [expr $cmx * 468 /1000] [expr $cmy * 326 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 468 /1000] [expr $cmy * 326 /1000] [expr $cmx * 472 /1000] [expr $cmy * 320 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 472 /1000] [expr $cmy * 320 /1000] [expr $cmx * 477 /1000] [expr $cmy * 313 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 477 /1000] [expr $cmy * 313 /1000] [expr $cmx * 481 /1000] [expr $cmy * 306 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 481 /1000] [expr $cmy * 306 /1000] [expr $cmx * 486 /1000] [expr $cmy * 299 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 486 /1000] [expr $cmy * 299 /1000] [expr $cmx * 490 /1000] [expr $cmy * 292 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 490 /1000] [expr $cmy * 292 /1000] [expr $cmx * 495 /1000] [expr $cmy * 285 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 495 /1000] [expr $cmy * 285 /1000] [expr $cmx * 499 /1000] [expr $cmy * 277 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 499 /1000] [expr $cmy * 277 /1000] [expr $cmx * 504 /1000] [expr $cmy * 269 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 504 /1000] [expr $cmy * 269 /1000] [expr $cmx * 508 /1000] [expr $cmy * 261 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 508 /1000] [expr $cmy * 261 /1000] [expr $cmx * 513 /1000] [expr $cmy * 253 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 513 /1000] [expr $cmy * 253 /1000] [expr $cmx * 517 /1000] [expr $cmy * 244 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 517 /1000] [expr $cmy * 244 /1000] [expr $cmx * 522 /1000] [expr $cmy * 235 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 522 /1000] [expr $cmy * 235 /1000] [expr $cmx * 526 /1000] [expr $cmy * 226 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 526 /1000] [expr $cmy * 226 /1000] [expr $cmx * 531 /1000] [expr $cmy * 217 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 531 /1000] [expr $cmy * 217 /1000] [expr $cmx * 535 /1000] [expr $cmy * 208 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 535 /1000] [expr $cmy * 208 /1000] [expr $cmx * 540 /1000] [expr $cmy * 198 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 540 /1000] [expr $cmy * 198 /1000] [expr $cmx * 544 /1000] [expr $cmy * 189 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 544 /1000] [expr $cmy * 189 /1000] [expr $cmx * 549 /1000] [expr $cmy * 179 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 549 /1000] [expr $cmy * 179 /1000] [expr $cmx * 553 /1000] [expr $cmy * 168 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 553 /1000] [expr $cmy * 168 /1000] [expr $cmx * 558 /1000] [expr $cmy * 158 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 558 /1000] [expr $cmy * 158 /1000] [expr $cmx * 562 /1000] [expr $cmy * 147 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 562 /1000] [expr $cmy * 147 /1000] [expr $cmx * 567 /1000] [expr $cmy * 136 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 567 /1000] [expr $cmy * 136 /1000] [expr $cmx * 571 /1000] [expr $cmy * 125 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 571 /1000] [expr $cmy * 125 /1000] [expr $cmx * 576 /1000] [expr $cmy * 114 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 576 /1000] [expr $cmy * 114 /1000] [expr $cmx * 580 /1000] [expr $cmy * 103 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 580 /1000] [expr $cmy * 103 /1000] [expr $cmx * 585 /1000] [expr $cmy * 91 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 585 /1000] [expr $cmy * 91 /1000] [expr $cmx * 589 /1000] [expr $cmy * 79 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 589 /1000] [expr $cmy * 79 /1000] [expr $cmx * 594 /1000] [expr $cmy * 67 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 277 /1000] [expr $cmy * 636 /1000] [expr $cmx * 281 /1000] [expr $cmy * 635 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 281 /1000] [expr $cmy * 635 /1000] [expr $cmx * 286 /1000] [expr $cmy * 633 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 286 /1000] [expr $cmy * 633 /1000] [expr $cmx * 290 /1000] [expr $cmy * 631 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 290 /1000] [expr $cmy * 631 /1000] [expr $cmx * 295 /1000] [expr $cmy * 630 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 295 /1000] [expr $cmy * 630 /1000] [expr $cmx * 299 /1000] [expr $cmy * 628 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 299 /1000] [expr $cmy * 628 /1000] [expr $cmx * 304 /1000] [expr $cmy * 626 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 304 /1000] [expr $cmy * 626 /1000] [expr $cmx * 308 /1000] [expr $cmy * 625 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 308 /1000] [expr $cmy * 625 /1000] [expr $cmx * 313 /1000] [expr $cmy * 623 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 313 /1000] [expr $cmy * 623 /1000] [expr $cmx * 317 /1000] [expr $cmy * 621 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 317 /1000] [expr $cmy * 621 /1000] [expr $cmx * 322 /1000] [expr $cmy * 620 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 322 /1000] [expr $cmy * 620 /1000] [expr $cmx * 326 /1000] [expr $cmy * 618 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 326 /1000] [expr $cmy * 618 /1000] [expr $cmx * 331 /1000] [expr $cmy * 616 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 331 /1000] [expr $cmy * 616 /1000] [expr $cmx * 335 /1000] [expr $cmy * 615 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 335 /1000] [expr $cmy * 615 /1000] [expr $cmx * 340 /1000] [expr $cmy * 613 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 340 /1000] [expr $cmy * 613 /1000] [expr $cmx * 344 /1000] [expr $cmy * 611 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 344 /1000] [expr $cmy * 611 /1000] [expr $cmx * 349 /1000] [expr $cmy * 610 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 349 /1000] [expr $cmy * 610 /1000] [expr $cmx * 353 /1000] [expr $cmy * 608 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 353 /1000] [expr $cmy * 608 /1000] [expr $cmx * 358 /1000] [expr $cmy * 606 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 358 /1000] [expr $cmy * 606 /1000] [expr $cmx * 362 /1000] [expr $cmy * 605 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 362 /1000] [expr $cmy * 605 /1000] [expr $cmx * 367 /1000] [expr $cmy * 603 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 367 /1000] [expr $cmy * 603 /1000] [expr $cmx * 371 /1000] [expr $cmy * 601 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 371 /1000] [expr $cmy * 601 /1000] [expr $cmx * 376 /1000] [expr $cmy * 600 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 376 /1000] [expr $cmy * 600 /1000] [expr $cmx * 380 /1000] [expr $cmy * 598 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 380 /1000] [expr $cmy * 598 /1000] [expr $cmx * 385 /1000] [expr $cmy * 596 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 385 /1000] [expr $cmy * 596 /1000] [expr $cmx * 389 /1000] [expr $cmy * 595 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 389 /1000] [expr $cmy * 595 /1000] [expr $cmx * 394 /1000] [expr $cmy * 593 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 394 /1000] [expr $cmy * 593 /1000] [expr $cmx * 398 /1000] [expr $cmy * 591 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 398 /1000] [expr $cmy * 591 /1000] [expr $cmx * 403 /1000] [expr $cmy * 590 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 403 /1000] [expr $cmy * 590 /1000] [expr $cmx * 407 /1000] [expr $cmy * 588 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 407 /1000] [expr $cmy * 588 /1000] [expr $cmx * 412 /1000] [expr $cmy * 586 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 412 /1000] [expr $cmy * 586 /1000] [expr $cmx * 416 /1000] [expr $cmy * 585 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 416 /1000] [expr $cmy * 585 /1000] [expr $cmx * 421 /1000] [expr $cmy * 583 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 421 /1000] [expr $cmy * 583 /1000] [expr $cmx * 425 /1000] [expr $cmy * 581 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 425 /1000] [expr $cmy * 581 /1000] [expr $cmx * 430 /1000] [expr $cmy * 580 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 430 /1000] [expr $cmy * 580 /1000] [expr $cmx * 434 /1000] [expr $cmy * 578 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 434 /1000] [expr $cmy * 578 /1000] [expr $cmx * 439 /1000] [expr $cmy * 576 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 439 /1000] [expr $cmy * 576 /1000] [expr $cmx * 443 /1000] [expr $cmy * 575 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 443 /1000] [expr $cmy * 575 /1000] [expr $cmx * 448 /1000] [expr $cmy * 573 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 448 /1000] [expr $cmy * 573 /1000] [expr $cmx * 452 /1000] [expr $cmy * 571 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 452 /1000] [expr $cmy * 571 /1000] [expr $cmx * 457 /1000] [expr $cmy * 570 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 457 /1000] [expr $cmy * 570 /1000] [expr $cmx * 461 /1000] [expr $cmy * 568 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 461 /1000] [expr $cmy * 568 /1000] [expr $cmx * 466 /1000] [expr $cmy * 566 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 466 /1000] [expr $cmy * 566 /1000] [expr $cmx * 470 /1000] [expr $cmy * 565 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 470 /1000] [expr $cmy * 565 /1000] [expr $cmx * 475 /1000] [expr $cmy * 563 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 475 /1000] [expr $cmy * 563 /1000] [expr $cmx * 479 /1000] [expr $cmy * 561 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 479 /1000] [expr $cmy * 561 /1000] [expr $cmx * 484 /1000] [expr $cmy * 560 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 484 /1000] [expr $cmy * 560 /1000] [expr $cmx * 488 /1000] [expr $cmy * 558 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 488 /1000] [expr $cmy * 558 /1000] [expr $cmx * 493 /1000] [expr $cmy * 556 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 493 /1000] [expr $cmy * 556 /1000] [expr $cmx * 497 /1000] [expr $cmy * 555 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 497 /1000] [expr $cmy * 555 /1000] [expr $cmx * 502 /1000] [expr $cmy * 553 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 502 /1000] [expr $cmy * 553 /1000] [expr $cmx * 506 /1000] [expr $cmy * 551 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 506 /1000] [expr $cmy * 551 /1000] [expr $cmx * 511 /1000] [expr $cmy * 550 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 511 /1000] [expr $cmy * 550 /1000] [expr $cmx * 515 /1000] [expr $cmy * 548 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 515 /1000] [expr $cmy * 548 /1000] [expr $cmx * 520 /1000] [expr $cmy * 547 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 520 /1000] [expr $cmy * 547 /1000] [expr $cmx * 524 /1000] [expr $cmy * 545 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 524 /1000] [expr $cmy * 545 /1000] [expr $cmx * 529 /1000] [expr $cmy * 543 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 529 /1000] [expr $cmy * 543 /1000] [expr $cmx * 533 /1000] [expr $cmy * 542 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 533 /1000] [expr $cmy * 542 /1000] [expr $cmx * 538 /1000] [expr $cmy * 540 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 538 /1000] [expr $cmy * 540 /1000] [expr $cmx * 542 /1000] [expr $cmy * 538 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 542 /1000] [expr $cmy * 538 /1000] [expr $cmx * 547 /1000] [expr $cmy * 537 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 547 /1000] [expr $cmy * 537 /1000] [expr $cmx * 551 /1000] [expr $cmy * 535 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 551 /1000] [expr $cmy * 535 /1000] [expr $cmx * 556 /1000] [expr $cmy * 533 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 556 /1000] [expr $cmy * 533 /1000] [expr $cmx * 560 /1000] [expr $cmy * 532 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 560 /1000] [expr $cmy * 532 /1000] [expr $cmx * 565 /1000] [expr $cmy * 530 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 565 /1000] [expr $cmy * 530 /1000] [expr $cmx * 569 /1000] [expr $cmy * 528 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 569 /1000] [expr $cmy * 528 /1000] [expr $cmx * 574 /1000] [expr $cmy * 527 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 574 /1000] [expr $cmy * 527 /1000] [expr $cmx * 578 /1000] [expr $cmy * 525 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 578 /1000] [expr $cmy * 525 /1000] [expr $cmx * 583 /1000] [expr $cmy * 523 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 583 /1000] [expr $cmy * 523 /1000] [expr $cmx * 587 /1000] [expr $cmy * 522 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 587 /1000] [expr $cmy * 522 /1000] [expr $cmx * 592 /1000] [expr $cmy * 520 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 592 /1000] [expr $cmy * 520 /1000] [expr $cmx * 596 /1000] [expr $cmy * 518 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 596 /1000] [expr $cmy * 518 /1000] [expr $cmx * 601 /1000] [expr $cmy * 517 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 601 /1000] [expr $cmy * 517 /1000] [expr $cmx * 605 /1000] [expr $cmy * 515 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 605 /1000] [expr $cmy * 515 /1000] [expr $cmx * 610 /1000] [expr $cmy * 513 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 610 /1000] [expr $cmy * 513 /1000] [expr $cmx * 614 /1000] [expr $cmy * 512 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 614 /1000] [expr $cmy * 512 /1000] [expr $cmx * 619 /1000] [expr $cmy * 510 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 619 /1000] [expr $cmy * 510 /1000] [expr $cmx * 623 /1000] [expr $cmy * 508 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 623 /1000] [expr $cmy * 508 /1000] [expr $cmx * 628 /1000] [expr $cmy * 507 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 628 /1000] [expr $cmy * 507 /1000] [expr $cmx * 632 /1000] [expr $cmy * 505 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 632 /1000] [expr $cmy * 505 /1000] [expr $cmx * 637 /1000] [expr $cmy * 503 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 637 /1000] [expr $cmy * 503 /1000] [expr $cmx * 641 /1000] [expr $cmy * 502 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 641 /1000] [expr $cmy * 502 /1000] [expr $cmx * 646 /1000] [expr $cmy * 500 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 646 /1000] [expr $cmy * 500 /1000] [expr $cmx * 650 /1000] [expr $cmy * 498 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 650 /1000] [expr $cmy * 498 /1000] [expr $cmx * 655 /1000] [expr $cmy * 497 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 655 /1000] [expr $cmy * 497 /1000] [expr $cmx * 659 /1000] [expr $cmy * 495 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 659 /1000] [expr $cmy * 495 /1000] [expr $cmx * 664 /1000] [expr $cmy * 493 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 664 /1000] [expr $cmy * 493 /1000] [expr $cmx * 668 /1000] [expr $cmy * 492 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 668 /1000] [expr $cmy * 492 /1000] [expr $cmx * 673 /1000] [expr $cmy * 490 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 673 /1000] [expr $cmy * 490 /1000] [expr $cmx * 677 /1000] [expr $cmy * 488 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 677 /1000] [expr $cmy * 488 /1000] [expr $cmx * 682 /1000] [expr $cmy * 487 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 682 /1000] [expr $cmy * 487 /1000] [expr $cmx * 686 /1000] [expr $cmy * 485 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 686 /1000] [expr $cmy * 485 /1000] [expr $cmx * 691 /1000] [expr $cmy * 483 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 691 /1000] [expr $cmy * 483 /1000] [expr $cmx * 695 /1000] [expr $cmy * 482 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 695 /1000] [expr $cmy * 482 /1000] [expr $cmx * 700 /1000] [expr $cmy * 480 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 700 /1000] [expr $cmy * 480 /1000] [expr $cmx * 704 /1000] [expr $cmy * 478 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 704 /1000] [expr $cmy * 478 /1000] [expr $cmx * 709 /1000] [expr $cmy * 477 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 709 /1000] [expr $cmy * 477 /1000] [expr $cmx * 713 /1000] [expr $cmy * 475 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 713 /1000] [expr $cmy * 475 /1000] [expr $cmx * 718 /1000] [expr $cmy * 473 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 718 /1000] [expr $cmy * 473 /1000] [expr $cmx * 722 /1000] [expr $cmy * 472 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 405 /1000] [expr $cmy * 517 /1000] [expr $cmx * 410 /1000] [expr $cmy * 526 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 410 /1000] [expr $cmy * 526 /1000] [expr $cmx * 414 /1000] [expr $cmy * 535 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 414 /1000] [expr $cmy * 535 /1000] [expr $cmx * 419 /1000] [expr $cmy * 543 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 419 /1000] [expr $cmy * 543 /1000] [expr $cmx * 423 /1000] [expr $cmy * 551 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 423 /1000] [expr $cmy * 551 /1000] [expr $cmx * 428 /1000] [expr $cmy * 559 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 428 /1000] [expr $cmy * 559 /1000] [expr $cmx * 432 /1000] [expr $cmy * 567 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 432 /1000] [expr $cmy * 567 /1000] [expr $cmx * 437 /1000] [expr $cmy * 574 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 437 /1000] [expr $cmy * 574 /1000] [expr $cmx * 441 /1000] [expr $cmy * 582 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 441 /1000] [expr $cmy * 582 /1000] [expr $cmx * 446 /1000] [expr $cmy * 589 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 446 /1000] [expr $cmy * 589 /1000] [expr $cmx * 450 /1000] [expr $cmy * 596 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 450 /1000] [expr $cmy * 596 /1000] [expr $cmx * 455 /1000] [expr $cmy * 602 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 455 /1000] [expr $cmy * 602 /1000] [expr $cmx * 459 /1000] [expr $cmy * 609 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 459 /1000] [expr $cmy * 609 /1000] [expr $cmx * 464 /1000] [expr $cmy * 615 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 464 /1000] [expr $cmy * 615 /1000] [expr $cmx * 468 /1000] [expr $cmy * 621 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 468 /1000] [expr $cmy * 621 /1000] [expr $cmx * 473 /1000] [expr $cmy * 627 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 473 /1000] [expr $cmy * 627 /1000] [expr $cmx * 477 /1000] [expr $cmy * 633 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 477 /1000] [expr $cmy * 633 /1000] [expr $cmx * 482 /1000] [expr $cmy * 638 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 482 /1000] [expr $cmy * 638 /1000] [expr $cmx * 486 /1000] [expr $cmy * 643 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 486 /1000] [expr $cmy * 643 /1000] [expr $cmx * 491 /1000] [expr $cmy * 648 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 491 /1000] [expr $cmy * 648 /1000] [expr $cmx * 495 /1000] [expr $cmy * 653 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 495 /1000] [expr $cmy * 653 /1000] [expr $cmx * 500 /1000] [expr $cmy * 657 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 500 /1000] [expr $cmy * 657 /1000] [expr $cmx * 504 /1000] [expr $cmy * 662 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 504 /1000] [expr $cmy * 662 /1000] [expr $cmx * 509 /1000] [expr $cmy * 666 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 509 /1000] [expr $cmy * 666 /1000] [expr $cmx * 513 /1000] [expr $cmy * 670 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 513 /1000] [expr $cmy * 670 /1000] [expr $cmx * 518 /1000] [expr $cmy * 673 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 518 /1000] [expr $cmy * 673 /1000] [expr $cmx * 522 /1000] [expr $cmy * 677 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 522 /1000] [expr $cmy * 677 /1000] [expr $cmx * 527 /1000] [expr $cmy * 680 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 527 /1000] [expr $cmy * 680 /1000] [expr $cmx * 531 /1000] [expr $cmy * 683 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 531 /1000] [expr $cmy * 683 /1000] [expr $cmx * 536 /1000] [expr $cmy * 686 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 536 /1000] [expr $cmy * 686 /1000] [expr $cmx * 540 /1000] [expr $cmy * 689 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 540 /1000] [expr $cmy * 689 /1000] [expr $cmx * 545 /1000] [expr $cmy * 691 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 545 /1000] [expr $cmy * 691 /1000] [expr $cmx * 549 /1000] [expr $cmy * 693 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 549 /1000] [expr $cmy * 693 /1000] [expr $cmx * 554 /1000] [expr $cmy * 695 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 554 /1000] [expr $cmy * 695 /1000] [expr $cmx * 558 /1000] [expr $cmy * 697 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 558 /1000] [expr $cmy * 697 /1000] [expr $cmx * 563 /1000] [expr $cmy * 698 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 563 /1000] [expr $cmy * 698 /1000] [expr $cmx * 567 /1000] [expr $cmy * 700 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 567 /1000] [expr $cmy * 700 /1000] [expr $cmx * 572 /1000] [expr $cmy * 701 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 572 /1000] [expr $cmy * 701 /1000] [expr $cmx * 576 /1000] [expr $cmy * 702 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 576 /1000] [expr $cmy * 702 /1000] [expr $cmx * 581 /1000] [expr $cmy * 702 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 581 /1000] [expr $cmy * 702 /1000] [expr $cmx * 585 /1000] [expr $cmy * 703 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 585 /1000] [expr $cmy * 703 /1000] [expr $cmx * 590 /1000] [expr $cmy * 703 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 590 /1000] [expr $cmy * 703 /1000] [expr $cmx * 594 /1000] [expr $cmy * 703 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 594 /1000] [expr $cmy * 703 /1000] [expr $cmx * 599 /1000] [expr $cmy * 703 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 599 /1000] [expr $cmy * 703 /1000] [expr $cmx * 603 /1000] [expr $cmy * 703 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 603 /1000] [expr $cmy * 703 /1000] [expr $cmx * 608 /1000] [expr $cmy * 702 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 608 /1000] [expr $cmy * 702 /1000] [expr $cmx * 612 /1000] [expr $cmy * 701 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 612 /1000] [expr $cmy * 701 /1000] [expr $cmx * 617 /1000] [expr $cmy * 700 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 617 /1000] [expr $cmy * 700 /1000] [expr $cmx * 621 /1000] [expr $cmy * 699 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 621 /1000] [expr $cmy * 699 /1000] [expr $cmx * 626 /1000] [expr $cmy * 698 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 626 /1000] [expr $cmy * 698 /1000] [expr $cmx * 630 /1000] [expr $cmy * 696 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 630 /1000] [expr $cmy * 696 /1000] [expr $cmx * 635 /1000] [expr $cmy * 694 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 635 /1000] [expr $cmy * 694 /1000] [expr $cmx * 639 /1000] [expr $cmy * 692 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 639 /1000] [expr $cmy * 692 /1000] [expr $cmx * 644 /1000] [expr $cmy * 690 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 644 /1000] [expr $cmy * 690 /1000] [expr $cmx * 648 /1000] [expr $cmy * 687 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 648 /1000] [expr $cmy * 687 /1000] [expr $cmx * 653 /1000] [expr $cmy * 684 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 653 /1000] [expr $cmy * 684 /1000] [expr $cmx * 657 /1000] [expr $cmy * 681 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 657 /1000] [expr $cmy * 681 /1000] [expr $cmx * 662 /1000] [expr $cmy * 678 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 662 /1000] [expr $cmy * 678 /1000] [expr $cmx * 666 /1000] [expr $cmy * 675 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 666 /1000] [expr $cmy * 675 /1000] [expr $cmx * 671 /1000] [expr $cmy * 671 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 671 /1000] [expr $cmy * 671 /1000] [expr $cmx * 675 /1000] [expr $cmy * 668 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 675 /1000] [expr $cmy * 668 /1000] [expr $cmx * 680 /1000] [expr $cmy * 663 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 680 /1000] [expr $cmy * 663 /1000] [expr $cmx * 684 /1000] [expr $cmy * 659 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 684 /1000] [expr $cmy * 659 /1000] [expr $cmx * 689 /1000] [expr $cmy * 655 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 689 /1000] [expr $cmy * 655 /1000] [expr $cmx * 693 /1000] [expr $cmy * 650 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 693 /1000] [expr $cmy * 650 /1000] [expr $cmx * 698 /1000] [expr $cmy * 645 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 698 /1000] [expr $cmy * 645 /1000] [expr $cmx * 702 /1000] [expr $cmy * 640 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 702 /1000] [expr $cmy * 640 /1000] [expr $cmx * 707 /1000] [expr $cmy * 635 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 707 /1000] [expr $cmy * 635 /1000] [expr $cmx * 711 /1000] [expr $cmy * 629 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 711 /1000] [expr $cmy * 629 /1000] [expr $cmx * 716 /1000] [expr $cmy * 624 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 716 /1000] [expr $cmy * 624 /1000] [expr $cmx * 720 /1000] [expr $cmy * 618 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 720 /1000] [expr $cmy * 618 /1000] [expr $cmx * 725 /1000] [expr $cmy * 612 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 725 /1000] [expr $cmy * 612 /1000] [expr $cmx * 729 /1000] [expr $cmy * 605 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 729 /1000] [expr $cmy * 605 /1000] [expr $cmx * 734 /1000] [expr $cmy * 599 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 734 /1000] [expr $cmy * 599 /1000] [expr $cmx * 738 /1000] [expr $cmy * 592 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 738 /1000] [expr $cmy * 592 /1000] [expr $cmx * 743 /1000] [expr $cmy * 585 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 743 /1000] [expr $cmy * 585 /1000] [expr $cmx * 747 /1000] [expr $cmy * 578 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 747 /1000] [expr $cmy * 578 /1000] [expr $cmx * 752 /1000] [expr $cmy * 570 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 752 /1000] [expr $cmy * 570 /1000] [expr $cmx * 756 /1000] [expr $cmy * 562 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 756 /1000] [expr $cmy * 562 /1000] [expr $cmx * 761 /1000] [expr $cmy * 555 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 761 /1000] [expr $cmy * 555 /1000] [expr $cmx * 765 /1000] [expr $cmy * 547 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 765 /1000] [expr $cmy * 547 /1000] [expr $cmx * 770 /1000] [expr $cmy * 538 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 770 /1000] [expr $cmy * 538 /1000] [expr $cmx * 774 /1000] [expr $cmy * 530 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 774 /1000] [expr $cmy * 530 /1000] [expr $cmx * 779 /1000] [expr $cmy * 521 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 779 /1000] [expr $cmy * 521 /1000] [expr $cmx * 783 /1000] [expr $cmy * 512 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 783 /1000] [expr $cmy * 512 /1000] [expr $cmx * 788 /1000] [expr $cmy * 503 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 788 /1000] [expr $cmy * 503 /1000] [expr $cmx * 792 /1000] [expr $cmy * 494 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 792 /1000] [expr $cmy * 494 /1000] [expr $cmx * 797 /1000] [expr $cmy * 484 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 797 /1000] [expr $cmy * 484 /1000] [expr $cmx * 801 /1000] [expr $cmy * 474 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 801 /1000] [expr $cmy * 474 /1000] [expr $cmx * 806 /1000] [expr $cmy * 464 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 806 /1000] [expr $cmy * 464 /1000] [expr $cmx * 810 /1000] [expr $cmy * 454 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 810 /1000] [expr $cmy * 454 /1000] [expr $cmx * 815 /1000] [expr $cmy * 444 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 815 /1000] [expr $cmy * 444 /1000] [expr $cmx * 819 /1000] [expr $cmy * 433 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 819 /1000] [expr $cmy * 433 /1000] [expr $cmx * 824 /1000] [expr $cmy * 422 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 824 /1000] [expr $cmy * 422 /1000] [expr $cmx * 828 /1000] [expr $cmy * 411 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 828 /1000] [expr $cmy * 411 /1000] [expr $cmx * 833 /1000] [expr $cmy * 400 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 833 /1000] [expr $cmy * 400 /1000] [expr $cmx * 837 /1000] [expr $cmy * 388 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 837 /1000] [expr $cmy * 388 /1000] [expr $cmx * 842 /1000] [expr $cmy * 376 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 842 /1000] [expr $cmy * 376 /1000] [expr $cmx * 846 /1000] [expr $cmy * 365 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 846 /1000] [expr $cmy * 365 /1000] [expr $cmx * 851 /1000] [expr $cmy * 352 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 148 /1000] [expr $cmy * 232 /1000] [expr $cmx * 151 /1000] [expr $cmy * 245 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 151 /1000] [expr $cmy * 245 /1000] [expr $cmx * 154 /1000] [expr $cmy * 258 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 154 /1000] [expr $cmy * 258 /1000] [expr $cmx * 156 /1000] [expr $cmy * 271 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 156 /1000] [expr $cmy * 271 /1000] [expr $cmx * 159 /1000] [expr $cmy * 284 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 159 /1000] [expr $cmy * 284 /1000] [expr $cmx * 161 /1000] [expr $cmy * 296 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 161 /1000] [expr $cmy * 296 /1000] [expr $cmx * 164 /1000] [expr $cmy * 309 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 164 /1000] [expr $cmy * 309 /1000] [expr $cmx * 167 /1000] [expr $cmy * 321 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 167 /1000] [expr $cmy * 321 /1000] [expr $cmx * 169 /1000] [expr $cmy * 333 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 169 /1000] [expr $cmy * 333 /1000] [expr $cmx * 172 /1000] [expr $cmy * 344 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 172 /1000] [expr $cmy * 344 /1000] [expr $cmx * 174 /1000] [expr $cmy * 356 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 174 /1000] [expr $cmy * 356 /1000] [expr $cmx * 177 /1000] [expr $cmy * 367 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 177 /1000] [expr $cmy * 367 /1000] [expr $cmx * 180 /1000] [expr $cmy * 378 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 180 /1000] [expr $cmy * 378 /1000] [expr $cmx * 182 /1000] [expr $cmy * 389 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 182 /1000] [expr $cmy * 389 /1000] [expr $cmx * 185 /1000] [expr $cmy * 399 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 185 /1000] [expr $cmy * 399 /1000] [expr $cmx * 187 /1000] [expr $cmy * 410 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 187 /1000] [expr $cmy * 410 /1000] [expr $cmx * 190 /1000] [expr $cmy * 420 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 190 /1000] [expr $cmy * 420 /1000] [expr $cmx * 193 /1000] [expr $cmy * 430 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 193 /1000] [expr $cmy * 430 /1000] [expr $cmx * 195 /1000] [expr $cmy * 439 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 195 /1000] [expr $cmy * 439 /1000] [expr $cmx * 198 /1000] [expr $cmy * 449 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 198 /1000] [expr $cmy * 449 /1000] [expr $cmx * 200 /1000] [expr $cmy * 458 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 200 /1000] [expr $cmy * 458 /1000] [expr $cmx * 203 /1000] [expr $cmy * 467 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 203 /1000] [expr $cmy * 467 /1000] [expr $cmx * 206 /1000] [expr $cmy * 476 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 206 /1000] [expr $cmy * 476 /1000] [expr $cmx * 208 /1000] [expr $cmy * 485 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 208 /1000] [expr $cmy * 485 /1000] [expr $cmx * 211 /1000] [expr $cmy * 493 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 211 /1000] [expr $cmy * 493 /1000] [expr $cmx * 213 /1000] [expr $cmy * 502 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 213 /1000] [expr $cmy * 502 /1000] [expr $cmx * 216 /1000] [expr $cmy * 510 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 216 /1000] [expr $cmy * 510 /1000] [expr $cmx * 219 /1000] [expr $cmy * 517 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 219 /1000] [expr $cmy * 517 /1000] [expr $cmx * 221 /1000] [expr $cmy * 525 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 221 /1000] [expr $cmy * 525 /1000] [expr $cmx * 224 /1000] [expr $cmy * 532 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 224 /1000] [expr $cmy * 532 /1000] [expr $cmx * 226 /1000] [expr $cmy * 540 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 226 /1000] [expr $cmy * 540 /1000] [expr $cmx * 229 /1000] [expr $cmy * 546 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 229 /1000] [expr $cmy * 546 /1000] [expr $cmx * 232 /1000] [expr $cmy * 553 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 232 /1000] [expr $cmy * 553 /1000] [expr $cmx * 234 /1000] [expr $cmy * 560 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 234 /1000] [expr $cmy * 560 /1000] [expr $cmx * 237 /1000] [expr $cmy * 566 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 237 /1000] [expr $cmy * 566 /1000] [expr $cmx * 239 /1000] [expr $cmy * 572 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 239 /1000] [expr $cmy * 572 /1000] [expr $cmx * 242 /1000] [expr $cmy * 578 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 242 /1000] [expr $cmy * 578 /1000] [expr $cmx * 244 /1000] [expr $cmy * 584 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 244 /1000] [expr $cmy * 584 /1000] [expr $cmx * 247 /1000] [expr $cmy * 589 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 247 /1000] [expr $cmy * 589 /1000] [expr $cmx * 250 /1000] [expr $cmy * 594 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 250 /1000] [expr $cmy * 594 /1000] [expr $cmx * 252 /1000] [expr $cmy * 599 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 252 /1000] [expr $cmy * 599 /1000] [expr $cmx * 255 /1000] [expr $cmy * 604 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 255 /1000] [expr $cmy * 604 /1000] [expr $cmx * 257 /1000] [expr $cmy * 609 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 257 /1000] [expr $cmy * 609 /1000] [expr $cmx * 260 /1000] [expr $cmy * 613 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 260 /1000] [expr $cmy * 613 /1000] [expr $cmx * 263 /1000] [expr $cmy * 617 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 263 /1000] [expr $cmy * 617 /1000] [expr $cmx * 265 /1000] [expr $cmy * 621 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 265 /1000] [expr $cmy * 621 /1000] [expr $cmx * 268 /1000] [expr $cmy * 625 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 268 /1000] [expr $cmy * 625 /1000] [expr $cmx * 270 /1000] [expr $cmy * 629 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 270 /1000] [expr $cmy * 629 /1000] [expr $cmx * 273 /1000] [expr $cmy * 632 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 273 /1000] [expr $cmy * 632 /1000] [expr $cmx * 276 /1000] [expr $cmy * 635 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 276 /1000] [expr $cmy * 635 /1000] [expr $cmx * 278 /1000] [expr $cmy * 638 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 278 /1000] [expr $cmy * 638 /1000] [expr $cmx * 281 /1000] [expr $cmy * 641 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 281 /1000] [expr $cmy * 641 /1000] [expr $cmx * 283 /1000] [expr $cmy * 643 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 283 /1000] [expr $cmy * 643 /1000] [expr $cmx * 286 /1000] [expr $cmy * 645 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 286 /1000] [expr $cmy * 645 /1000] [expr $cmx * 289 /1000] [expr $cmy * 647 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 289 /1000] [expr $cmy * 647 /1000] [expr $cmx * 291 /1000] [expr $cmy * 649 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 291 /1000] [expr $cmy * 649 /1000] [expr $cmx * 294 /1000] [expr $cmy * 651 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 294 /1000] [expr $cmy * 651 /1000] [expr $cmx * 296 /1000] [expr $cmy * 652 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 296 /1000] [expr $cmy * 652 /1000] [expr $cmx * 299 /1000] [expr $cmy * 653 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 299 /1000] [expr $cmy * 653 /1000] [expr $cmx * 302 /1000] [expr $cmy * 654 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 302 /1000] [expr $cmy * 654 /1000] [expr $cmx * 304 /1000] [expr $cmy * 655 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 304 /1000] [expr $cmy * 655 /1000] [expr $cmx * 307 /1000] [expr $cmy * 655 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 307 /1000] [expr $cmy * 655 /1000] [expr $cmx * 309 /1000] [expr $cmy * 656 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 309 /1000] [expr $cmy * 656 /1000] [expr $cmx * 312 /1000] [expr $cmy * 656 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 312 /1000] [expr $cmy * 656 /1000] [expr $cmx * 315 /1000] [expr $cmy * 656 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 315 /1000] [expr $cmy * 656 /1000] [expr $cmx * 317 /1000] [expr $cmy * 655 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 317 /1000] [expr $cmy * 655 /1000] [expr $cmx * 320 /1000] [expr $cmy * 655 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 320 /1000] [expr $cmy * 655 /1000] [expr $cmx * 322 /1000] [expr $cmy * 654 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 322 /1000] [expr $cmy * 654 /1000] [expr $cmx * 325 /1000] [expr $cmy * 653 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 325 /1000] [expr $cmy * 653 /1000] [expr $cmx * 328 /1000] [expr $cmy * 652 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 328 /1000] [expr $cmy * 652 /1000] [expr $cmx * 330 /1000] [expr $cmy * 651 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 330 /1000] [expr $cmy * 651 /1000] [expr $cmx * 333 /1000] [expr $cmy * 649 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 333 /1000] [expr $cmy * 649 /1000] [expr $cmx * 335 /1000] [expr $cmy * 647 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 335 /1000] [expr $cmy * 647 /1000] [expr $cmx * 338 /1000] [expr $cmy * 645 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 338 /1000] [expr $cmy * 645 /1000] [expr $cmx * 341 /1000] [expr $cmy * 643 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 341 /1000] [expr $cmy * 643 /1000] [expr $cmx * 343 /1000] [expr $cmy * 640 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 343 /1000] [expr $cmy * 640 /1000] [expr $cmx * 346 /1000] [expr $cmy * 638 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 346 /1000] [expr $cmy * 638 /1000] [expr $cmx * 348 /1000] [expr $cmy * 635 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 348 /1000] [expr $cmy * 635 /1000] [expr $cmx * 351 /1000] [expr $cmy * 632 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 351 /1000] [expr $cmy * 632 /1000] [expr $cmx * 354 /1000] [expr $cmy * 628 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 354 /1000] [expr $cmy * 628 /1000] [expr $cmx * 356 /1000] [expr $cmy * 625 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 356 /1000] [expr $cmy * 625 /1000] [expr $cmx * 359 /1000] [expr $cmy * 621 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 359 /1000] [expr $cmy * 621 /1000] [expr $cmx * 361 /1000] [expr $cmy * 617 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 361 /1000] [expr $cmy * 617 /1000] [expr $cmx * 364 /1000] [expr $cmy * 613 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 364 /1000] [expr $cmy * 613 /1000] [expr $cmx * 366 /1000] [expr $cmy * 609 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 366 /1000] [expr $cmy * 609 /1000] [expr $cmx * 369 /1000] [expr $cmy * 604 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 369 /1000] [expr $cmy * 604 /1000] [expr $cmx * 372 /1000] [expr $cmy * 599 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 372 /1000] [expr $cmy * 599 /1000] [expr $cmx * 374 /1000] [expr $cmy * 594 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 374 /1000] [expr $cmy * 594 /1000] [expr $cmx * 377 /1000] [expr $cmy * 589 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 377 /1000] [expr $cmy * 589 /1000] [expr $cmx * 379 /1000] [expr $cmy * 584 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 379 /1000] [expr $cmy * 584 /1000] [expr $cmx * 382 /1000] [expr $cmy * 578 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 382 /1000] [expr $cmy * 578 /1000] [expr $cmx * 385 /1000] [expr $cmy * 572 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 385 /1000] [expr $cmy * 572 /1000] [expr $cmx * 387 /1000] [expr $cmy * 566 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 387 /1000] [expr $cmy * 566 /1000] [expr $cmx * 390 /1000] [expr $cmy * 560 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 390 /1000] [expr $cmy * 560 /1000] [expr $cmx * 392 /1000] [expr $cmy * 553 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 392 /1000] [expr $cmy * 553 /1000] [expr $cmx * 395 /1000] [expr $cmy * 546 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 395 /1000] [expr $cmy * 546 /1000] [expr $cmx * 398 /1000] [expr $cmy * 539 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 398 /1000] [expr $cmy * 539 /1000] [expr $cmx * 400 /1000] [expr $cmy * 532 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 400 /1000] [expr $cmy * 532 /1000] [expr $cmx * 403 /1000] [expr $cmy * 525 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 403 /1000] [expr $cmy * 525 /1000] [expr $cmx * 405 /1000] [expr $cmy * 517 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 371 /1000] [expr $cmy * 411 /1000] [expr $cmx * 374 /1000] [expr $cmy * 414 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 374 /1000] [expr $cmy * 414 /1000] [expr $cmx * 376 /1000] [expr $cmy * 417 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 376 /1000] [expr $cmy * 417 /1000] [expr $cmx * 379 /1000] [expr $cmy * 420 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 379 /1000] [expr $cmy * 420 /1000] [expr $cmx * 381 /1000] [expr $cmy * 423 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 381 /1000] [expr $cmy * 423 /1000] [expr $cmx * 384 /1000] [expr $cmy * 426 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 384 /1000] [expr $cmy * 426 /1000] [expr $cmx * 387 /1000] [expr $cmy * 429 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 387 /1000] [expr $cmy * 429 /1000] [expr $cmx * 389 /1000] [expr $cmy * 431 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 389 /1000] [expr $cmy * 431 /1000] [expr $cmx * 392 /1000] [expr $cmy * 434 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 392 /1000] [expr $cmy * 434 /1000] [expr $cmx * 394 /1000] [expr $cmy * 437 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 394 /1000] [expr $cmy * 437 /1000] [expr $cmx * 397 /1000] [expr $cmy * 440 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 397 /1000] [expr $cmy * 440 /1000] [expr $cmx * 400 /1000] [expr $cmy * 443 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 400 /1000] [expr $cmy * 443 /1000] [expr $cmx * 402 /1000] [expr $cmy * 446 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 402 /1000] [expr $cmy * 446 /1000] [expr $cmx * 405 /1000] [expr $cmy * 449 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 405 /1000] [expr $cmy * 449 /1000] [expr $cmx * 407 /1000] [expr $cmy * 452 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 407 /1000] [expr $cmy * 452 /1000] [expr $cmx * 410 /1000] [expr $cmy * 454 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 410 /1000] [expr $cmy * 454 /1000] [expr $cmx * 413 /1000] [expr $cmy * 457 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 413 /1000] [expr $cmy * 457 /1000] [expr $cmx * 415 /1000] [expr $cmy * 460 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 415 /1000] [expr $cmy * 460 /1000] [expr $cmx * 418 /1000] [expr $cmy * 463 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 418 /1000] [expr $cmy * 463 /1000] [expr $cmx * 420 /1000] [expr $cmy * 466 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 420 /1000] [expr $cmy * 466 /1000] [expr $cmx * 423 /1000] [expr $cmy * 469 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 423 /1000] [expr $cmy * 469 /1000] [expr $cmx * 426 /1000] [expr $cmy * 472 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 426 /1000] [expr $cmy * 472 /1000] [expr $cmx * 428 /1000] [expr $cmy * 475 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 428 /1000] [expr $cmy * 475 /1000] [expr $cmx * 431 /1000] [expr $cmy * 478 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 431 /1000] [expr $cmy * 478 /1000] [expr $cmx * 433 /1000] [expr $cmy * 480 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 433 /1000] [expr $cmy * 480 /1000] [expr $cmx * 436 /1000] [expr $cmy * 483 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 436 /1000] [expr $cmy * 483 /1000] [expr $cmx * 438 /1000] [expr $cmy * 486 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 438 /1000] [expr $cmy * 486 /1000] [expr $cmx * 441 /1000] [expr $cmy * 489 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 441 /1000] [expr $cmy * 489 /1000] [expr $cmx * 444 /1000] [expr $cmy * 492 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 444 /1000] [expr $cmy * 492 /1000] [expr $cmx * 446 /1000] [expr $cmy * 495 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 446 /1000] [expr $cmy * 495 /1000] [expr $cmx * 449 /1000] [expr $cmy * 498 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 449 /1000] [expr $cmy * 498 /1000] [expr $cmx * 451 /1000] [expr $cmy * 501 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 451 /1000] [expr $cmy * 501 /1000] [expr $cmx * 454 /1000] [expr $cmy * 504 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 454 /1000] [expr $cmy * 504 /1000] [expr $cmx * 457 /1000] [expr $cmy * 506 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 457 /1000] [expr $cmy * 506 /1000] [expr $cmx * 459 /1000] [expr $cmy * 509 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 459 /1000] [expr $cmy * 509 /1000] [expr $cmx * 462 /1000] [expr $cmy * 512 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 462 /1000] [expr $cmy * 512 /1000] [expr $cmx * 464 /1000] [expr $cmy * 515 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 464 /1000] [expr $cmy * 515 /1000] [expr $cmx * 467 /1000] [expr $cmy * 518 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 467 /1000] [expr $cmy * 518 /1000] [expr $cmx * 470 /1000] [expr $cmy * 521 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 470 /1000] [expr $cmy * 521 /1000] [expr $cmx * 472 /1000] [expr $cmy * 524 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 472 /1000] [expr $cmy * 524 /1000] [expr $cmx * 475 /1000] [expr $cmy * 527 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 475 /1000] [expr $cmy * 527 /1000] [expr $cmx * 477 /1000] [expr $cmy * 529 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 477 /1000] [expr $cmy * 529 /1000] [expr $cmx * 480 /1000] [expr $cmy * 532 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 480 /1000] [expr $cmy * 532 /1000] [expr $cmx * 483 /1000] [expr $cmy * 535 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 483 /1000] [expr $cmy * 535 /1000] [expr $cmx * 485 /1000] [expr $cmy * 538 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 485 /1000] [expr $cmy * 538 /1000] [expr $cmx * 488 /1000] [expr $cmy * 541 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 488 /1000] [expr $cmy * 541 /1000] [expr $cmx * 490 /1000] [expr $cmy * 544 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 490 /1000] [expr $cmy * 544 /1000] [expr $cmx * 493 /1000] [expr $cmy * 547 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 493 /1000] [expr $cmy * 547 /1000] [expr $cmx * 496 /1000] [expr $cmy * 550 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 496 /1000] [expr $cmy * 550 /1000] [expr $cmx * 498 /1000] [expr $cmy * 553 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 498 /1000] [expr $cmy * 553 /1000] [expr $cmx * 501 /1000] [expr $cmy * 555 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 501 /1000] [expr $cmy * 555 /1000] [expr $cmx * 503 /1000] [expr $cmy * 558 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 503 /1000] [expr $cmy * 558 /1000] [expr $cmx * 506 /1000] [expr $cmy * 561 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 506 /1000] [expr $cmy * 561 /1000] [expr $cmx * 509 /1000] [expr $cmy * 564 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 509 /1000] [expr $cmy * 564 /1000] [expr $cmx * 511 /1000] [expr $cmy * 567 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 511 /1000] [expr $cmy * 567 /1000] [expr $cmx * 514 /1000] [expr $cmy * 570 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 514 /1000] [expr $cmy * 570 /1000] [expr $cmx * 516 /1000] [expr $cmy * 573 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 516 /1000] [expr $cmy * 573 /1000] [expr $cmx * 519 /1000] [expr $cmy * 576 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 519 /1000] [expr $cmy * 576 /1000] [expr $cmx * 522 /1000] [expr $cmy * 579 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 522 /1000] [expr $cmy * 579 /1000] [expr $cmx * 524 /1000] [expr $cmy * 581 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 524 /1000] [expr $cmy * 581 /1000] [expr $cmx * 527 /1000] [expr $cmy * 584 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 527 /1000] [expr $cmy * 584 /1000] [expr $cmx * 529 /1000] [expr $cmy * 587 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 529 /1000] [expr $cmy * 587 /1000] [expr $cmx * 532 /1000] [expr $cmy * 590 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 532 /1000] [expr $cmy * 590 /1000] [expr $cmx * 535 /1000] [expr $cmy * 593 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 535 /1000] [expr $cmy * 593 /1000] [expr $cmx * 537 /1000] [expr $cmy * 596 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 537 /1000] [expr $cmy * 596 /1000] [expr $cmx * 540 /1000] [expr $cmy * 599 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 540 /1000] [expr $cmy * 599 /1000] [expr $cmx * 542 /1000] [expr $cmy * 602 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 542 /1000] [expr $cmy * 602 /1000] [expr $cmx * 545 /1000] [expr $cmy * 604 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 545 /1000] [expr $cmy * 604 /1000] [expr $cmx * 548 /1000] [expr $cmy * 607 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 548 /1000] [expr $cmy * 607 /1000] [expr $cmx * 550 /1000] [expr $cmy * 610 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 550 /1000] [expr $cmy * 610 /1000] [expr $cmx * 553 /1000] [expr $cmy * 613 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 553 /1000] [expr $cmy * 613 /1000] [expr $cmx * 555 /1000] [expr $cmy * 616 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 555 /1000] [expr $cmy * 616 /1000] [expr $cmx * 558 /1000] [expr $cmy * 619 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 558 /1000] [expr $cmy * 619 /1000] [expr $cmx * 561 /1000] [expr $cmy * 622 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 561 /1000] [expr $cmy * 622 /1000] [expr $cmx * 563 /1000] [expr $cmy * 625 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 563 /1000] [expr $cmy * 625 /1000] [expr $cmx * 566 /1000] [expr $cmy * 628 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 566 /1000] [expr $cmy * 628 /1000] [expr $cmx * 568 /1000] [expr $cmy * 630 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 568 /1000] [expr $cmy * 630 /1000] [expr $cmx * 571 /1000] [expr $cmy * 633 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 571 /1000] [expr $cmy * 633 /1000] [expr $cmx * 573 /1000] [expr $cmy * 636 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 573 /1000] [expr $cmy * 636 /1000] [expr $cmx * 576 /1000] [expr $cmy * 639 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 576 /1000] [expr $cmy * 639 /1000] [expr $cmx * 579 /1000] [expr $cmy * 642 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 579 /1000] [expr $cmy * 642 /1000] [expr $cmx * 581 /1000] [expr $cmy * 645 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 581 /1000] [expr $cmy * 645 /1000] [expr $cmx * 584 /1000] [expr $cmy * 648 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 584 /1000] [expr $cmy * 648 /1000] [expr $cmx * 586 /1000] [expr $cmy * 651 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 586 /1000] [expr $cmy * 651 /1000] [expr $cmx * 589 /1000] [expr $cmy * 654 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 589 /1000] [expr $cmy * 654 /1000] [expr $cmx * 592 /1000] [expr $cmy * 656 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 592 /1000] [expr $cmy * 656 /1000] [expr $cmx * 594 /1000] [expr $cmy * 659 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 594 /1000] [expr $cmy * 659 /1000] [expr $cmx * 597 /1000] [expr $cmy * 662 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 597 /1000] [expr $cmy * 662 /1000] [expr $cmx * 599 /1000] [expr $cmy * 665 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 599 /1000] [expr $cmy * 665 /1000] [expr $cmx * 602 /1000] [expr $cmy * 668 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 602 /1000] [expr $cmy * 668 /1000] [expr $cmx * 605 /1000] [expr $cmy * 671 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 605 /1000] [expr $cmy * 671 /1000] [expr $cmx * 607 /1000] [expr $cmy * 674 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 607 /1000] [expr $cmy * 674 /1000] [expr $cmx * 610 /1000] [expr $cmy * 677 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 610 /1000] [expr $cmy * 677 /1000] [expr $cmx * 612 /1000] [expr $cmy * 679 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 612 /1000] [expr $cmy * 679 /1000] [expr $cmx * 615 /1000] [expr $cmy * 682 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 615 /1000] [expr $cmy * 682 /1000] [expr $cmx * 618 /1000] [expr $cmy * 685 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 618 /1000] [expr $cmy * 685 /1000] [expr $cmx * 620 /1000] [expr $cmy * 688 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 620 /1000] [expr $cmy * 688 /1000] [expr $cmx * 623 /1000] [expr $cmy * 691 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 623 /1000] [expr $cmy * 691 /1000] [expr $cmx * 625 /1000] [expr $cmy * 694 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 625 /1000] [expr $cmy * 694 /1000] [expr $cmx * 628 /1000] [expr $cmy * 697 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 594 /1000] [expr $cmy * 67 /1000] [expr $cmx * 596 /1000] [expr $cmy * 80 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 596 /1000] [expr $cmy * 80 /1000] [expr $cmx * 599 /1000] [expr $cmy * 93 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 599 /1000] [expr $cmy * 93 /1000] [expr $cmx * 601 /1000] [expr $cmy * 106 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 601 /1000] [expr $cmy * 106 /1000] [expr $cmx * 604 /1000] [expr $cmy * 119 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 604 /1000] [expr $cmy * 119 /1000] [expr $cmx * 607 /1000] [expr $cmy * 131 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 607 /1000] [expr $cmy * 131 /1000] [expr $cmx * 609 /1000] [expr $cmy * 144 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 609 /1000] [expr $cmy * 144 /1000] [expr $cmx * 612 /1000] [expr $cmy * 156 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 612 /1000] [expr $cmy * 156 /1000] [expr $cmx * 614 /1000] [expr $cmy * 168 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 614 /1000] [expr $cmy * 168 /1000] [expr $cmx * 617 /1000] [expr $cmy * 179 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 617 /1000] [expr $cmy * 179 /1000] [expr $cmx * 620 /1000] [expr $cmy * 191 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 620 /1000] [expr $cmy * 191 /1000] [expr $cmx * 622 /1000] [expr $cmy * 202 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 622 /1000] [expr $cmy * 202 /1000] [expr $cmx * 625 /1000] [expr $cmy * 213 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 625 /1000] [expr $cmy * 213 /1000] [expr $cmx * 627 /1000] [expr $cmy * 224 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 627 /1000] [expr $cmy * 224 /1000] [expr $cmx * 630 /1000] [expr $cmy * 234 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 630 /1000] [expr $cmy * 234 /1000] [expr $cmx * 633 /1000] [expr $cmy * 245 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 633 /1000] [expr $cmy * 245 /1000] [expr $cmx * 635 /1000] [expr $cmy * 255 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 635 /1000] [expr $cmy * 255 /1000] [expr $cmx * 638 /1000] [expr $cmy * 265 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 638 /1000] [expr $cmy * 265 /1000] [expr $cmx * 640 /1000] [expr $cmy * 275 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 640 /1000] [expr $cmy * 275 /1000] [expr $cmx * 643 /1000] [expr $cmy * 284 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 643 /1000] [expr $cmy * 284 /1000] [expr $cmx * 645 /1000] [expr $cmy * 293 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 645 /1000] [expr $cmy * 293 /1000] [expr $cmx * 648 /1000] [expr $cmy * 303 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 648 /1000] [expr $cmy * 303 /1000] [expr $cmx * 651 /1000] [expr $cmy * 311 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 651 /1000] [expr $cmy * 311 /1000] [expr $cmx * 653 /1000] [expr $cmy * 320 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 653 /1000] [expr $cmy * 320 /1000] [expr $cmx * 656 /1000] [expr $cmy * 328 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 656 /1000] [expr $cmy * 328 /1000] [expr $cmx * 658 /1000] [expr $cmy * 337 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 658 /1000] [expr $cmy * 337 /1000] [expr $cmx * 661 /1000] [expr $cmy * 345 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 661 /1000] [expr $cmy * 345 /1000] [expr $cmx * 664 /1000] [expr $cmy * 353 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 664 /1000] [expr $cmy * 353 /1000] [expr $cmx * 666 /1000] [expr $cmy * 360 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 666 /1000] [expr $cmy * 360 /1000] [expr $cmx * 669 /1000] [expr $cmy * 367 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 669 /1000] [expr $cmy * 367 /1000] [expr $cmx * 671 /1000] [expr $cmy * 375 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 671 /1000] [expr $cmy * 375 /1000] [expr $cmx * 674 /1000] [expr $cmy * 382 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 674 /1000] [expr $cmy * 382 /1000] [expr $cmx * 677 /1000] [expr $cmy * 388 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 677 /1000] [expr $cmy * 388 /1000] [expr $cmx * 679 /1000] [expr $cmy * 395 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 679 /1000] [expr $cmy * 395 /1000] [expr $cmx * 682 /1000] [expr $cmy * 401 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 682 /1000] [expr $cmy * 401 /1000] [expr $cmx * 684 /1000] [expr $cmy * 407 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 684 /1000] [expr $cmy * 407 /1000] [expr $cmx * 687 /1000] [expr $cmy * 413 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 687 /1000] [expr $cmy * 413 /1000] [expr $cmx * 690 /1000] [expr $cmy * 419 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 690 /1000] [expr $cmy * 419 /1000] [expr $cmx * 692 /1000] [expr $cmy * 424 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 692 /1000] [expr $cmy * 424 /1000] [expr $cmx * 695 /1000] [expr $cmy * 429 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 695 /1000] [expr $cmy * 429 /1000] [expr $cmx * 697 /1000] [expr $cmy * 435 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 697 /1000] [expr $cmy * 435 /1000] [expr $cmx * 700 /1000] [expr $cmy * 439 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 700 /1000] [expr $cmy * 439 /1000] [expr $cmx * 703 /1000] [expr $cmy * 444 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 703 /1000] [expr $cmy * 444 /1000] [expr $cmx * 705 /1000] [expr $cmy * 448 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 705 /1000] [expr $cmy * 448 /1000] [expr $cmx * 708 /1000] [expr $cmy * 452 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 708 /1000] [expr $cmy * 452 /1000] [expr $cmx * 710 /1000] [expr $cmy * 456 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 710 /1000] [expr $cmy * 456 /1000] [expr $cmx * 713 /1000] [expr $cmy * 460 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 713 /1000] [expr $cmy * 460 /1000] [expr $cmx * 716 /1000] [expr $cmy * 464 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 716 /1000] [expr $cmy * 464 /1000] [expr $cmx * 718 /1000] [expr $cmy * 467 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 718 /1000] [expr $cmy * 467 /1000] [expr $cmx * 721 /1000] [expr $cmy * 470 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 721 /1000] [expr $cmy * 470 /1000] [expr $cmx * 723 /1000] [expr $cmy * 473 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 723 /1000] [expr $cmy * 473 /1000] [expr $cmx * 726 /1000] [expr $cmy * 476 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 726 /1000] [expr $cmy * 476 /1000] [expr $cmx * 729 /1000] [expr $cmy * 478 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 729 /1000] [expr $cmy * 478 /1000] [expr $cmx * 731 /1000] [expr $cmy * 480 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 731 /1000] [expr $cmy * 480 /1000] [expr $cmx * 734 /1000] [expr $cmy * 482 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 734 /1000] [expr $cmy * 482 /1000] [expr $cmx * 736 /1000] [expr $cmy * 484 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 736 /1000] [expr $cmy * 484 /1000] [expr $cmx * 739 /1000] [expr $cmy * 486 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 739 /1000] [expr $cmy * 486 /1000] [expr $cmx * 742 /1000] [expr $cmy * 487 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 742 /1000] [expr $cmy * 487 /1000] [expr $cmx * 744 /1000] [expr $cmy * 488 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 744 /1000] [expr $cmy * 488 /1000] [expr $cmx * 747 /1000] [expr $cmy * 489 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 747 /1000] [expr $cmy * 489 /1000] [expr $cmx * 749 /1000] [expr $cmy * 490 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 749 /1000] [expr $cmy * 490 /1000] [expr $cmx * 752 /1000] [expr $cmy * 491 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 752 /1000] [expr $cmy * 491 /1000] [expr $cmx * 755 /1000] [expr $cmy * 491 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 755 /1000] [expr $cmy * 491 /1000] [expr $cmx * 757 /1000] [expr $cmy * 491 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 757 /1000] [expr $cmy * 491 /1000] [expr $cmx * 760 /1000] [expr $cmy * 491 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 760 /1000] [expr $cmy * 491 /1000] [expr $cmx * 762 /1000] [expr $cmy * 491 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 762 /1000] [expr $cmy * 491 /1000] [expr $cmx * 765 /1000] [expr $cmy * 490 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 765 /1000] [expr $cmy * 490 /1000] [expr $cmx * 767 /1000] [expr $cmy * 489 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 767 /1000] [expr $cmy * 489 /1000] [expr $cmx * 770 /1000] [expr $cmy * 488 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 770 /1000] [expr $cmy * 488 /1000] [expr $cmx * 773 /1000] [expr $cmy * 487 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 773 /1000] [expr $cmy * 487 /1000] [expr $cmx * 775 /1000] [expr $cmy * 486 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 775 /1000] [expr $cmy * 486 /1000] [expr $cmx * 778 /1000] [expr $cmy * 484 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 778 /1000] [expr $cmy * 484 /1000] [expr $cmx * 780 /1000] [expr $cmy * 482 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 780 /1000] [expr $cmy * 482 /1000] [expr $cmx * 783 /1000] [expr $cmy * 480 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 783 /1000] [expr $cmy * 480 /1000] [expr $cmx * 786 /1000] [expr $cmy * 478 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 786 /1000] [expr $cmy * 478 /1000] [expr $cmx * 788 /1000] [expr $cmy * 476 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 788 /1000] [expr $cmy * 476 /1000] [expr $cmx * 791 /1000] [expr $cmy * 473 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 791 /1000] [expr $cmy * 473 /1000] [expr $cmx * 793 /1000] [expr $cmy * 470 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 793 /1000] [expr $cmy * 470 /1000] [expr $cmx * 796 /1000] [expr $cmy * 467 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 796 /1000] [expr $cmy * 467 /1000] [expr $cmx * 799 /1000] [expr $cmy * 464 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 799 /1000] [expr $cmy * 464 /1000] [expr $cmx * 801 /1000] [expr $cmy * 460 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 801 /1000] [expr $cmy * 460 /1000] [expr $cmx * 804 /1000] [expr $cmy * 456 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 804 /1000] [expr $cmy * 456 /1000] [expr $cmx * 806 /1000] [expr $cmy * 452 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 806 /1000] [expr $cmy * 452 /1000] [expr $cmx * 809 /1000] [expr $cmy * 448 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 809 /1000] [expr $cmy * 448 /1000] [expr $cmx * 812 /1000] [expr $cmy * 444 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 812 /1000] [expr $cmy * 444 /1000] [expr $cmx * 814 /1000] [expr $cmy * 439 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 814 /1000] [expr $cmy * 439 /1000] [expr $cmx * 817 /1000] [expr $cmy * 434 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 817 /1000] [expr $cmy * 434 /1000] [expr $cmx * 819 /1000] [expr $cmy * 429 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 819 /1000] [expr $cmy * 429 /1000] [expr $cmx * 822 /1000] [expr $cmy * 424 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 822 /1000] [expr $cmy * 424 /1000] [expr $cmx * 825 /1000] [expr $cmy * 419 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 825 /1000] [expr $cmy * 419 /1000] [expr $cmx * 827 /1000] [expr $cmy * 413 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 827 /1000] [expr $cmy * 413 /1000] [expr $cmx * 830 /1000] [expr $cmy * 407 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 830 /1000] [expr $cmy * 407 /1000] [expr $cmx * 832 /1000] [expr $cmy * 401 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 832 /1000] [expr $cmy * 401 /1000] [expr $cmx * 835 /1000] [expr $cmy * 395 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 835 /1000] [expr $cmy * 395 /1000] [expr $cmx * 838 /1000] [expr $cmy * 388 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 838 /1000] [expr $cmy * 388 /1000] [expr $cmx * 840 /1000] [expr $cmy * 381 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 840 /1000] [expr $cmy * 381 /1000] [expr $cmx * 843 /1000] [expr $cmy * 374 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 843 /1000] [expr $cmy * 374 /1000] [expr $cmx * 845 /1000] [expr $cmy * 367 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 845 /1000] [expr $cmy * 367 /1000] [expr $cmx * 848 /1000] [expr $cmy * 360 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 848 /1000] [expr $cmy * 360 /1000] [expr $cmx * 851 /1000] [expr $cmy * 352 /1000] -fill red -width 1.000000 -capstyle round
eval $can create text [expr $cmx * 836 /1000] [expr $cmy * 119 /1000] -text \{   1e+04\} -fill blue -anchor e [expr [info exists font]?"-font \$font":{}]
$can create line [expr $cmx * 852 /1000] [expr $cmy * 119 /1000] [expr $cmx * 934 /1000] [expr $cmy * 119 /1000] -fill blue -width 1.000000 -capstyle round
eval $can create text [expr $cmx * 836 /1000] [expr $cmy * 144 /1000] -text \{ 9.5e+03\} -fill green -anchor e [expr [info exists font]?"-font \$font":{}]
$can create line [expr $cmx * 852 /1000] [expr $cmy * 144 /1000] [expr $cmx * 934 /1000] [expr $cmy * 144 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 844 /1000] [expr $cmy * 738 /1000] [expr $cmx * 845 /1000] [expr $cmy * 746 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 845 /1000] [expr $cmy * 746 /1000] [expr $cmx * 845 /1000] [expr $cmy * 747 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 399 /1000] [expr $cmy * 903 /1000] [expr $cmx * 409 /1000] [expr $cmy * 907 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 409 /1000] [expr $cmy * 907 /1000] [expr $cmx * 411 /1000] [expr $cmy * 908 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 588 /1000] [expr $cmy * 462 /1000] [expr $cmx * 590 /1000] [expr $cmy * 463 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 590 /1000] [expr $cmy * 463 /1000] [expr $cmx * 600 /1000] [expr $cmy * 467 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 154 /1000] [expr $cmy * 623 /1000] [expr $cmx * 154 /1000] [expr $cmy * 624 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 154 /1000] [expr $cmy * 624 /1000] [expr $cmx * 155 /1000] [expr $cmy * 632 /1000] -fill green -width 1.000000 -capstyle round
eval $can create text [expr $cmx * 836 /1000] [expr $cmy * 169 /1000] -text \{   9e+03\} -fill brown -anchor e [expr [info exists font]?"-font \$font":{}]
$can create line [expr $cmx * 852 /1000] [expr $cmy * 169 /1000] [expr $cmx * 934 /1000] [expr $cmy * 169 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 838 /1000] [expr $cmy * 731 /1000] [expr $cmx * 838 /1000] [expr $cmy * 738 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 838 /1000] [expr $cmy * 738 /1000] [expr $cmx * 839 /1000] [expr $cmy * 745 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 839 /1000] [expr $cmy * 745 /1000] [expr $cmx * 839 /1000] [expr $cmy * 750 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 393 /1000] [expr $cmy * 896 /1000] [expr $cmx * 402 /1000] [expr $cmy * 900 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 402 /1000] [expr $cmy * 900 /1000] [expr $cmx * 412 /1000] [expr $cmy * 904 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 412 /1000] [expr $cmy * 904 /1000] [expr $cmx * 417 /1000] [expr $cmy * 906 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 582 /1000] [expr $cmy * 464 /1000] [expr $cmx * 587 /1000] [expr $cmy * 466 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 587 /1000] [expr $cmy * 466 /1000] [expr $cmx * 597 /1000] [expr $cmy * 470 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 597 /1000] [expr $cmy * 470 /1000] [expr $cmx * 606 /1000] [expr $cmy * 474 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 160 /1000] [expr $cmy * 620 /1000] [expr $cmx * 160 /1000] [expr $cmy * 625 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 160 /1000] [expr $cmy * 625 /1000] [expr $cmx * 161 /1000] [expr $cmy * 632 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 161 /1000] [expr $cmy * 632 /1000] [expr $cmx * 161 /1000] [expr $cmy * 639 /1000] -fill brown -width 1.000000 -capstyle round
eval $can create text [expr $cmx * 836 /1000] [expr $cmy * 194 /1000] -text \{ 8.5e+03\} -fill magenta -anchor e [expr [info exists font]?"-font \$font":{}]
$can create line [expr $cmx * 852 /1000] [expr $cmy * 194 /1000] [expr $cmx * 934 /1000] [expr $cmy * 194 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 831 /1000] [expr $cmy * 724 /1000] [expr $cmx * 831 /1000] [expr $cmy * 731 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 831 /1000] [expr $cmy * 731 /1000] [expr $cmx * 832 /1000] [expr $cmy * 738 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 832 /1000] [expr $cmy * 738 /1000] [expr $cmx * 832 /1000] [expr $cmy * 745 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 832 /1000] [expr $cmy * 745 /1000] [expr $cmx * 833 /1000] [expr $cmy * 752 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 386 /1000] [expr $cmy * 889 /1000] [expr $cmx * 395 /1000] [expr $cmy * 892 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 395 /1000] [expr $cmy * 892 /1000] [expr $cmx * 405 /1000] [expr $cmy * 896 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 405 /1000] [expr $cmy * 896 /1000] [expr $cmx * 414 /1000] [expr $cmy * 900 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 414 /1000] [expr $cmy * 900 /1000] [expr $cmx * 423 /1000] [expr $cmy * 904 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 576 /1000] [expr $cmy * 466 /1000] [expr $cmx * 585 /1000] [expr $cmy * 470 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 585 /1000] [expr $cmy * 470 /1000] [expr $cmx * 594 /1000] [expr $cmy * 474 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 594 /1000] [expr $cmy * 474 /1000] [expr $cmx * 604 /1000] [expr $cmy * 478 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 604 /1000] [expr $cmy * 478 /1000] [expr $cmx * 613 /1000] [expr $cmy * 481 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 166 /1000] [expr $cmy * 618 /1000] [expr $cmx * 167 /1000] [expr $cmy * 625 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 167 /1000] [expr $cmy * 625 /1000] [expr $cmx * 167 /1000] [expr $cmy * 632 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 167 /1000] [expr $cmy * 632 /1000] [expr $cmx * 168 /1000] [expr $cmy * 639 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 168 /1000] [expr $cmy * 639 /1000] [expr $cmx * 168 /1000] [expr $cmy * 646 /1000] -fill magenta -width 1.000000 -capstyle round
eval $can create text [expr $cmx * 836 /1000] [expr $cmy * 219 /1000] -text \{   8e+03\} -fill cyan -anchor e [expr [info exists font]?"-font \$font":{}]
$can create line [expr $cmx * 852 /1000] [expr $cmy * 219 /1000] [expr $cmx * 934 /1000] [expr $cmy * 219 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 825 /1000] [expr $cmy * 717 /1000] [expr $cmx * 825 /1000] [expr $cmy * 723 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 825 /1000] [expr $cmy * 723 /1000] [expr $cmx * 825 /1000] [expr $cmy * 730 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 825 /1000] [expr $cmy * 730 /1000] [expr $cmx * 825 /1000] [expr $cmy * 737 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 825 /1000] [expr $cmy * 737 /1000] [expr $cmx * 826 /1000] [expr $cmy * 744 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 826 /1000] [expr $cmy * 744 /1000] [expr $cmx * 827 /1000] [expr $cmy * 752 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 827 /1000] [expr $cmy * 752 /1000] [expr $cmx * 827 /1000] [expr $cmy * 754 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 380 /1000] [expr $cmy * 882 /1000] [expr $cmx * 389 /1000] [expr $cmy * 885 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 389 /1000] [expr $cmy * 885 /1000] [expr $cmx * 398 /1000] [expr $cmy * 888 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 398 /1000] [expr $cmy * 888 /1000] [expr $cmx * 407 /1000] [expr $cmy * 892 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 407 /1000] [expr $cmy * 892 /1000] [expr $cmx * 417 /1000] [expr $cmy * 896 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 417 /1000] [expr $cmy * 896 /1000] [expr $cmx * 427 /1000] [expr $cmy * 900 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 427 /1000] [expr $cmy * 900 /1000] [expr $cmx * 429 /1000] [expr $cmy * 902 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 570 /1000] [expr $cmy * 468 /1000] [expr $cmx * 572 /1000] [expr $cmy * 470 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 572 /1000] [expr $cmy * 470 /1000] [expr $cmx * 582 /1000] [expr $cmy * 474 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 582 /1000] [expr $cmy * 474 /1000] [expr $cmx * 592 /1000] [expr $cmy * 478 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 592 /1000] [expr $cmy * 478 /1000] [expr $cmx * 601 /1000] [expr $cmy * 482 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 601 /1000] [expr $cmy * 482 /1000] [expr $cmx * 610 /1000] [expr $cmy * 485 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 610 /1000] [expr $cmy * 485 /1000] [expr $cmx * 619 /1000] [expr $cmy * 488 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 172 /1000] [expr $cmy * 616 /1000] [expr $cmx * 172 /1000] [expr $cmy * 618 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 172 /1000] [expr $cmy * 618 /1000] [expr $cmx * 173 /1000] [expr $cmy * 626 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 173 /1000] [expr $cmy * 626 /1000] [expr $cmx * 174 /1000] [expr $cmy * 633 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 174 /1000] [expr $cmy * 633 /1000] [expr $cmx * 174 /1000] [expr $cmy * 640 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 174 /1000] [expr $cmy * 640 /1000] [expr $cmx * 174 /1000] [expr $cmy * 647 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 174 /1000] [expr $cmy * 647 /1000] [expr $cmx * 174 /1000] [expr $cmy * 653 /1000] -fill cyan -width 1.000000 -capstyle round
eval $can create text [expr $cmx * 836 /1000] [expr $cmy * 244 /1000] -text \{ 7.5e+03\} -fill black -anchor e [expr [info exists font]?"-font \$font":{}]
$can create line [expr $cmx * 852 /1000] [expr $cmy * 244 /1000] [expr $cmx * 934 /1000] [expr $cmy * 244 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 818 /1000] [expr $cmy * 710 /1000] [expr $cmx * 818 /1000] [expr $cmy * 716 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 818 /1000] [expr $cmy * 716 /1000] [expr $cmx * 818 /1000] [expr $cmy * 722 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 818 /1000] [expr $cmy * 722 /1000] [expr $cmx * 818 /1000] [expr $cmy * 729 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 818 /1000] [expr $cmy * 729 /1000] [expr $cmx * 818 /1000] [expr $cmy * 736 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 818 /1000] [expr $cmy * 736 /1000] [expr $cmx * 819 /1000] [expr $cmy * 743 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 819 /1000] [expr $cmy * 743 /1000] [expr $cmx * 820 /1000] [expr $cmy * 751 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 820 /1000] [expr $cmy * 751 /1000] [expr $cmx * 821 /1000] [expr $cmy * 756 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 373 /1000] [expr $cmy * 875 /1000] [expr $cmx * 382 /1000] [expr $cmy * 877 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 382 /1000] [expr $cmy * 877 /1000] [expr $cmx * 391 /1000] [expr $cmy * 880 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 391 /1000] [expr $cmy * 880 /1000] [expr $cmx * 400 /1000] [expr $cmy * 884 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 400 /1000] [expr $cmy * 884 /1000] [expr $cmx * 409 /1000] [expr $cmy * 888 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 409 /1000] [expr $cmy * 888 /1000] [expr $cmx * 419 /1000] [expr $cmy * 892 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 419 /1000] [expr $cmy * 892 /1000] [expr $cmx * 429 /1000] [expr $cmy * 896 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 429 /1000] [expr $cmy * 896 /1000] [expr $cmx * 435 /1000] [expr $cmy * 899 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 564 /1000] [expr $cmy * 471 /1000] [expr $cmx * 570 /1000] [expr $cmy * 474 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 570 /1000] [expr $cmy * 474 /1000] [expr $cmx * 580 /1000] [expr $cmy * 478 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 580 /1000] [expr $cmy * 478 /1000] [expr $cmx * 590 /1000] [expr $cmy * 482 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 590 /1000] [expr $cmy * 482 /1000] [expr $cmx * 599 /1000] [expr $cmy * 486 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 599 /1000] [expr $cmy * 486 /1000] [expr $cmx * 608 /1000] [expr $cmy * 490 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 608 /1000] [expr $cmy * 490 /1000] [expr $cmx * 617 /1000] [expr $cmy * 493 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 617 /1000] [expr $cmy * 493 /1000] [expr $cmx * 626 /1000] [expr $cmy * 495 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 178 /1000] [expr $cmy * 614 /1000] [expr $cmx * 179 /1000] [expr $cmy * 619 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 179 /1000] [expr $cmy * 619 /1000] [expr $cmx * 180 /1000] [expr $cmy * 627 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 180 /1000] [expr $cmy * 627 /1000] [expr $cmx * 181 /1000] [expr $cmy * 634 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 181 /1000] [expr $cmy * 634 /1000] [expr $cmx * 181 /1000] [expr $cmy * 641 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 181 /1000] [expr $cmy * 641 /1000] [expr $cmx * 181 /1000] [expr $cmy * 648 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 181 /1000] [expr $cmy * 648 /1000] [expr $cmx * 181 /1000] [expr $cmy * 654 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 181 /1000] [expr $cmy * 654 /1000] [expr $cmx * 181 /1000] [expr $cmy * 660 /1000] -fill black -width 1.000000 -capstyle round
eval $can create text [expr $cmx * 836 /1000] [expr $cmy * 269 /1000] -text \{   7e+03\} -fill gray -anchor e [expr [info exists font]?"-font \$font":{}]
$can create line [expr $cmx * 852 /1000] [expr $cmy * 269 /1000] [expr $cmx * 934 /1000] [expr $cmy * 269 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 812 /1000] [expr $cmy * 703 /1000] [expr $cmx * 811 /1000] [expr $cmy * 708 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 811 /1000] [expr $cmy * 708 /1000] [expr $cmx * 811 /1000] [expr $cmy * 714 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 811 /1000] [expr $cmy * 714 /1000] [expr $cmx * 811 /1000] [expr $cmy * 721 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 811 /1000] [expr $cmy * 721 /1000] [expr $cmx * 811 /1000] [expr $cmy * 728 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 811 /1000] [expr $cmy * 728 /1000] [expr $cmx * 811 /1000] [expr $cmy * 735 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 811 /1000] [expr $cmy * 735 /1000] [expr $cmx * 812 /1000] [expr $cmy * 742 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 812 /1000] [expr $cmy * 742 /1000] [expr $cmx * 813 /1000] [expr $cmy * 750 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 813 /1000] [expr $cmy * 750 /1000] [expr $cmx * 814 /1000] [expr $cmy * 758 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 814 /1000] [expr $cmy * 758 /1000] [expr $cmx * 814 /1000] [expr $cmy * 759 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 367 /1000] [expr $cmy * 867 /1000] [expr $cmx * 375 /1000] [expr $cmy * 870 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 375 /1000] [expr $cmy * 870 /1000] [expr $cmx * 384 /1000] [expr $cmy * 873 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 384 /1000] [expr $cmy * 873 /1000] [expr $cmx * 392 /1000] [expr $cmy * 876 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 392 /1000] [expr $cmy * 876 /1000] [expr $cmx * 401 /1000] [expr $cmy * 879 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 401 /1000] [expr $cmy * 879 /1000] [expr $cmx * 411 /1000] [expr $cmy * 883 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 411 /1000] [expr $cmy * 883 /1000] [expr $cmx * 420 /1000] [expr $cmy * 887 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 420 /1000] [expr $cmy * 887 /1000] [expr $cmx * 430 /1000] [expr $cmy * 891 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 430 /1000] [expr $cmy * 891 /1000] [expr $cmx * 441 /1000] [expr $cmy * 896 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 441 /1000] [expr $cmy * 896 /1000] [expr $cmx * 442 /1000] [expr $cmy * 897 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 557 /1000] [expr $cmy * 473 /1000] [expr $cmx * 558 /1000] [expr $cmy * 474 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 558 /1000] [expr $cmy * 474 /1000] [expr $cmx * 569 /1000] [expr $cmy * 479 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 569 /1000] [expr $cmy * 479 /1000] [expr $cmx * 579 /1000] [expr $cmy * 483 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 579 /1000] [expr $cmy * 483 /1000] [expr $cmx * 588 /1000] [expr $cmy * 487 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 588 /1000] [expr $cmy * 487 /1000] [expr $cmx * 598 /1000] [expr $cmy * 491 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 598 /1000] [expr $cmy * 491 /1000] [expr $cmx * 607 /1000] [expr $cmy * 494 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 607 /1000] [expr $cmy * 494 /1000] [expr $cmx * 615 /1000] [expr $cmy * 497 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 615 /1000] [expr $cmy * 497 /1000] [expr $cmx * 624 /1000] [expr $cmy * 500 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 624 /1000] [expr $cmy * 500 /1000] [expr $cmx * 632 /1000] [expr $cmy * 503 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 185 /1000] [expr $cmy * 611 /1000] [expr $cmx * 185 /1000] [expr $cmy * 612 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 185 /1000] [expr $cmy * 612 /1000] [expr $cmx * 186 /1000] [expr $cmy * 620 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 186 /1000] [expr $cmy * 620 /1000] [expr $cmx * 187 /1000] [expr $cmy * 628 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 187 /1000] [expr $cmy * 628 /1000] [expr $cmx * 188 /1000] [expr $cmy * 635 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 188 /1000] [expr $cmy * 635 /1000] [expr $cmx * 188 /1000] [expr $cmy * 642 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 188 /1000] [expr $cmy * 642 /1000] [expr $cmx * 188 /1000] [expr $cmy * 649 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 188 /1000] [expr $cmy * 649 /1000] [expr $cmx * 188 /1000] [expr $cmy * 656 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 188 /1000] [expr $cmy * 656 /1000] [expr $cmx * 188 /1000] [expr $cmy * 662 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 188 /1000] [expr $cmy * 662 /1000] [expr $cmx * 187 /1000] [expr $cmy * 667 /1000] -fill gray -width 1.000000 -capstyle round
eval $can create text [expr $cmx * 836 /1000] [expr $cmy * 294 /1000] -text \{ 6.5e+03\} -fill red -anchor e [expr [info exists font]?"-font \$font":{}]
$can create line [expr $cmx * 852 /1000] [expr $cmy * 294 /1000] [expr $cmx * 934 /1000] [expr $cmy * 294 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 806 /1000] [expr $cmy * 695 /1000] [expr $cmx * 805 /1000] [expr $cmy * 701 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 805 /1000] [expr $cmy * 701 /1000] [expr $cmx * 804 /1000] [expr $cmy * 707 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 804 /1000] [expr $cmy * 707 /1000] [expr $cmx * 803 /1000] [expr $cmy * 713 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 803 /1000] [expr $cmy * 713 /1000] [expr $cmx * 803 /1000] [expr $cmy * 719 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 803 /1000] [expr $cmy * 719 /1000] [expr $cmx * 803 /1000] [expr $cmy * 726 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 803 /1000] [expr $cmy * 726 /1000] [expr $cmx * 803 /1000] [expr $cmy * 733 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 803 /1000] [expr $cmy * 733 /1000] [expr $cmx * 804 /1000] [expr $cmy * 740 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 804 /1000] [expr $cmy * 740 /1000] [expr $cmx * 805 /1000] [expr $cmy * 748 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 805 /1000] [expr $cmy * 748 /1000] [expr $cmx * 806 /1000] [expr $cmy * 756 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 806 /1000] [expr $cmy * 756 /1000] [expr $cmx * 807 /1000] [expr $cmy * 761 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 360 /1000] [expr $cmy * 860 /1000] [expr $cmx * 368 /1000] [expr $cmy * 862 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 368 /1000] [expr $cmy * 862 /1000] [expr $cmx * 377 /1000] [expr $cmy * 865 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 377 /1000] [expr $cmy * 865 /1000] [expr $cmx * 385 /1000] [expr $cmy * 868 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 385 /1000] [expr $cmy * 868 /1000] [expr $cmx * 394 /1000] [expr $cmy * 871 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 394 /1000] [expr $cmy * 871 /1000] [expr $cmx * 403 /1000] [expr $cmy * 874 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 403 /1000] [expr $cmy * 874 /1000] [expr $cmx * 412 /1000] [expr $cmy * 878 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 412 /1000] [expr $cmy * 878 /1000] [expr $cmx * 422 /1000] [expr $cmy * 882 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 422 /1000] [expr $cmy * 882 /1000] [expr $cmx * 432 /1000] [expr $cmy * 886 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 432 /1000] [expr $cmy * 886 /1000] [expr $cmx * 442 /1000] [expr $cmy * 891 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 442 /1000] [expr $cmy * 891 /1000] [expr $cmx * 449 /1000] [expr $cmy * 894 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 550 /1000] [expr $cmy * 476 /1000] [expr $cmx * 557 /1000] [expr $cmy * 479 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 557 /1000] [expr $cmy * 479 /1000] [expr $cmx * 567 /1000] [expr $cmy * 484 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 567 /1000] [expr $cmy * 484 /1000] [expr $cmx * 577 /1000] [expr $cmy * 488 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 577 /1000] [expr $cmy * 488 /1000] [expr $cmx * 587 /1000] [expr $cmy * 492 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 587 /1000] [expr $cmy * 492 /1000] [expr $cmx * 596 /1000] [expr $cmy * 496 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 596 /1000] [expr $cmy * 496 /1000] [expr $cmx * 605 /1000] [expr $cmy * 499 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 605 /1000] [expr $cmy * 499 /1000] [expr $cmx * 614 /1000] [expr $cmy * 502 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 614 /1000] [expr $cmy * 502 /1000] [expr $cmx * 622 /1000] [expr $cmy * 505 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 622 /1000] [expr $cmy * 505 /1000] [expr $cmx * 631 /1000] [expr $cmy * 508 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 631 /1000] [expr $cmy * 508 /1000] [expr $cmx * 639 /1000] [expr $cmy * 510 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 192 /1000] [expr $cmy * 609 /1000] [expr $cmx * 193 /1000] [expr $cmy * 614 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 193 /1000] [expr $cmy * 614 /1000] [expr $cmx * 194 /1000] [expr $cmy * 622 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 194 /1000] [expr $cmy * 622 /1000] [expr $cmx * 195 /1000] [expr $cmy * 630 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 195 /1000] [expr $cmy * 630 /1000] [expr $cmx * 196 /1000] [expr $cmy * 637 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 196 /1000] [expr $cmy * 637 /1000] [expr $cmx * 196 /1000] [expr $cmy * 644 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 196 /1000] [expr $cmy * 644 /1000] [expr $cmx * 196 /1000] [expr $cmy * 651 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 196 /1000] [expr $cmy * 651 /1000] [expr $cmx * 196 /1000] [expr $cmy * 657 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 196 /1000] [expr $cmy * 657 /1000] [expr $cmx * 195 /1000] [expr $cmy * 663 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 195 /1000] [expr $cmy * 663 /1000] [expr $cmx * 194 /1000] [expr $cmy * 669 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 194 /1000] [expr $cmy * 669 /1000] [expr $cmx * 193 /1000] [expr $cmy * 675 /1000] -fill red -width 1.000000 -capstyle round
eval $can create text [expr $cmx * 836 /1000] [expr $cmy * 319 /1000] -text \{   6e+03\} -fill blue -anchor e [expr [info exists font]?"-font \$font":{}]
$can create line [expr $cmx * 852 /1000] [expr $cmy * 319 /1000] [expr $cmx * 934 /1000] [expr $cmy * 319 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 799 /1000] [expr $cmy * 688 /1000] [expr $cmx * 798 /1000] [expr $cmy * 693 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 798 /1000] [expr $cmy * 693 /1000] [expr $cmx * 797 /1000] [expr $cmy * 699 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 797 /1000] [expr $cmy * 699 /1000] [expr $cmx * 796 /1000] [expr $cmy * 705 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 796 /1000] [expr $cmy * 705 /1000] [expr $cmx * 795 /1000] [expr $cmy * 711 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 795 /1000] [expr $cmy * 711 /1000] [expr $cmx * 795 /1000] [expr $cmy * 717 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 795 /1000] [expr $cmy * 717 /1000] [expr $cmx * 795 /1000] [expr $cmy * 723 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 795 /1000] [expr $cmy * 723 /1000] [expr $cmx * 795 /1000] [expr $cmy * 730 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 795 /1000] [expr $cmy * 730 /1000] [expr $cmx * 796 /1000] [expr $cmy * 738 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 796 /1000] [expr $cmy * 738 /1000] [expr $cmx * 797 /1000] [expr $cmy * 746 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 797 /1000] [expr $cmy * 746 /1000] [expr $cmx * 798 /1000] [expr $cmy * 754 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 798 /1000] [expr $cmy * 754 /1000] [expr $cmx * 800 /1000] [expr $cmy * 762 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 800 /1000] [expr $cmy * 762 /1000] [expr $cmx * 800 /1000] [expr $cmy * 764 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 354 /1000] [expr $cmy * 853 /1000] [expr $cmx * 362 /1000] [expr $cmy * 855 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 362 /1000] [expr $cmy * 855 /1000] [expr $cmx * 370 /1000] [expr $cmy * 857 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 370 /1000] [expr $cmy * 857 /1000] [expr $cmx * 378 /1000] [expr $cmy * 860 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 378 /1000] [expr $cmy * 860 /1000] [expr $cmx * 386 /1000] [expr $cmy * 862 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 386 /1000] [expr $cmy * 862 /1000] [expr $cmx * 395 /1000] [expr $cmy * 865 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 395 /1000] [expr $cmy * 865 /1000] [expr $cmx * 404 /1000] [expr $cmy * 868 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 404 /1000] [expr $cmy * 868 /1000] [expr $cmx * 413 /1000] [expr $cmy * 872 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 413 /1000] [expr $cmy * 872 /1000] [expr $cmx * 423 /1000] [expr $cmy * 876 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 423 /1000] [expr $cmy * 876 /1000] [expr $cmx * 433 /1000] [expr $cmy * 880 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 433 /1000] [expr $cmy * 880 /1000] [expr $cmx * 443 /1000] [expr $cmy * 885 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 443 /1000] [expr $cmy * 885 /1000] [expr $cmx * 454 /1000] [expr $cmy * 891 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 454 /1000] [expr $cmy * 891 /1000] [expr $cmx * 456 /1000] [expr $cmy * 892 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 543 /1000] [expr $cmy * 478 /1000] [expr $cmx * 545 /1000] [expr $cmy * 479 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 545 /1000] [expr $cmy * 479 /1000] [expr $cmx * 556 /1000] [expr $cmy * 485 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 556 /1000] [expr $cmy * 485 /1000] [expr $cmx * 566 /1000] [expr $cmy * 490 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 566 /1000] [expr $cmy * 490 /1000] [expr $cmx * 576 /1000] [expr $cmy * 494 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 576 /1000] [expr $cmy * 494 /1000] [expr $cmx * 586 /1000] [expr $cmy * 498 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 586 /1000] [expr $cmy * 498 /1000] [expr $cmx * 595 /1000] [expr $cmy * 502 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 595 /1000] [expr $cmy * 502 /1000] [expr $cmx * 604 /1000] [expr $cmy * 505 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 604 /1000] [expr $cmy * 505 /1000] [expr $cmx * 613 /1000] [expr $cmy * 508 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 613 /1000] [expr $cmy * 508 /1000] [expr $cmx * 621 /1000] [expr $cmy * 510 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 621 /1000] [expr $cmy * 510 /1000] [expr $cmx * 629 /1000] [expr $cmy * 513 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 629 /1000] [expr $cmy * 513 /1000] [expr $cmx * 637 /1000] [expr $cmy * 515 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 637 /1000] [expr $cmy * 515 /1000] [expr $cmx * 645 /1000] [expr $cmy * 517 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 199 /1000] [expr $cmy * 606 /1000] [expr $cmx * 199 /1000] [expr $cmy * 607 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 199 /1000] [expr $cmy * 607 /1000] [expr $cmx * 201 /1000] [expr $cmy * 616 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 201 /1000] [expr $cmy * 616 /1000] [expr $cmx * 202 /1000] [expr $cmy * 624 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 202 /1000] [expr $cmy * 624 /1000] [expr $cmx * 203 /1000] [expr $cmy * 632 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 203 /1000] [expr $cmy * 632 /1000] [expr $cmx * 204 /1000] [expr $cmy * 640 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 204 /1000] [expr $cmy * 640 /1000] [expr $cmx * 204 /1000] [expr $cmy * 647 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 204 /1000] [expr $cmy * 647 /1000] [expr $cmx * 204 /1000] [expr $cmy * 653 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 204 /1000] [expr $cmy * 653 /1000] [expr $cmx * 204 /1000] [expr $cmy * 659 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 204 /1000] [expr $cmy * 659 /1000] [expr $cmx * 203 /1000] [expr $cmy * 665 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 203 /1000] [expr $cmy * 665 /1000] [expr $cmx * 202 /1000] [expr $cmy * 671 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 202 /1000] [expr $cmy * 671 /1000] [expr $cmx * 201 /1000] [expr $cmy * 677 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 201 /1000] [expr $cmy * 677 /1000] [expr $cmx * 200 /1000] [expr $cmy * 682 /1000] -fill blue -width 1.000000 -capstyle round
eval $can create text [expr $cmx * 836 /1000] [expr $cmy * 344 /1000] -text \{ 5.5e+03\} -fill green -anchor e [expr [info exists font]?"-font \$font":{}]
$can create line [expr $cmx * 852 /1000] [expr $cmy * 344 /1000] [expr $cmx * 934 /1000] [expr $cmy * 344 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 793 /1000] [expr $cmy * 681 /1000] [expr $cmx * 791 /1000] [expr $cmy * 686 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 791 /1000] [expr $cmy * 686 /1000] [expr $cmx * 790 /1000] [expr $cmy * 691 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 790 /1000] [expr $cmy * 691 /1000] [expr $cmx * 789 /1000] [expr $cmy * 697 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 789 /1000] [expr $cmy * 697 /1000] [expr $cmx * 788 /1000] [expr $cmy * 702 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 788 /1000] [expr $cmy * 702 /1000] [expr $cmx * 787 /1000] [expr $cmy * 708 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 787 /1000] [expr $cmy * 708 /1000] [expr $cmx * 787 /1000] [expr $cmy * 714 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 787 /1000] [expr $cmy * 714 /1000] [expr $cmx * 786 /1000] [expr $cmy * 721 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 786 /1000] [expr $cmy * 721 /1000] [expr $cmx * 787 /1000] [expr $cmy * 728 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 787 /1000] [expr $cmy * 728 /1000] [expr $cmx * 787 /1000] [expr $cmy * 735 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 787 /1000] [expr $cmy * 735 /1000] [expr $cmx * 788 /1000] [expr $cmy * 743 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 788 /1000] [expr $cmy * 743 /1000] [expr $cmx * 789 /1000] [expr $cmy * 751 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 789 /1000] [expr $cmy * 751 /1000] [expr $cmx * 791 /1000] [expr $cmy * 759 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 791 /1000] [expr $cmy * 759 /1000] [expr $cmx * 793 /1000] [expr $cmy * 767 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 348 /1000] [expr $cmy * 846 /1000] [expr $cmx * 355 /1000] [expr $cmy * 848 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 355 /1000] [expr $cmy * 848 /1000] [expr $cmx * 363 /1000] [expr $cmy * 849 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 363 /1000] [expr $cmy * 849 /1000] [expr $cmx * 371 /1000] [expr $cmy * 851 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 371 /1000] [expr $cmy * 851 /1000] [expr $cmx * 379 /1000] [expr $cmy * 854 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 379 /1000] [expr $cmy * 854 /1000] [expr $cmx * 387 /1000] [expr $cmy * 856 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 387 /1000] [expr $cmy * 856 /1000] [expr $cmx * 395 /1000] [expr $cmy * 859 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 395 /1000] [expr $cmy * 859 /1000] [expr $cmx * 404 /1000] [expr $cmy * 862 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 404 /1000] [expr $cmy * 862 /1000] [expr $cmx * 413 /1000] [expr $cmy * 866 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 413 /1000] [expr $cmy * 866 /1000] [expr $cmx * 423 /1000] [expr $cmy * 870 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 423 /1000] [expr $cmy * 870 /1000] [expr $cmx * 433 /1000] [expr $cmy * 874 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 433 /1000] [expr $cmy * 874 /1000] [expr $cmx * 443 /1000] [expr $cmy * 879 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 443 /1000] [expr $cmy * 879 /1000] [expr $cmx * 454 /1000] [expr $cmy * 884 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 454 /1000] [expr $cmy * 884 /1000] [expr $cmx * 463 /1000] [expr $cmy * 889 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 536 /1000] [expr $cmy * 481 /1000] [expr $cmx * 545 /1000] [expr $cmy * 486 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 545 /1000] [expr $cmy * 486 /1000] [expr $cmx * 556 /1000] [expr $cmy * 491 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 556 /1000] [expr $cmy * 491 /1000] [expr $cmx * 566 /1000] [expr $cmy * 496 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 566 /1000] [expr $cmy * 496 /1000] [expr $cmx * 576 /1000] [expr $cmy * 500 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 576 /1000] [expr $cmy * 500 /1000] [expr $cmx * 586 /1000] [expr $cmy * 504 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 586 /1000] [expr $cmy * 504 /1000] [expr $cmx * 595 /1000] [expr $cmy * 508 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 595 /1000] [expr $cmy * 508 /1000] [expr $cmx * 604 /1000] [expr $cmy * 511 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 604 /1000] [expr $cmy * 511 /1000] [expr $cmx * 612 /1000] [expr $cmy * 514 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 612 /1000] [expr $cmy * 514 /1000] [expr $cmx * 620 /1000] [expr $cmy * 516 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 620 /1000] [expr $cmy * 516 /1000] [expr $cmx * 628 /1000] [expr $cmy * 519 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 628 /1000] [expr $cmy * 519 /1000] [expr $cmx * 636 /1000] [expr $cmy * 521 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 636 /1000] [expr $cmy * 521 /1000] [expr $cmx * 644 /1000] [expr $cmy * 522 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 644 /1000] [expr $cmy * 522 /1000] [expr $cmx * 651 /1000] [expr $cmy * 524 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 206 /1000] [expr $cmy * 603 /1000] [expr $cmx * 208 /1000] [expr $cmy * 611 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 208 /1000] [expr $cmy * 611 /1000] [expr $cmx * 210 /1000] [expr $cmy * 619 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 210 /1000] [expr $cmy * 619 /1000] [expr $cmx * 211 /1000] [expr $cmy * 627 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 211 /1000] [expr $cmy * 627 /1000] [expr $cmx * 212 /1000] [expr $cmy * 635 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 212 /1000] [expr $cmy * 635 /1000] [expr $cmx * 212 /1000] [expr $cmy * 642 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 212 /1000] [expr $cmy * 642 /1000] [expr $cmx * 213 /1000] [expr $cmy * 649 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 213 /1000] [expr $cmy * 649 /1000] [expr $cmx * 212 /1000] [expr $cmy * 656 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 212 /1000] [expr $cmy * 656 /1000] [expr $cmx * 212 /1000] [expr $cmy * 662 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 212 /1000] [expr $cmy * 662 /1000] [expr $cmx * 211 /1000] [expr $cmy * 668 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 211 /1000] [expr $cmy * 668 /1000] [expr $cmx * 210 /1000] [expr $cmy * 673 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 210 /1000] [expr $cmy * 673 /1000] [expr $cmx * 209 /1000] [expr $cmy * 679 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 209 /1000] [expr $cmy * 679 /1000] [expr $cmx * 208 /1000] [expr $cmy * 684 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 208 /1000] [expr $cmy * 684 /1000] [expr $cmx * 206 /1000] [expr $cmy * 689 /1000] -fill green -width 1.000000 -capstyle round
eval $can create text [expr $cmx * 836 /1000] [expr $cmy * 369 /1000] -text \{   5e+03\} -fill brown -anchor e [expr [info exists font]?"-font \$font":{}]
$can create line [expr $cmx * 852 /1000] [expr $cmy * 369 /1000] [expr $cmx * 934 /1000] [expr $cmy * 369 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 786 /1000] [expr $cmy * 674 /1000] [expr $cmx * 784 /1000] [expr $cmy * 679 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 784 /1000] [expr $cmy * 679 /1000] [expr $cmx * 783 /1000] [expr $cmy * 683 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 783 /1000] [expr $cmy * 683 /1000] [expr $cmx * 781 /1000] [expr $cmy * 688 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 781 /1000] [expr $cmy * 688 /1000] [expr $cmx * 780 /1000] [expr $cmy * 694 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 780 /1000] [expr $cmy * 694 /1000] [expr $cmx * 779 /1000] [expr $cmy * 699 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 779 /1000] [expr $cmy * 699 /1000] [expr $cmx * 778 /1000] [expr $cmy * 705 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 778 /1000] [expr $cmy * 705 /1000] [expr $cmx * 778 /1000] [expr $cmy * 711 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 778 /1000] [expr $cmy * 711 /1000] [expr $cmx * 778 /1000] [expr $cmy * 717 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 778 /1000] [expr $cmy * 717 /1000] [expr $cmx * 778 /1000] [expr $cmy * 724 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 778 /1000] [expr $cmy * 724 /1000] [expr $cmx * 778 /1000] [expr $cmy * 731 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 778 /1000] [expr $cmy * 731 /1000] [expr $cmx * 779 /1000] [expr $cmy * 739 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 779 /1000] [expr $cmy * 739 /1000] [expr $cmx * 780 /1000] [expr $cmy * 747 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 780 /1000] [expr $cmy * 747 /1000] [expr $cmx * 782 /1000] [expr $cmy * 756 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 782 /1000] [expr $cmy * 756 /1000] [expr $cmx * 784 /1000] [expr $cmy * 765 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 784 /1000] [expr $cmy * 765 /1000] [expr $cmx * 785 /1000] [expr $cmy * 769 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 341 /1000] [expr $cmy * 839 /1000] [expr $cmx * 348 /1000] [expr $cmy * 840 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 348 /1000] [expr $cmy * 840 /1000] [expr $cmx * 356 /1000] [expr $cmy * 842 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 356 /1000] [expr $cmy * 842 /1000] [expr $cmx * 363 /1000] [expr $cmy * 843 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 363 /1000] [expr $cmy * 843 /1000] [expr $cmx * 371 /1000] [expr $cmy * 845 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 371 /1000] [expr $cmy * 845 /1000] [expr $cmx * 379 /1000] [expr $cmy * 847 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 379 /1000] [expr $cmy * 847 /1000] [expr $cmx * 387 /1000] [expr $cmy * 850 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 387 /1000] [expr $cmy * 850 /1000] [expr $cmx * 396 /1000] [expr $cmy * 853 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 396 /1000] [expr $cmy * 853 /1000] [expr $cmx * 404 /1000] [expr $cmy * 856 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 404 /1000] [expr $cmy * 856 /1000] [expr $cmx * 413 /1000] [expr $cmy * 859 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 413 /1000] [expr $cmy * 859 /1000] [expr $cmx * 423 /1000] [expr $cmy * 863 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 423 /1000] [expr $cmy * 863 /1000] [expr $cmx * 433 /1000] [expr $cmy * 867 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 433 /1000] [expr $cmy * 867 /1000] [expr $cmx * 443 /1000] [expr $cmy * 872 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 443 /1000] [expr $cmy * 872 /1000] [expr $cmx * 454 /1000] [expr $cmy * 877 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 454 /1000] [expr $cmy * 877 /1000] [expr $cmx * 465 /1000] [expr $cmy * 883 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 465 /1000] [expr $cmy * 883 /1000] [expr $cmx * 471 /1000] [expr $cmy * 886 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 528 /1000] [expr $cmy * 484 /1000] [expr $cmx * 534 /1000] [expr $cmy * 487 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 534 /1000] [expr $cmy * 487 /1000] [expr $cmx * 545 /1000] [expr $cmy * 493 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 545 /1000] [expr $cmy * 493 /1000] [expr $cmx * 556 /1000] [expr $cmy * 498 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 556 /1000] [expr $cmy * 498 /1000] [expr $cmx * 566 /1000] [expr $cmy * 503 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 566 /1000] [expr $cmy * 503 /1000] [expr $cmx * 576 /1000] [expr $cmy * 507 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 576 /1000] [expr $cmy * 507 /1000] [expr $cmx * 586 /1000] [expr $cmy * 511 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 586 /1000] [expr $cmy * 511 /1000] [expr $cmx * 595 /1000] [expr $cmy * 514 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 595 /1000] [expr $cmy * 514 /1000] [expr $cmx * 603 /1000] [expr $cmy * 517 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 603 /1000] [expr $cmy * 517 /1000] [expr $cmx * 612 /1000] [expr $cmy * 520 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 612 /1000] [expr $cmy * 520 /1000] [expr $cmx * 620 /1000] [expr $cmy * 523 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 620 /1000] [expr $cmy * 523 /1000] [expr $cmx * 628 /1000] [expr $cmy * 525 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 628 /1000] [expr $cmy * 525 /1000] [expr $cmx * 636 /1000] [expr $cmy * 527 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 636 /1000] [expr $cmy * 527 /1000] [expr $cmx * 643 /1000] [expr $cmy * 528 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 643 /1000] [expr $cmy * 528 /1000] [expr $cmx * 651 /1000] [expr $cmy * 530 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 651 /1000] [expr $cmy * 530 /1000] [expr $cmx * 658 /1000] [expr $cmy * 531 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 214 /1000] [expr $cmy * 600 /1000] [expr $cmx * 215 /1000] [expr $cmy * 605 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 215 /1000] [expr $cmy * 605 /1000] [expr $cmx * 217 /1000] [expr $cmy * 614 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 217 /1000] [expr $cmy * 614 /1000] [expr $cmx * 219 /1000] [expr $cmy * 623 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 219 /1000] [expr $cmy * 623 /1000] [expr $cmx * 220 /1000] [expr $cmy * 631 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 220 /1000] [expr $cmy * 631 /1000] [expr $cmx * 221 /1000] [expr $cmy * 639 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 221 /1000] [expr $cmy * 639 /1000] [expr $cmx * 221 /1000] [expr $cmy * 646 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 221 /1000] [expr $cmy * 646 /1000] [expr $cmx * 221 /1000] [expr $cmy * 653 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 221 /1000] [expr $cmy * 653 /1000] [expr $cmx * 221 /1000] [expr $cmy * 659 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 221 /1000] [expr $cmy * 659 /1000] [expr $cmx * 221 /1000] [expr $cmy * 665 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 221 /1000] [expr $cmy * 665 /1000] [expr $cmx * 220 /1000] [expr $cmy * 671 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 220 /1000] [expr $cmy * 671 /1000] [expr $cmx * 219 /1000] [expr $cmy * 676 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 219 /1000] [expr $cmy * 676 /1000] [expr $cmx * 218 /1000] [expr $cmy * 682 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 218 /1000] [expr $cmy * 682 /1000] [expr $cmx * 216 /1000] [expr $cmy * 687 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 216 /1000] [expr $cmy * 687 /1000] [expr $cmx * 215 /1000] [expr $cmy * 691 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 215 /1000] [expr $cmy * 691 /1000] [expr $cmx * 213 /1000] [expr $cmy * 696 /1000] -fill brown -width 1.000000 -capstyle round
eval $can create text [expr $cmx * 836 /1000] [expr $cmy * 394 /1000] -text \{ 4.5e+03\} -fill magenta -anchor e [expr [info exists font]?"-font \$font":{}]
$can create line [expr $cmx * 852 /1000] [expr $cmy * 394 /1000] [expr $cmx * 934 /1000] [expr $cmy * 394 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 780 /1000] [expr $cmy * 667 /1000] [expr $cmx * 778 /1000] [expr $cmy * 671 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 778 /1000] [expr $cmy * 671 /1000] [expr $cmx * 776 /1000] [expr $cmy * 676 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 776 /1000] [expr $cmy * 676 /1000] [expr $cmx * 774 /1000] [expr $cmy * 680 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 774 /1000] [expr $cmy * 680 /1000] [expr $cmx * 773 /1000] [expr $cmy * 685 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 773 /1000] [expr $cmy * 685 /1000] [expr $cmx * 771 /1000] [expr $cmy * 690 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 771 /1000] [expr $cmy * 690 /1000] [expr $cmx * 770 /1000] [expr $cmy * 696 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 770 /1000] [expr $cmy * 696 /1000] [expr $cmx * 769 /1000] [expr $cmy * 701 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 769 /1000] [expr $cmy * 701 /1000] [expr $cmx * 768 /1000] [expr $cmy * 707 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 768 /1000] [expr $cmy * 707 /1000] [expr $cmx * 768 /1000] [expr $cmy * 714 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 768 /1000] [expr $cmy * 714 /1000] [expr $cmx * 768 /1000] [expr $cmy * 720 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 768 /1000] [expr $cmy * 720 /1000] [expr $cmx * 768 /1000] [expr $cmy * 727 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 768 /1000] [expr $cmy * 727 /1000] [expr $cmx * 769 /1000] [expr $cmy * 734 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 769 /1000] [expr $cmy * 734 /1000] [expr $cmx * 770 /1000] [expr $cmy * 742 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 770 /1000] [expr $cmy * 742 /1000] [expr $cmx * 772 /1000] [expr $cmy * 751 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 772 /1000] [expr $cmy * 751 /1000] [expr $cmx * 774 /1000] [expr $cmy * 760 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 774 /1000] [expr $cmy * 760 /1000] [expr $cmx * 776 /1000] [expr $cmy * 769 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 776 /1000] [expr $cmy * 769 /1000] [expr $cmx * 777 /1000] [expr $cmy * 772 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 335 /1000] [expr $cmy * 832 /1000] [expr $cmx * 342 /1000] [expr $cmy * 833 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 342 /1000] [expr $cmy * 833 /1000] [expr $cmx * 349 /1000] [expr $cmy * 834 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 349 /1000] [expr $cmy * 834 /1000] [expr $cmx * 356 /1000] [expr $cmy * 835 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 356 /1000] [expr $cmy * 835 /1000] [expr $cmx * 363 /1000] [expr $cmy * 837 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 363 /1000] [expr $cmy * 837 /1000] [expr $cmx * 371 /1000] [expr $cmy * 839 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 371 /1000] [expr $cmy * 839 /1000] [expr $cmx * 379 /1000] [expr $cmy * 841 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 379 /1000] [expr $cmy * 841 /1000] [expr $cmx * 387 /1000] [expr $cmy * 843 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 387 /1000] [expr $cmy * 843 /1000] [expr $cmx * 395 /1000] [expr $cmy * 846 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 395 /1000] [expr $cmy * 846 /1000] [expr $cmx * 404 /1000] [expr $cmy * 848 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 404 /1000] [expr $cmy * 848 /1000] [expr $cmx * 413 /1000] [expr $cmy * 852 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 413 /1000] [expr $cmy * 852 /1000] [expr $cmx * 422 /1000] [expr $cmy * 855 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 422 /1000] [expr $cmy * 855 /1000] [expr $cmx * 432 /1000] [expr $cmy * 859 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 432 /1000] [expr $cmy * 859 /1000] [expr $cmx * 442 /1000] [expr $cmy * 864 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 442 /1000] [expr $cmy * 864 /1000] [expr $cmx * 452 /1000] [expr $cmy * 869 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 452 /1000] [expr $cmy * 869 /1000] [expr $cmx * 463 /1000] [expr $cmy * 875 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 463 /1000] [expr $cmy * 875 /1000] [expr $cmx * 475 /1000] [expr $cmy * 881 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 475 /1000] [expr $cmy * 881 /1000] [expr $cmx * 479 /1000] [expr $cmy * 883 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 520 /1000] [expr $cmy * 487 /1000] [expr $cmx * 524 /1000] [expr $cmy * 489 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 524 /1000] [expr $cmy * 489 /1000] [expr $cmx * 536 /1000] [expr $cmy * 495 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 536 /1000] [expr $cmy * 495 /1000] [expr $cmx * 547 /1000] [expr $cmy * 501 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 547 /1000] [expr $cmy * 501 /1000] [expr $cmx * 557 /1000] [expr $cmy * 506 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 557 /1000] [expr $cmy * 506 /1000] [expr $cmx * 567 /1000] [expr $cmy * 511 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 567 /1000] [expr $cmy * 511 /1000] [expr $cmx * 577 /1000] [expr $cmy * 515 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 577 /1000] [expr $cmy * 515 /1000] [expr $cmx * 586 /1000] [expr $cmy * 518 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 586 /1000] [expr $cmy * 518 /1000] [expr $cmx * 595 /1000] [expr $cmy * 522 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 595 /1000] [expr $cmy * 522 /1000] [expr $cmx * 604 /1000] [expr $cmy * 524 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 604 /1000] [expr $cmy * 524 /1000] [expr $cmx * 612 /1000] [expr $cmy * 527 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 612 /1000] [expr $cmy * 527 /1000] [expr $cmx * 620 /1000] [expr $cmy * 529 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 620 /1000] [expr $cmy * 529 /1000] [expr $cmx * 628 /1000] [expr $cmy * 531 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 628 /1000] [expr $cmy * 531 /1000] [expr $cmx * 636 /1000] [expr $cmy * 533 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 636 /1000] [expr $cmy * 533 /1000] [expr $cmx * 643 /1000] [expr $cmy * 535 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 643 /1000] [expr $cmy * 535 /1000] [expr $cmx * 650 /1000] [expr $cmy * 536 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 650 /1000] [expr $cmy * 536 /1000] [expr $cmx * 657 /1000] [expr $cmy * 537 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 657 /1000] [expr $cmy * 537 /1000] [expr $cmx * 664 /1000] [expr $cmy * 538 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 222 /1000] [expr $cmy * 597 /1000] [expr $cmx * 223 /1000] [expr $cmy * 600 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 223 /1000] [expr $cmy * 600 /1000] [expr $cmx * 225 /1000] [expr $cmy * 610 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 225 /1000] [expr $cmy * 610 /1000] [expr $cmx * 227 /1000] [expr $cmy * 619 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 227 /1000] [expr $cmy * 619 /1000] [expr $cmx * 229 /1000] [expr $cmy * 628 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 229 /1000] [expr $cmy * 628 /1000] [expr $cmx * 230 /1000] [expr $cmy * 635 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 230 /1000] [expr $cmy * 635 /1000] [expr $cmx * 231 /1000] [expr $cmy * 643 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 231 /1000] [expr $cmy * 643 /1000] [expr $cmx * 231 /1000] [expr $cmy * 650 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 231 /1000] [expr $cmy * 650 /1000] [expr $cmx * 231 /1000] [expr $cmy * 656 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 231 /1000] [expr $cmy * 656 /1000] [expr $cmx * 231 /1000] [expr $cmy * 663 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 231 /1000] [expr $cmy * 663 /1000] [expr $cmx * 230 /1000] [expr $cmy * 669 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 230 /1000] [expr $cmy * 669 /1000] [expr $cmx * 229 /1000] [expr $cmy * 674 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 229 /1000] [expr $cmy * 674 /1000] [expr $cmx * 228 /1000] [expr $cmy * 680 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 228 /1000] [expr $cmy * 680 /1000] [expr $cmx * 226 /1000] [expr $cmy * 685 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 226 /1000] [expr $cmy * 685 /1000] [expr $cmx * 225 /1000] [expr $cmy * 690 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 225 /1000] [expr $cmy * 690 /1000] [expr $cmx * 223 /1000] [expr $cmy * 694 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 223 /1000] [expr $cmy * 694 /1000] [expr $cmx * 221 /1000] [expr $cmy * 699 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 221 /1000] [expr $cmy * 699 /1000] [expr $cmx * 219 /1000] [expr $cmy * 703 /1000] -fill magenta -width 1.000000 -capstyle round
eval $can create text [expr $cmx * 836 /1000] [expr $cmy * 419 /1000] -text \{   4e+03\} -fill cyan -anchor e [expr [info exists font]?"-font \$font":{}]
$can create line [expr $cmx * 852 /1000] [expr $cmy * 419 /1000] [expr $cmx * 934 /1000] [expr $cmy * 419 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 773 /1000] [expr $cmy * 660 /1000] [expr $cmx * 771 /1000] [expr $cmy * 664 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 771 /1000] [expr $cmy * 664 /1000] [expr $cmx * 769 /1000] [expr $cmy * 668 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 769 /1000] [expr $cmy * 668 /1000] [expr $cmx * 767 /1000] [expr $cmy * 672 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 767 /1000] [expr $cmy * 672 /1000] [expr $cmx * 765 /1000] [expr $cmy * 677 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 765 /1000] [expr $cmy * 677 /1000] [expr $cmx * 763 /1000] [expr $cmy * 682 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 763 /1000] [expr $cmy * 682 /1000] [expr $cmx * 762 /1000] [expr $cmy * 687 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 762 /1000] [expr $cmy * 687 /1000] [expr $cmx * 760 /1000] [expr $cmy * 692 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 760 /1000] [expr $cmy * 692 /1000] [expr $cmx * 759 /1000] [expr $cmy * 697 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 759 /1000] [expr $cmy * 697 /1000] [expr $cmx * 758 /1000] [expr $cmy * 703 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 758 /1000] [expr $cmy * 703 /1000] [expr $cmx * 758 /1000] [expr $cmy * 709 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 758 /1000] [expr $cmy * 709 /1000] [expr $cmx * 758 /1000] [expr $cmy * 715 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 758 /1000] [expr $cmy * 715 /1000] [expr $cmx * 758 /1000] [expr $cmy * 722 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 758 /1000] [expr $cmy * 722 /1000] [expr $cmx * 758 /1000] [expr $cmy * 729 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 758 /1000] [expr $cmy * 729 /1000] [expr $cmx * 759 /1000] [expr $cmy * 737 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 759 /1000] [expr $cmy * 737 /1000] [expr $cmx * 760 /1000] [expr $cmy * 745 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 760 /1000] [expr $cmy * 745 /1000] [expr $cmx * 762 /1000] [expr $cmy * 754 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 762 /1000] [expr $cmy * 754 /1000] [expr $cmx * 765 /1000] [expr $cmy * 763 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 765 /1000] [expr $cmy * 763 /1000] [expr $cmx * 768 /1000] [expr $cmy * 774 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 768 /1000] [expr $cmy * 774 /1000] [expr $cmx * 769 /1000] [expr $cmy * 776 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 328 /1000] [expr $cmy * 825 /1000] [expr $cmx * 335 /1000] [expr $cmy * 825 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 335 /1000] [expr $cmy * 825 /1000] [expr $cmx * 342 /1000] [expr $cmy * 826 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 342 /1000] [expr $cmy * 826 /1000] [expr $cmx * 349 /1000] [expr $cmy * 827 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 349 /1000] [expr $cmy * 827 /1000] [expr $cmx * 356 /1000] [expr $cmy * 828 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 356 /1000] [expr $cmy * 828 /1000] [expr $cmx * 363 /1000] [expr $cmy * 830 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 363 /1000] [expr $cmy * 830 /1000] [expr $cmx * 370 /1000] [expr $cmy * 831 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 370 /1000] [expr $cmy * 831 /1000] [expr $cmx * 378 /1000] [expr $cmy * 833 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 378 /1000] [expr $cmy * 833 /1000] [expr $cmx * 386 /1000] [expr $cmy * 835 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 386 /1000] [expr $cmy * 835 /1000] [expr $cmx * 394 /1000] [expr $cmy * 838 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 394 /1000] [expr $cmy * 838 /1000] [expr $cmx * 403 /1000] [expr $cmy * 840 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 403 /1000] [expr $cmy * 840 /1000] [expr $cmx * 411 /1000] [expr $cmy * 844 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 411 /1000] [expr $cmy * 844 /1000] [expr $cmx * 420 /1000] [expr $cmy * 847 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 420 /1000] [expr $cmy * 847 /1000] [expr $cmx * 430 /1000] [expr $cmy * 851 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 430 /1000] [expr $cmy * 851 /1000] [expr $cmx * 440 /1000] [expr $cmy * 855 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 440 /1000] [expr $cmy * 855 /1000] [expr $cmx * 450 /1000] [expr $cmy * 860 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 450 /1000] [expr $cmy * 860 /1000] [expr $cmx * 461 /1000] [expr $cmy * 865 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 461 /1000] [expr $cmy * 865 /1000] [expr $cmx * 473 /1000] [expr $cmy * 872 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 473 /1000] [expr $cmy * 872 /1000] [expr $cmx * 485 /1000] [expr $cmy * 878 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 485 /1000] [expr $cmy * 878 /1000] [expr $cmx * 487 /1000] [expr $cmy * 880 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 512 /1000] [expr $cmy * 490 /1000] [expr $cmx * 514 /1000] [expr $cmy * 491 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 514 /1000] [expr $cmy * 491 /1000] [expr $cmx * 526 /1000] [expr $cmy * 498 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 526 /1000] [expr $cmy * 498 /1000] [expr $cmx * 538 /1000] [expr $cmy * 504 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 538 /1000] [expr $cmy * 504 /1000] [expr $cmx * 549 /1000] [expr $cmy * 510 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 549 /1000] [expr $cmy * 510 /1000] [expr $cmx * 559 /1000] [expr $cmy * 515 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 559 /1000] [expr $cmy * 515 /1000] [expr $cmx * 569 /1000] [expr $cmy * 519 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 569 /1000] [expr $cmy * 519 /1000] [expr $cmx * 579 /1000] [expr $cmy * 523 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 579 /1000] [expr $cmy * 523 /1000] [expr $cmx * 588 /1000] [expr $cmy * 526 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 588 /1000] [expr $cmy * 526 /1000] [expr $cmx * 596 /1000] [expr $cmy * 530 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 596 /1000] [expr $cmy * 530 /1000] [expr $cmx * 605 /1000] [expr $cmy * 532 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 605 /1000] [expr $cmy * 532 /1000] [expr $cmx * 613 /1000] [expr $cmy * 535 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 613 /1000] [expr $cmy * 535 /1000] [expr $cmx * 621 /1000] [expr $cmy * 537 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 621 /1000] [expr $cmy * 537 /1000] [expr $cmx * 629 /1000] [expr $cmy * 539 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 629 /1000] [expr $cmy * 539 /1000] [expr $cmx * 636 /1000] [expr $cmy * 540 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 636 /1000] [expr $cmy * 540 /1000] [expr $cmx * 643 /1000] [expr $cmy * 542 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 643 /1000] [expr $cmy * 542 /1000] [expr $cmx * 650 /1000] [expr $cmy * 543 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 650 /1000] [expr $cmy * 543 /1000] [expr $cmx * 657 /1000] [expr $cmy * 544 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 657 /1000] [expr $cmy * 544 /1000] [expr $cmx * 664 /1000] [expr $cmy * 545 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 664 /1000] [expr $cmy * 545 /1000] [expr $cmx * 671 /1000] [expr $cmy * 545 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 230 /1000] [expr $cmy * 594 /1000] [expr $cmx * 231 /1000] [expr $cmy * 596 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 231 /1000] [expr $cmy * 596 /1000] [expr $cmx * 234 /1000] [expr $cmy * 607 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 234 /1000] [expr $cmy * 607 /1000] [expr $cmx * 237 /1000] [expr $cmy * 616 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 237 /1000] [expr $cmy * 616 /1000] [expr $cmx * 239 /1000] [expr $cmy * 625 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 239 /1000] [expr $cmy * 625 /1000] [expr $cmx * 240 /1000] [expr $cmy * 633 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 240 /1000] [expr $cmy * 633 /1000] [expr $cmx * 241 /1000] [expr $cmy * 641 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 241 /1000] [expr $cmy * 641 /1000] [expr $cmx * 241 /1000] [expr $cmy * 648 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 241 /1000] [expr $cmy * 648 /1000] [expr $cmx * 241 /1000] [expr $cmy * 655 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 241 /1000] [expr $cmy * 655 /1000] [expr $cmx * 241 /1000] [expr $cmy * 661 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 241 /1000] [expr $cmy * 661 /1000] [expr $cmx * 241 /1000] [expr $cmy * 667 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 241 /1000] [expr $cmy * 667 /1000] [expr $cmx * 240 /1000] [expr $cmy * 673 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 240 /1000] [expr $cmy * 673 /1000] [expr $cmx * 239 /1000] [expr $cmy * 678 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 239 /1000] [expr $cmy * 678 /1000] [expr $cmx * 237 /1000] [expr $cmy * 683 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 237 /1000] [expr $cmy * 683 /1000] [expr $cmx * 236 /1000] [expr $cmy * 688 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 236 /1000] [expr $cmy * 688 /1000] [expr $cmx * 234 /1000] [expr $cmy * 693 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 234 /1000] [expr $cmy * 693 /1000] [expr $cmx * 232 /1000] [expr $cmy * 698 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 232 /1000] [expr $cmy * 698 /1000] [expr $cmx * 230 /1000] [expr $cmy * 702 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 230 /1000] [expr $cmy * 702 /1000] [expr $cmx * 228 /1000] [expr $cmy * 706 /1000] -fill cyan -width 1.000000 -capstyle round
$can create line [expr $cmx * 228 /1000] [expr $cmy * 706 /1000] [expr $cmx * 226 /1000] [expr $cmy * 710 /1000] -fill cyan -width 1.000000 -capstyle round
eval $can create text [expr $cmx * 836 /1000] [expr $cmy * 444 /1000] -text \{ 3.5e+03\} -fill black -anchor e [expr [info exists font]?"-font \$font":{}]
$can create line [expr $cmx * 852 /1000] [expr $cmy * 444 /1000] [expr $cmx * 934 /1000] [expr $cmy * 444 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 767 /1000] [expr $cmy * 653 /1000] [expr $cmx * 764 /1000] [expr $cmy * 656 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 764 /1000] [expr $cmy * 656 /1000] [expr $cmx * 762 /1000] [expr $cmy * 660 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 762 /1000] [expr $cmy * 660 /1000] [expr $cmx * 760 /1000] [expr $cmy * 664 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 760 /1000] [expr $cmy * 664 /1000] [expr $cmx * 757 /1000] [expr $cmy * 668 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 757 /1000] [expr $cmy * 668 /1000] [expr $cmx * 755 /1000] [expr $cmy * 673 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 755 /1000] [expr $cmy * 673 /1000] [expr $cmx * 753 /1000] [expr $cmy * 677 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 753 /1000] [expr $cmy * 677 /1000] [expr $cmx * 752 /1000] [expr $cmy * 682 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 752 /1000] [expr $cmy * 682 /1000] [expr $cmx * 750 /1000] [expr $cmy * 687 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 750 /1000] [expr $cmy * 687 /1000] [expr $cmx * 749 /1000] [expr $cmy * 692 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 749 /1000] [expr $cmy * 692 /1000] [expr $cmx * 748 /1000] [expr $cmy * 698 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 748 /1000] [expr $cmy * 698 /1000] [expr $cmx * 747 /1000] [expr $cmy * 703 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 747 /1000] [expr $cmy * 703 /1000] [expr $cmx * 746 /1000] [expr $cmy * 710 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 746 /1000] [expr $cmy * 710 /1000] [expr $cmx * 746 /1000] [expr $cmy * 716 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 746 /1000] [expr $cmy * 716 /1000] [expr $cmx * 747 /1000] [expr $cmy * 723 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 747 /1000] [expr $cmy * 723 /1000] [expr $cmx * 747 /1000] [expr $cmy * 730 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 747 /1000] [expr $cmy * 730 /1000] [expr $cmx * 748 /1000] [expr $cmy * 738 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 748 /1000] [expr $cmy * 738 /1000] [expr $cmx * 750 /1000] [expr $cmy * 747 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 750 /1000] [expr $cmy * 747 /1000] [expr $cmx * 752 /1000] [expr $cmy * 756 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 752 /1000] [expr $cmy * 756 /1000] [expr $cmx * 755 /1000] [expr $cmy * 766 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 755 /1000] [expr $cmy * 766 /1000] [expr $cmx * 759 /1000] [expr $cmy * 777 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 759 /1000] [expr $cmy * 777 /1000] [expr $cmx * 760 /1000] [expr $cmy * 779 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 322 /1000] [expr $cmy * 817 /1000] [expr $cmx * 328 /1000] [expr $cmy * 818 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 328 /1000] [expr $cmy * 818 /1000] [expr $cmx * 335 /1000] [expr $cmy * 818 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 335 /1000] [expr $cmy * 818 /1000] [expr $cmx * 341 /1000] [expr $cmy * 819 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 341 /1000] [expr $cmy * 819 /1000] [expr $cmx * 348 /1000] [expr $cmy * 820 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 348 /1000] [expr $cmy * 820 /1000] [expr $cmx * 355 /1000] [expr $cmy * 821 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 355 /1000] [expr $cmy * 821 /1000] [expr $cmx * 362 /1000] [expr $cmy * 822 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 362 /1000] [expr $cmy * 822 /1000] [expr $cmx * 369 /1000] [expr $cmy * 824 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 369 /1000] [expr $cmy * 824 /1000] [expr $cmx * 377 /1000] [expr $cmy * 825 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 377 /1000] [expr $cmy * 825 /1000] [expr $cmx * 385 /1000] [expr $cmy * 827 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 385 /1000] [expr $cmy * 827 /1000] [expr $cmx * 393 /1000] [expr $cmy * 829 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 393 /1000] [expr $cmy * 829 /1000] [expr $cmx * 401 /1000] [expr $cmy * 832 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 401 /1000] [expr $cmy * 832 /1000] [expr $cmx * 409 /1000] [expr $cmy * 835 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 409 /1000] [expr $cmy * 835 /1000] [expr $cmx * 418 /1000] [expr $cmy * 838 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 418 /1000] [expr $cmy * 838 /1000] [expr $cmx * 427 /1000] [expr $cmy * 841 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 427 /1000] [expr $cmy * 841 /1000] [expr $cmx * 437 /1000] [expr $cmy * 845 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 437 /1000] [expr $cmy * 845 /1000] [expr $cmx * 447 /1000] [expr $cmy * 850 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 447 /1000] [expr $cmy * 850 /1000] [expr $cmx * 458 /1000] [expr $cmy * 855 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 458 /1000] [expr $cmy * 855 /1000] [expr $cmx * 469 /1000] [expr $cmy * 861 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 469 /1000] [expr $cmy * 861 /1000] [expr $cmx * 481 /1000] [expr $cmy * 867 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 481 /1000] [expr $cmy * 867 /1000] [expr $cmx * 493 /1000] [expr $cmy * 875 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 493 /1000] [expr $cmy * 875 /1000] [expr $cmx * 496 /1000] [expr $cmy * 877 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 503 /1000] [expr $cmy * 493 /1000] [expr $cmx * 506 /1000] [expr $cmy * 495 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 506 /1000] [expr $cmy * 495 /1000] [expr $cmx * 518 /1000] [expr $cmy * 503 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 518 /1000] [expr $cmy * 503 /1000] [expr $cmx * 530 /1000] [expr $cmy * 509 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 530 /1000] [expr $cmy * 509 /1000] [expr $cmx * 541 /1000] [expr $cmy * 515 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 541 /1000] [expr $cmy * 515 /1000] [expr $cmx * 552 /1000] [expr $cmy * 520 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 552 /1000] [expr $cmy * 520 /1000] [expr $cmx * 562 /1000] [expr $cmy * 525 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 562 /1000] [expr $cmy * 525 /1000] [expr $cmx * 572 /1000] [expr $cmy * 529 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 572 /1000] [expr $cmy * 529 /1000] [expr $cmx * 581 /1000] [expr $cmy * 532 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 581 /1000] [expr $cmy * 532 /1000] [expr $cmx * 590 /1000] [expr $cmy * 535 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 590 /1000] [expr $cmy * 535 /1000] [expr $cmx * 598 /1000] [expr $cmy * 538 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 598 /1000] [expr $cmy * 538 /1000] [expr $cmx * 606 /1000] [expr $cmy * 541 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 606 /1000] [expr $cmy * 541 /1000] [expr $cmx * 614 /1000] [expr $cmy * 543 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 614 /1000] [expr $cmy * 543 /1000] [expr $cmx * 622 /1000] [expr $cmy * 545 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 622 /1000] [expr $cmy * 545 /1000] [expr $cmx * 630 /1000] [expr $cmy * 546 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 630 /1000] [expr $cmy * 546 /1000] [expr $cmx * 637 /1000] [expr $cmy * 548 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 637 /1000] [expr $cmy * 548 /1000] [expr $cmx * 644 /1000] [expr $cmy * 549 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 644 /1000] [expr $cmy * 549 /1000] [expr $cmx * 651 /1000] [expr $cmy * 550 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 651 /1000] [expr $cmy * 550 /1000] [expr $cmx * 658 /1000] [expr $cmy * 551 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 658 /1000] [expr $cmy * 551 /1000] [expr $cmx * 664 /1000] [expr $cmy * 552 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 664 /1000] [expr $cmy * 552 /1000] [expr $cmx * 671 /1000] [expr $cmy * 552 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 671 /1000] [expr $cmy * 552 /1000] [expr $cmx * 677 /1000] [expr $cmy * 553 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 239 /1000] [expr $cmy * 591 /1000] [expr $cmx * 240 /1000] [expr $cmy * 593 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 240 /1000] [expr $cmy * 593 /1000] [expr $cmx * 244 /1000] [expr $cmy * 604 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 244 /1000] [expr $cmy * 604 /1000] [expr $cmx * 247 /1000] [expr $cmy * 614 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 247 /1000] [expr $cmy * 614 /1000] [expr $cmx * 249 /1000] [expr $cmy * 623 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 249 /1000] [expr $cmy * 623 /1000] [expr $cmx * 251 /1000] [expr $cmy * 632 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 251 /1000] [expr $cmy * 632 /1000] [expr $cmx * 252 /1000] [expr $cmy * 640 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 252 /1000] [expr $cmy * 640 /1000] [expr $cmx * 252 /1000] [expr $cmy * 647 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 252 /1000] [expr $cmy * 647 /1000] [expr $cmx * 253 /1000] [expr $cmy * 654 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 253 /1000] [expr $cmy * 654 /1000] [expr $cmx * 253 /1000] [expr $cmy * 660 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 253 /1000] [expr $cmy * 660 /1000] [expr $cmx * 252 /1000] [expr $cmy * 666 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 252 /1000] [expr $cmy * 666 /1000] [expr $cmx * 251 /1000] [expr $cmy * 672 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 251 /1000] [expr $cmy * 672 /1000] [expr $cmx * 250 /1000] [expr $cmy * 678 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 250 /1000] [expr $cmy * 678 /1000] [expr $cmx * 249 /1000] [expr $cmy * 683 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 249 /1000] [expr $cmy * 683 /1000] [expr $cmx * 247 /1000] [expr $cmy * 688 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 247 /1000] [expr $cmy * 688 /1000] [expr $cmx * 246 /1000] [expr $cmy * 693 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 246 /1000] [expr $cmy * 693 /1000] [expr $cmx * 244 /1000] [expr $cmy * 697 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 244 /1000] [expr $cmy * 697 /1000] [expr $cmx * 242 /1000] [expr $cmy * 702 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 242 /1000] [expr $cmy * 702 /1000] [expr $cmx * 239 /1000] [expr $cmy * 706 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 239 /1000] [expr $cmy * 706 /1000] [expr $cmx * 237 /1000] [expr $cmy * 710 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 237 /1000] [expr $cmy * 710 /1000] [expr $cmx * 235 /1000] [expr $cmy * 714 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 235 /1000] [expr $cmy * 714 /1000] [expr $cmx * 232 /1000] [expr $cmy * 717 /1000] -fill black -width 1.000000 -capstyle round
eval $can create text [expr $cmx * 836 /1000] [expr $cmy * 469 /1000] -text \{   3e+03\} -fill gray -anchor e [expr [info exists font]?"-font \$font":{}]
$can create line [expr $cmx * 852 /1000] [expr $cmy * 469 /1000] [expr $cmx * 934 /1000] [expr $cmy * 469 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 761 /1000] [expr $cmy * 645 /1000] [expr $cmx * 758 /1000] [expr $cmy * 649 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 758 /1000] [expr $cmy * 649 /1000] [expr $cmx * 755 /1000] [expr $cmy * 652 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 755 /1000] [expr $cmy * 652 /1000] [expr $cmx * 752 /1000] [expr $cmy * 656 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 752 /1000] [expr $cmy * 656 /1000] [expr $cmx * 750 /1000] [expr $cmy * 660 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 750 /1000] [expr $cmy * 660 /1000] [expr $cmx * 747 /1000] [expr $cmy * 664 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 747 /1000] [expr $cmy * 664 /1000] [expr $cmx * 745 /1000] [expr $cmy * 668 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 745 /1000] [expr $cmy * 668 /1000] [expr $cmx * 743 /1000] [expr $cmy * 672 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 743 /1000] [expr $cmy * 672 /1000] [expr $cmx * 741 /1000] [expr $cmy * 677 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 741 /1000] [expr $cmy * 677 /1000] [expr $cmx * 739 /1000] [expr $cmy * 682 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 739 /1000] [expr $cmy * 682 /1000] [expr $cmx * 738 /1000] [expr $cmy * 686 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 738 /1000] [expr $cmy * 686 /1000] [expr $cmx * 736 /1000] [expr $cmy * 692 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 736 /1000] [expr $cmy * 692 /1000] [expr $cmx * 735 /1000] [expr $cmy * 697 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 735 /1000] [expr $cmy * 697 /1000] [expr $cmx * 735 /1000] [expr $cmy * 703 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 735 /1000] [expr $cmy * 703 /1000] [expr $cmx * 734 /1000] [expr $cmy * 709 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 734 /1000] [expr $cmy * 709 /1000] [expr $cmx * 734 /1000] [expr $cmy * 716 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 734 /1000] [expr $cmy * 716 /1000] [expr $cmx * 734 /1000] [expr $cmy * 723 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 734 /1000] [expr $cmy * 723 /1000] [expr $cmx * 735 /1000] [expr $cmy * 730 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 735 /1000] [expr $cmy * 730 /1000] [expr $cmx * 736 /1000] [expr $cmy * 738 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 736 /1000] [expr $cmy * 738 /1000] [expr $cmx * 738 /1000] [expr $cmy * 747 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 738 /1000] [expr $cmy * 747 /1000] [expr $cmx * 741 /1000] [expr $cmy * 756 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 741 /1000] [expr $cmy * 756 /1000] [expr $cmx * 744 /1000] [expr $cmy * 767 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 744 /1000] [expr $cmy * 767 /1000] [expr $cmx * 748 /1000] [expr $cmy * 778 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 748 /1000] [expr $cmy * 778 /1000] [expr $cmx * 750 /1000] [expr $cmy * 783 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 315 /1000] [expr $cmy * 810 /1000] [expr $cmx * 322 /1000] [expr $cmy * 810 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 322 /1000] [expr $cmy * 810 /1000] [expr $cmx * 328 /1000] [expr $cmy * 811 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 328 /1000] [expr $cmy * 811 /1000] [expr $cmx * 334 /1000] [expr $cmy * 811 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 334 /1000] [expr $cmy * 811 /1000] [expr $cmx * 341 /1000] [expr $cmy * 811 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 341 /1000] [expr $cmy * 811 /1000] [expr $cmx * 347 /1000] [expr $cmy * 812 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 347 /1000] [expr $cmy * 812 /1000] [expr $cmx * 354 /1000] [expr $cmy * 813 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 354 /1000] [expr $cmy * 813 /1000] [expr $cmx * 361 /1000] [expr $cmy * 814 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 361 /1000] [expr $cmy * 814 /1000] [expr $cmx * 368 /1000] [expr $cmy * 815 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 368 /1000] [expr $cmy * 815 /1000] [expr $cmx * 375 /1000] [expr $cmy * 816 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 375 /1000] [expr $cmy * 816 /1000] [expr $cmx * 382 /1000] [expr $cmy * 818 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 382 /1000] [expr $cmy * 818 /1000] [expr $cmx * 390 /1000] [expr $cmy * 820 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 390 /1000] [expr $cmy * 820 /1000] [expr $cmx * 398 /1000] [expr $cmy * 822 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 398 /1000] [expr $cmy * 822 /1000] [expr $cmx * 406 /1000] [expr $cmy * 825 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 406 /1000] [expr $cmy * 825 /1000] [expr $cmx * 415 /1000] [expr $cmy * 827 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 415 /1000] [expr $cmy * 827 /1000] [expr $cmx * 424 /1000] [expr $cmy * 831 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 424 /1000] [expr $cmy * 831 /1000] [expr $cmx * 433 /1000] [expr $cmy * 834 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 433 /1000] [expr $cmy * 834 /1000] [expr $cmx * 443 /1000] [expr $cmy * 838 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 443 /1000] [expr $cmy * 838 /1000] [expr $cmx * 453 /1000] [expr $cmy * 843 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 453 /1000] [expr $cmy * 843 /1000] [expr $cmx * 464 /1000] [expr $cmy * 849 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 464 /1000] [expr $cmy * 849 /1000] [expr $cmx * 475 /1000] [expr $cmy * 855 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 475 /1000] [expr $cmy * 855 /1000] [expr $cmx * 488 /1000] [expr $cmy * 862 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 488 /1000] [expr $cmy * 862 /1000] [expr $cmx * 501 /1000] [expr $cmy * 870 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 501 /1000] [expr $cmy * 870 /1000] [expr $cmx * 506 /1000] [expr $cmy * 873 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 493 /1000] [expr $cmy * 497 /1000] [expr $cmx * 498 /1000] [expr $cmy * 500 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 498 /1000] [expr $cmy * 500 /1000] [expr $cmx * 511 /1000] [expr $cmy * 508 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 511 /1000] [expr $cmy * 508 /1000] [expr $cmx * 524 /1000] [expr $cmy * 515 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 524 /1000] [expr $cmy * 515 /1000] [expr $cmx * 535 /1000] [expr $cmy * 521 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 535 /1000] [expr $cmy * 521 /1000] [expr $cmx * 546 /1000] [expr $cmy * 527 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 546 /1000] [expr $cmy * 527 /1000] [expr $cmx * 556 /1000] [expr $cmy * 531 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 556 /1000] [expr $cmy * 531 /1000] [expr $cmx * 566 /1000] [expr $cmy * 536 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 566 /1000] [expr $cmy * 536 /1000] [expr $cmx * 575 /1000] [expr $cmy * 539 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 575 /1000] [expr $cmy * 539 /1000] [expr $cmx * 584 /1000] [expr $cmy * 543 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 584 /1000] [expr $cmy * 543 /1000] [expr $cmx * 593 /1000] [expr $cmy * 545 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 593 /1000] [expr $cmy * 545 /1000] [expr $cmx * 601 /1000] [expr $cmy * 548 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 601 /1000] [expr $cmy * 548 /1000] [expr $cmx * 609 /1000] [expr $cmy * 550 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 609 /1000] [expr $cmy * 550 /1000] [expr $cmx * 617 /1000] [expr $cmy * 552 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 617 /1000] [expr $cmy * 552 /1000] [expr $cmx * 624 /1000] [expr $cmy * 554 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 624 /1000] [expr $cmy * 554 /1000] [expr $cmx * 631 /1000] [expr $cmy * 555 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 631 /1000] [expr $cmy * 555 /1000] [expr $cmx * 638 /1000] [expr $cmy * 556 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 638 /1000] [expr $cmy * 556 /1000] [expr $cmx * 645 /1000] [expr $cmy * 557 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 645 /1000] [expr $cmy * 557 /1000] [expr $cmx * 652 /1000] [expr $cmy * 558 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 652 /1000] [expr $cmy * 558 /1000] [expr $cmx * 658 /1000] [expr $cmy * 559 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 658 /1000] [expr $cmy * 559 /1000] [expr $cmx * 665 /1000] [expr $cmy * 559 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 665 /1000] [expr $cmy * 559 /1000] [expr $cmx * 671 /1000] [expr $cmy * 559 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 671 /1000] [expr $cmy * 559 /1000] [expr $cmx * 677 /1000] [expr $cmy * 560 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 677 /1000] [expr $cmy * 560 /1000] [expr $cmx * 684 /1000] [expr $cmy * 560 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 249 /1000] [expr $cmy * 587 /1000] [expr $cmx * 251 /1000] [expr $cmy * 592 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 251 /1000] [expr $cmy * 592 /1000] [expr $cmx * 255 /1000] [expr $cmy * 603 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 255 /1000] [expr $cmy * 603 /1000] [expr $cmx * 258 /1000] [expr $cmy * 614 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 258 /1000] [expr $cmy * 614 /1000] [expr $cmx * 261 /1000] [expr $cmy * 623 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 261 /1000] [expr $cmy * 623 /1000] [expr $cmx * 263 /1000] [expr $cmy * 632 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 263 /1000] [expr $cmy * 632 /1000] [expr $cmx * 264 /1000] [expr $cmy * 640 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 264 /1000] [expr $cmy * 640 /1000] [expr $cmx * 265 /1000] [expr $cmy * 647 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 265 /1000] [expr $cmy * 647 /1000] [expr $cmx * 265 /1000] [expr $cmy * 654 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 265 /1000] [expr $cmy * 654 /1000] [expr $cmx * 265 /1000] [expr $cmy * 661 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 265 /1000] [expr $cmy * 661 /1000] [expr $cmx * 264 /1000] [expr $cmy * 667 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 264 /1000] [expr $cmy * 667 /1000] [expr $cmx * 264 /1000] [expr $cmy * 673 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 264 /1000] [expr $cmy * 673 /1000] [expr $cmx * 263 /1000] [expr $cmy * 678 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 263 /1000] [expr $cmy * 678 /1000] [expr $cmx * 261 /1000] [expr $cmy * 684 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 261 /1000] [expr $cmy * 684 /1000] [expr $cmx * 260 /1000] [expr $cmy * 688 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 260 /1000] [expr $cmy * 688 /1000] [expr $cmx * 258 /1000] [expr $cmy * 693 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 258 /1000] [expr $cmy * 693 /1000] [expr $cmx * 256 /1000] [expr $cmy * 698 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 256 /1000] [expr $cmy * 698 /1000] [expr $cmx * 254 /1000] [expr $cmy * 702 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 254 /1000] [expr $cmy * 702 /1000] [expr $cmx * 252 /1000] [expr $cmy * 706 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 252 /1000] [expr $cmy * 706 /1000] [expr $cmx * 249 /1000] [expr $cmy * 710 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 249 /1000] [expr $cmy * 710 /1000] [expr $cmx * 247 /1000] [expr $cmy * 714 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 247 /1000] [expr $cmy * 714 /1000] [expr $cmx * 244 /1000] [expr $cmy * 718 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 244 /1000] [expr $cmy * 718 /1000] [expr $cmx * 241 /1000] [expr $cmy * 721 /1000] -fill gray -width 1.000000 -capstyle round
$can create line [expr $cmx * 241 /1000] [expr $cmy * 721 /1000] [expr $cmx * 238 /1000] [expr $cmy * 725 /1000] -fill gray -width 1.000000 -capstyle round
eval $can create text [expr $cmx * 836 /1000] [expr $cmy * 494 /1000] -text \{ 2.5e+03\} -fill red -anchor e [expr [info exists font]?"-font \$font":{}]
$can create line [expr $cmx * 852 /1000] [expr $cmy * 494 /1000] [expr $cmx * 934 /1000] [expr $cmy * 494 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 754 /1000] [expr $cmy * 638 /1000] [expr $cmx * 751 /1000] [expr $cmy * 641 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 751 /1000] [expr $cmy * 641 /1000] [expr $cmx * 748 /1000] [expr $cmy * 645 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 748 /1000] [expr $cmy * 645 /1000] [expr $cmx * 745 /1000] [expr $cmy * 648 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 745 /1000] [expr $cmy * 648 /1000] [expr $cmx * 742 /1000] [expr $cmy * 651 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 742 /1000] [expr $cmy * 651 /1000] [expr $cmx * 739 /1000] [expr $cmy * 655 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 739 /1000] [expr $cmy * 655 /1000] [expr $cmx * 737 /1000] [expr $cmy * 659 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 737 /1000] [expr $cmy * 659 /1000] [expr $cmx * 734 /1000] [expr $cmy * 663 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 734 /1000] [expr $cmy * 663 /1000] [expr $cmx * 732 /1000] [expr $cmy * 667 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 732 /1000] [expr $cmy * 667 /1000] [expr $cmx * 730 /1000] [expr $cmy * 671 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 730 /1000] [expr $cmy * 671 /1000] [expr $cmx * 728 /1000] [expr $cmy * 675 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 728 /1000] [expr $cmy * 675 /1000] [expr $cmx * 726 /1000] [expr $cmy * 680 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 726 /1000] [expr $cmy * 680 /1000] [expr $cmx * 724 /1000] [expr $cmy * 685 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 724 /1000] [expr $cmy * 685 /1000] [expr $cmx * 723 /1000] [expr $cmy * 690 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 723 /1000] [expr $cmy * 690 /1000] [expr $cmx * 722 /1000] [expr $cmy * 695 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 722 /1000] [expr $cmy * 695 /1000] [expr $cmx * 721 /1000] [expr $cmy * 701 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 721 /1000] [expr $cmy * 701 /1000] [expr $cmx * 720 /1000] [expr $cmy * 707 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 720 /1000] [expr $cmy * 707 /1000] [expr $cmx * 720 /1000] [expr $cmy * 714 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 720 /1000] [expr $cmy * 714 /1000] [expr $cmx * 720 /1000] [expr $cmy * 721 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 720 /1000] [expr $cmy * 721 /1000] [expr $cmx * 721 /1000] [expr $cmy * 728 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 721 /1000] [expr $cmy * 728 /1000] [expr $cmx * 723 /1000] [expr $cmy * 736 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 723 /1000] [expr $cmy * 736 /1000] [expr $cmx * 725 /1000] [expr $cmy * 745 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 725 /1000] [expr $cmy * 745 /1000] [expr $cmx * 727 /1000] [expr $cmy * 755 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 727 /1000] [expr $cmy * 755 /1000] [expr $cmx * 731 /1000] [expr $cmy * 765 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 731 /1000] [expr $cmy * 765 /1000] [expr $cmx * 735 /1000] [expr $cmy * 777 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 735 /1000] [expr $cmy * 777 /1000] [expr $cmx * 739 /1000] [expr $cmy * 787 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 309 /1000] [expr $cmy * 803 /1000] [expr $cmx * 315 /1000] [expr $cmy * 803 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 315 /1000] [expr $cmy * 803 /1000] [expr $cmx * 321 /1000] [expr $cmy * 803 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 321 /1000] [expr $cmy * 803 /1000] [expr $cmx * 327 /1000] [expr $cmy * 803 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 327 /1000] [expr $cmy * 803 /1000] [expr $cmx * 333 /1000] [expr $cmy * 803 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 333 /1000] [expr $cmy * 803 /1000] [expr $cmx * 339 /1000] [expr $cmy * 803 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 339 /1000] [expr $cmy * 803 /1000] [expr $cmx * 346 /1000] [expr $cmy * 804 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 346 /1000] [expr $cmy * 804 /1000] [expr $cmx * 352 /1000] [expr $cmy * 804 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 352 /1000] [expr $cmy * 804 /1000] [expr $cmx * 359 /1000] [expr $cmy * 805 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 359 /1000] [expr $cmy * 805 /1000] [expr $cmx * 365 /1000] [expr $cmy * 806 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 365 /1000] [expr $cmy * 806 /1000] [expr $cmx * 372 /1000] [expr $cmy * 807 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 372 /1000] [expr $cmy * 807 /1000] [expr $cmx * 379 /1000] [expr $cmy * 808 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 379 /1000] [expr $cmy * 808 /1000] [expr $cmx * 387 /1000] [expr $cmy * 810 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 387 /1000] [expr $cmy * 810 /1000] [expr $cmx * 394 /1000] [expr $cmy * 811 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 394 /1000] [expr $cmy * 811 /1000] [expr $cmx * 402 /1000] [expr $cmy * 814 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 402 /1000] [expr $cmy * 814 /1000] [expr $cmx * 411 /1000] [expr $cmy * 816 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 411 /1000] [expr $cmy * 816 /1000] [expr $cmx * 419 /1000] [expr $cmy * 819 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 419 /1000] [expr $cmy * 819 /1000] [expr $cmx * 428 /1000] [expr $cmy * 822 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 428 /1000] [expr $cmy * 822 /1000] [expr $cmx * 437 /1000] [expr $cmy * 826 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 437 /1000] [expr $cmy * 826 /1000] [expr $cmx * 447 /1000] [expr $cmy * 830 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 447 /1000] [expr $cmy * 830 /1000] [expr $cmx * 457 /1000] [expr $cmy * 835 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 457 /1000] [expr $cmy * 835 /1000] [expr $cmx * 468 /1000] [expr $cmy * 840 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 468 /1000] [expr $cmy * 840 /1000] [expr $cmx * 480 /1000] [expr $cmy * 846 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 480 /1000] [expr $cmy * 846 /1000] [expr $cmx * 492 /1000] [expr $cmy * 854 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 492 /1000] [expr $cmy * 854 /1000] [expr $cmx * 506 /1000] [expr $cmy * 862 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 506 /1000] [expr $cmy * 862 /1000] [expr $cmx * 517 /1000] [expr $cmy * 869 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 482 /1000] [expr $cmy * 501 /1000] [expr $cmx * 493 /1000] [expr $cmy * 508 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 493 /1000] [expr $cmy * 508 /1000] [expr $cmx * 507 /1000] [expr $cmy * 516 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 507 /1000] [expr $cmy * 516 /1000] [expr $cmx * 519 /1000] [expr $cmy * 524 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 519 /1000] [expr $cmy * 524 /1000] [expr $cmx * 531 /1000] [expr $cmy * 530 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 531 /1000] [expr $cmy * 530 /1000] [expr $cmx * 542 /1000] [expr $cmy * 535 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 542 /1000] [expr $cmy * 535 /1000] [expr $cmx * 552 /1000] [expr $cmy * 540 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 552 /1000] [expr $cmy * 540 /1000] [expr $cmx * 562 /1000] [expr $cmy * 544 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 562 /1000] [expr $cmy * 544 /1000] [expr $cmx * 571 /1000] [expr $cmy * 548 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 571 /1000] [expr $cmy * 548 /1000] [expr $cmx * 580 /1000] [expr $cmy * 551 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 580 /1000] [expr $cmy * 551 /1000] [expr $cmx * 588 /1000] [expr $cmy * 554 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 588 /1000] [expr $cmy * 554 /1000] [expr $cmx * 597 /1000] [expr $cmy * 556 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 597 /1000] [expr $cmy * 556 /1000] [expr $cmx * 605 /1000] [expr $cmy * 559 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 605 /1000] [expr $cmy * 559 /1000] [expr $cmx * 612 /1000] [expr $cmy * 560 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 612 /1000] [expr $cmy * 560 /1000] [expr $cmx * 620 /1000] [expr $cmy * 562 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 620 /1000] [expr $cmy * 562 /1000] [expr $cmx * 627 /1000] [expr $cmy * 563 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 627 /1000] [expr $cmy * 563 /1000] [expr $cmx * 634 /1000] [expr $cmy * 564 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 634 /1000] [expr $cmy * 564 /1000] [expr $cmx * 640 /1000] [expr $cmy * 565 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 640 /1000] [expr $cmy * 565 /1000] [expr $cmx * 647 /1000] [expr $cmy * 566 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 647 /1000] [expr $cmy * 566 /1000] [expr $cmx * 653 /1000] [expr $cmy * 566 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 653 /1000] [expr $cmy * 566 /1000] [expr $cmx * 660 /1000] [expr $cmy * 567 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 660 /1000] [expr $cmy * 567 /1000] [expr $cmx * 666 /1000] [expr $cmy * 567 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 666 /1000] [expr $cmy * 567 /1000] [expr $cmx * 672 /1000] [expr $cmy * 567 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 672 /1000] [expr $cmy * 567 /1000] [expr $cmx * 678 /1000] [expr $cmy * 567 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 678 /1000] [expr $cmy * 567 /1000] [expr $cmx * 684 /1000] [expr $cmy * 567 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 684 /1000] [expr $cmy * 567 /1000] [expr $cmx * 690 /1000] [expr $cmy * 567 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 260 /1000] [expr $cmy * 583 /1000] [expr $cmx * 264 /1000] [expr $cmy * 593 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 264 /1000] [expr $cmy * 593 /1000] [expr $cmx * 268 /1000] [expr $cmy * 605 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 268 /1000] [expr $cmy * 605 /1000] [expr $cmx * 272 /1000] [expr $cmy * 615 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 272 /1000] [expr $cmy * 615 /1000] [expr $cmx * 274 /1000] [expr $cmy * 625 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 274 /1000] [expr $cmy * 625 /1000] [expr $cmx * 276 /1000] [expr $cmy * 634 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 276 /1000] [expr $cmy * 634 /1000] [expr $cmx * 278 /1000] [expr $cmy * 642 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 278 /1000] [expr $cmy * 642 /1000] [expr $cmx * 279 /1000] [expr $cmy * 649 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 279 /1000] [expr $cmy * 649 /1000] [expr $cmx * 279 /1000] [expr $cmy * 656 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 279 /1000] [expr $cmy * 656 /1000] [expr $cmx * 279 /1000] [expr $cmy * 663 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 279 /1000] [expr $cmy * 663 /1000] [expr $cmx * 278 /1000] [expr $cmy * 669 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 278 /1000] [expr $cmy * 669 /1000] [expr $cmx * 277 /1000] [expr $cmy * 675 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 277 /1000] [expr $cmy * 675 /1000] [expr $cmx * 276 /1000] [expr $cmy * 680 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 276 /1000] [expr $cmy * 680 /1000] [expr $cmx * 275 /1000] [expr $cmy * 685 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 275 /1000] [expr $cmy * 685 /1000] [expr $cmx * 273 /1000] [expr $cmy * 690 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 273 /1000] [expr $cmy * 690 /1000] [expr $cmx * 271 /1000] [expr $cmy * 695 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 271 /1000] [expr $cmy * 695 /1000] [expr $cmx * 269 /1000] [expr $cmy * 699 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 269 /1000] [expr $cmy * 699 /1000] [expr $cmx * 267 /1000] [expr $cmy * 703 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 267 /1000] [expr $cmy * 703 /1000] [expr $cmx * 265 /1000] [expr $cmy * 707 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 265 /1000] [expr $cmy * 707 /1000] [expr $cmx * 262 /1000] [expr $cmy * 711 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 262 /1000] [expr $cmy * 711 /1000] [expr $cmx * 260 /1000] [expr $cmy * 715 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 260 /1000] [expr $cmy * 715 /1000] [expr $cmx * 257 /1000] [expr $cmy * 719 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 257 /1000] [expr $cmy * 719 /1000] [expr $cmx * 254 /1000] [expr $cmy * 722 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 254 /1000] [expr $cmy * 722 /1000] [expr $cmx * 251 /1000] [expr $cmy * 725 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 251 /1000] [expr $cmy * 725 /1000] [expr $cmx * 248 /1000] [expr $cmy * 729 /1000] -fill red -width 1.000000 -capstyle round
$can create line [expr $cmx * 248 /1000] [expr $cmy * 729 /1000] [expr $cmx * 245 /1000] [expr $cmy * 732 /1000] -fill red -width 1.000000 -capstyle round
eval $can create text [expr $cmx * 836 /1000] [expr $cmy * 519 /1000] -text \{   2e+03\} -fill blue -anchor e [expr [info exists font]?"-font \$font":{}]
$can create line [expr $cmx * 852 /1000] [expr $cmy * 519 /1000] [expr $cmx * 934 /1000] [expr $cmy * 519 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 748 /1000] [expr $cmy * 631 /1000] [expr $cmx * 744 /1000] [expr $cmy * 634 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 744 /1000] [expr $cmy * 634 /1000] [expr $cmx * 741 /1000] [expr $cmy * 637 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 741 /1000] [expr $cmy * 637 /1000] [expr $cmx * 738 /1000] [expr $cmy * 640 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 738 /1000] [expr $cmy * 640 /1000] [expr $cmx * 735 /1000] [expr $cmy * 643 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 735 /1000] [expr $cmy * 643 /1000] [expr $cmx * 731 /1000] [expr $cmy * 646 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 731 /1000] [expr $cmy * 646 /1000] [expr $cmx * 728 /1000] [expr $cmy * 650 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 728 /1000] [expr $cmy * 650 /1000] [expr $cmx * 725 /1000] [expr $cmy * 653 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 725 /1000] [expr $cmy * 653 /1000] [expr $cmx * 723 /1000] [expr $cmy * 657 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 723 /1000] [expr $cmy * 657 /1000] [expr $cmx * 720 /1000] [expr $cmy * 660 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 720 /1000] [expr $cmy * 660 /1000] [expr $cmx * 717 /1000] [expr $cmy * 664 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 717 /1000] [expr $cmy * 664 /1000] [expr $cmx * 715 /1000] [expr $cmy * 668 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 715 /1000] [expr $cmy * 668 /1000] [expr $cmx * 713 /1000] [expr $cmy * 672 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 713 /1000] [expr $cmy * 672 /1000] [expr $cmx * 711 /1000] [expr $cmy * 677 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 711 /1000] [expr $cmy * 677 /1000] [expr $cmx * 709 /1000] [expr $cmy * 681 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 709 /1000] [expr $cmy * 681 /1000] [expr $cmx * 708 /1000] [expr $cmy * 686 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 708 /1000] [expr $cmy * 686 /1000] [expr $cmx * 706 /1000] [expr $cmy * 692 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 706 /1000] [expr $cmy * 692 /1000] [expr $cmx * 705 /1000] [expr $cmy * 697 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 705 /1000] [expr $cmy * 697 /1000] [expr $cmx * 705 /1000] [expr $cmy * 703 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 705 /1000] [expr $cmy * 703 /1000] [expr $cmx * 704 /1000] [expr $cmy * 709 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 704 /1000] [expr $cmy * 709 /1000] [expr $cmx * 705 /1000] [expr $cmy * 716 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 705 /1000] [expr $cmy * 716 /1000] [expr $cmx * 705 /1000] [expr $cmy * 724 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 705 /1000] [expr $cmy * 724 /1000] [expr $cmx * 706 /1000] [expr $cmy * 732 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 706 /1000] [expr $cmy * 732 /1000] [expr $cmx * 708 /1000] [expr $cmy * 740 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 708 /1000] [expr $cmy * 740 /1000] [expr $cmx * 711 /1000] [expr $cmy * 750 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 711 /1000] [expr $cmy * 750 /1000] [expr $cmx * 715 /1000] [expr $cmy * 761 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 715 /1000] [expr $cmy * 761 /1000] [expr $cmx * 719 /1000] [expr $cmy * 773 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 719 /1000] [expr $cmy * 773 /1000] [expr $cmx * 725 /1000] [expr $cmy * 786 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 725 /1000] [expr $cmy * 786 /1000] [expr $cmx * 728 /1000] [expr $cmy * 791 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 303 /1000] [expr $cmy * 796 /1000] [expr $cmx * 308 /1000] [expr $cmy * 796 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 308 /1000] [expr $cmy * 796 /1000] [expr $cmx * 314 /1000] [expr $cmy * 795 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 314 /1000] [expr $cmy * 795 /1000] [expr $cmx * 320 /1000] [expr $cmy * 795 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 320 /1000] [expr $cmy * 795 /1000] [expr $cmx * 325 /1000] [expr $cmy * 795 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 325 /1000] [expr $cmy * 795 /1000] [expr $cmx * 331 /1000] [expr $cmy * 794 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 331 /1000] [expr $cmy * 794 /1000] [expr $cmx * 337 /1000] [expr $cmy * 794 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 337 /1000] [expr $cmy * 794 /1000] [expr $cmx * 343 /1000] [expr $cmy * 795 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 343 /1000] [expr $cmy * 795 /1000] [expr $cmx * 349 /1000] [expr $cmy * 795 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 349 /1000] [expr $cmy * 795 /1000] [expr $cmx * 356 /1000] [expr $cmy * 795 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 356 /1000] [expr $cmy * 795 /1000] [expr $cmx * 362 /1000] [expr $cmy * 796 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 362 /1000] [expr $cmy * 796 /1000] [expr $cmx * 369 /1000] [expr $cmy * 796 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 369 /1000] [expr $cmy * 796 /1000] [expr $cmx * 376 /1000] [expr $cmy * 797 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 376 /1000] [expr $cmy * 797 /1000] [expr $cmx * 383 /1000] [expr $cmy * 798 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 383 /1000] [expr $cmy * 798 /1000] [expr $cmx * 390 /1000] [expr $cmy * 800 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 390 /1000] [expr $cmy * 800 /1000] [expr $cmx * 397 /1000] [expr $cmy * 801 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 397 /1000] [expr $cmy * 801 /1000] [expr $cmx * 405 /1000] [expr $cmy * 803 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 405 /1000] [expr $cmy * 803 /1000] [expr $cmx * 413 /1000] [expr $cmy * 805 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 413 /1000] [expr $cmy * 805 /1000] [expr $cmx * 421 /1000] [expr $cmy * 808 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 421 /1000] [expr $cmy * 808 /1000] [expr $cmx * 430 /1000] [expr $cmy * 811 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 430 /1000] [expr $cmy * 811 /1000] [expr $cmx * 439 /1000] [expr $cmy * 815 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 439 /1000] [expr $cmy * 815 /1000] [expr $cmx * 449 /1000] [expr $cmy * 819 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 449 /1000] [expr $cmy * 819 /1000] [expr $cmx * 459 /1000] [expr $cmy * 823 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 459 /1000] [expr $cmy * 823 /1000] [expr $cmx * 470 /1000] [expr $cmy * 829 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 470 /1000] [expr $cmy * 829 /1000] [expr $cmx * 482 /1000] [expr $cmy * 835 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 482 /1000] [expr $cmy * 835 /1000] [expr $cmx * 494 /1000] [expr $cmy * 842 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 494 /1000] [expr $cmy * 842 /1000] [expr $cmx * 508 /1000] [expr $cmy * 851 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 508 /1000] [expr $cmy * 851 /1000] [expr $cmx * 523 /1000] [expr $cmy * 861 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 523 /1000] [expr $cmy * 861 /1000] [expr $cmx * 528 /1000] [expr $cmy * 865 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 471 /1000] [expr $cmy * 505 /1000] [expr $cmx * 476 /1000] [expr $cmy * 509 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 476 /1000] [expr $cmy * 509 /1000] [expr $cmx * 491 /1000] [expr $cmy * 519 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 491 /1000] [expr $cmy * 519 /1000] [expr $cmx * 505 /1000] [expr $cmy * 528 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 505 /1000] [expr $cmy * 528 /1000] [expr $cmx * 517 /1000] [expr $cmy * 535 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 517 /1000] [expr $cmy * 535 /1000] [expr $cmx * 529 /1000] [expr $cmy * 541 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 529 /1000] [expr $cmy * 541 /1000] [expr $cmx * 540 /1000] [expr $cmy * 547 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 540 /1000] [expr $cmy * 547 /1000] [expr $cmx * 550 /1000] [expr $cmy * 551 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 550 /1000] [expr $cmy * 551 /1000] [expr $cmx * 560 /1000] [expr $cmy * 555 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 560 /1000] [expr $cmy * 555 /1000] [expr $cmx * 569 /1000] [expr $cmy * 559 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 569 /1000] [expr $cmy * 559 /1000] [expr $cmx * 578 /1000] [expr $cmy * 562 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 578 /1000] [expr $cmy * 562 /1000] [expr $cmx * 586 /1000] [expr $cmy * 565 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 586 /1000] [expr $cmy * 565 /1000] [expr $cmx * 594 /1000] [expr $cmy * 567 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 594 /1000] [expr $cmy * 567 /1000] [expr $cmx * 602 /1000] [expr $cmy * 569 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 602 /1000] [expr $cmy * 569 /1000] [expr $cmx * 609 /1000] [expr $cmy * 570 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 609 /1000] [expr $cmy * 570 /1000] [expr $cmx * 616 /1000] [expr $cmy * 572 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 616 /1000] [expr $cmy * 572 /1000] [expr $cmx * 623 /1000] [expr $cmy * 573 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 623 /1000] [expr $cmy * 573 /1000] [expr $cmx * 630 /1000] [expr $cmy * 574 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 630 /1000] [expr $cmy * 574 /1000] [expr $cmx * 637 /1000] [expr $cmy * 574 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 637 /1000] [expr $cmy * 574 /1000] [expr $cmx * 643 /1000] [expr $cmy * 575 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 643 /1000] [expr $cmy * 575 /1000] [expr $cmx * 650 /1000] [expr $cmy * 575 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 650 /1000] [expr $cmy * 575 /1000] [expr $cmx * 656 /1000] [expr $cmy * 575 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 656 /1000] [expr $cmy * 575 /1000] [expr $cmx * 662 /1000] [expr $cmy * 576 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 662 /1000] [expr $cmy * 576 /1000] [expr $cmx * 668 /1000] [expr $cmy * 576 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 668 /1000] [expr $cmy * 576 /1000] [expr $cmx * 674 /1000] [expr $cmy * 575 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 674 /1000] [expr $cmy * 575 /1000] [expr $cmx * 679 /1000] [expr $cmy * 575 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 679 /1000] [expr $cmy * 575 /1000] [expr $cmx * 685 /1000] [expr $cmy * 575 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 685 /1000] [expr $cmy * 575 /1000] [expr $cmx * 691 /1000] [expr $cmy * 574 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 691 /1000] [expr $cmy * 574 /1000] [expr $cmx * 696 /1000] [expr $cmy * 574 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 271 /1000] [expr $cmy * 579 /1000] [expr $cmx * 274 /1000] [expr $cmy * 584 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 274 /1000] [expr $cmy * 584 /1000] [expr $cmx * 280 /1000] [expr $cmy * 597 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 280 /1000] [expr $cmy * 597 /1000] [expr $cmx * 284 /1000] [expr $cmy * 609 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 284 /1000] [expr $cmy * 609 /1000] [expr $cmx * 288 /1000] [expr $cmy * 620 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 288 /1000] [expr $cmy * 620 /1000] [expr $cmx * 291 /1000] [expr $cmy * 629 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 291 /1000] [expr $cmy * 629 /1000] [expr $cmx * 293 /1000] [expr $cmy * 638 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 293 /1000] [expr $cmy * 638 /1000] [expr $cmx * 294 /1000] [expr $cmy * 646 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 294 /1000] [expr $cmy * 646 /1000] [expr $cmx * 294 /1000] [expr $cmy * 654 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 294 /1000] [expr $cmy * 654 /1000] [expr $cmx * 295 /1000] [expr $cmy * 661 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 295 /1000] [expr $cmy * 661 /1000] [expr $cmx * 294 /1000] [expr $cmy * 667 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 294 /1000] [expr $cmy * 667 /1000] [expr $cmx * 294 /1000] [expr $cmy * 673 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 294 /1000] [expr $cmy * 673 /1000] [expr $cmx * 293 /1000] [expr $cmy * 678 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 293 /1000] [expr $cmy * 678 /1000] [expr $cmx * 291 /1000] [expr $cmy * 684 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 291 /1000] [expr $cmy * 684 /1000] [expr $cmx * 290 /1000] [expr $cmy * 689 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 290 /1000] [expr $cmy * 689 /1000] [expr $cmx * 288 /1000] [expr $cmy * 693 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 288 /1000] [expr $cmy * 693 /1000] [expr $cmx * 286 /1000] [expr $cmy * 698 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 286 /1000] [expr $cmy * 698 /1000] [expr $cmx * 284 /1000] [expr $cmy * 702 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 284 /1000] [expr $cmy * 702 /1000] [expr $cmx * 282 /1000] [expr $cmy * 706 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 282 /1000] [expr $cmy * 706 /1000] [expr $cmx * 279 /1000] [expr $cmy * 710 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 279 /1000] [expr $cmy * 710 /1000] [expr $cmx * 276 /1000] [expr $cmy * 713 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 276 /1000] [expr $cmy * 713 /1000] [expr $cmx * 274 /1000] [expr $cmy * 717 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 274 /1000] [expr $cmy * 717 /1000] [expr $cmx * 271 /1000] [expr $cmy * 720 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 271 /1000] [expr $cmy * 720 /1000] [expr $cmx * 268 /1000] [expr $cmy * 724 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 268 /1000] [expr $cmy * 724 /1000] [expr $cmx * 264 /1000] [expr $cmy * 727 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 264 /1000] [expr $cmy * 727 /1000] [expr $cmx * 261 /1000] [expr $cmy * 730 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 261 /1000] [expr $cmy * 730 /1000] [expr $cmx * 258 /1000] [expr $cmy * 733 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 258 /1000] [expr $cmy * 733 /1000] [expr $cmx * 255 /1000] [expr $cmy * 736 /1000] -fill blue -width 1.000000 -capstyle round
$can create line [expr $cmx * 255 /1000] [expr $cmy * 736 /1000] [expr $cmx * 251 /1000] [expr $cmy * 739 /1000] -fill blue -width 1.000000 -capstyle round
eval $can create text [expr $cmx * 836 /1000] [expr $cmy * 544 /1000] -text \{ 1.5e+03\} -fill green -anchor e [expr [info exists font]?"-font \$font":{}]
$can create line [expr $cmx * 852 /1000] [expr $cmy * 544 /1000] [expr $cmx * 934 /1000] [expr $cmy * 544 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 741 /1000] [expr $cmy * 624 /1000] [expr $cmx * 738 /1000] [expr $cmy * 627 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 738 /1000] [expr $cmy * 627 /1000] [expr $cmx * 734 /1000] [expr $cmy * 629 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 734 /1000] [expr $cmy * 629 /1000] [expr $cmx * 730 /1000] [expr $cmy * 632 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 730 /1000] [expr $cmy * 632 /1000] [expr $cmx * 727 /1000] [expr $cmy * 635 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 727 /1000] [expr $cmy * 635 /1000] [expr $cmx * 723 /1000] [expr $cmy * 637 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 723 /1000] [expr $cmy * 637 /1000] [expr $cmx * 720 /1000] [expr $cmy * 640 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 720 /1000] [expr $cmy * 640 /1000] [expr $cmx * 717 /1000] [expr $cmy * 643 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 717 /1000] [expr $cmy * 643 /1000] [expr $cmx * 714 /1000] [expr $cmy * 646 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 714 /1000] [expr $cmy * 646 /1000] [expr $cmx * 710 /1000] [expr $cmy * 650 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 710 /1000] [expr $cmy * 650 /1000] [expr $cmx * 707 /1000] [expr $cmy * 653 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 707 /1000] [expr $cmy * 653 /1000] [expr $cmx * 704 /1000] [expr $cmy * 656 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 704 /1000] [expr $cmy * 656 /1000] [expr $cmx * 702 /1000] [expr $cmy * 660 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 702 /1000] [expr $cmy * 660 /1000] [expr $cmx * 699 /1000] [expr $cmy * 664 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 699 /1000] [expr $cmy * 664 /1000] [expr $cmx * 697 /1000] [expr $cmy * 668 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 697 /1000] [expr $cmy * 668 /1000] [expr $cmx * 694 /1000] [expr $cmy * 672 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 694 /1000] [expr $cmy * 672 /1000] [expr $cmx * 692 /1000] [expr $cmy * 676 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 692 /1000] [expr $cmy * 676 /1000] [expr $cmx * 690 /1000] [expr $cmy * 681 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 690 /1000] [expr $cmy * 681 /1000] [expr $cmx * 689 /1000] [expr $cmy * 685 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 689 /1000] [expr $cmy * 685 /1000] [expr $cmx * 687 /1000] [expr $cmy * 691 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 687 /1000] [expr $cmy * 691 /1000] [expr $cmx * 686 /1000] [expr $cmy * 696 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 686 /1000] [expr $cmy * 696 /1000] [expr $cmx * 686 /1000] [expr $cmy * 702 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 686 /1000] [expr $cmy * 702 /1000] [expr $cmx * 686 /1000] [expr $cmy * 709 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 686 /1000] [expr $cmy * 709 /1000] [expr $cmx * 686 /1000] [expr $cmy * 716 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 686 /1000] [expr $cmy * 716 /1000] [expr $cmx * 687 /1000] [expr $cmy * 723 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 687 /1000] [expr $cmy * 723 /1000] [expr $cmx * 688 /1000] [expr $cmy * 732 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 688 /1000] [expr $cmy * 732 /1000] [expr $cmx * 691 /1000] [expr $cmy * 741 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 691 /1000] [expr $cmy * 741 /1000] [expr $cmx * 694 /1000] [expr $cmy * 751 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 694 /1000] [expr $cmy * 751 /1000] [expr $cmx * 698 /1000] [expr $cmy * 763 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 698 /1000] [expr $cmy * 763 /1000] [expr $cmx * 704 /1000] [expr $cmy * 776 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 704 /1000] [expr $cmy * 776 /1000] [expr $cmx * 711 /1000] [expr $cmy * 791 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 711 /1000] [expr $cmy * 791 /1000] [expr $cmx * 714 /1000] [expr $cmy * 796 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 296 /1000] [expr $cmy * 789 /1000] [expr $cmx * 302 /1000] [expr $cmy * 788 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 302 /1000] [expr $cmy * 788 /1000] [expr $cmx * 307 /1000] [expr $cmy * 787 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 307 /1000] [expr $cmy * 787 /1000] [expr $cmx * 312 /1000] [expr $cmy * 787 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 312 /1000] [expr $cmy * 787 /1000] [expr $cmx * 318 /1000] [expr $cmy * 786 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 318 /1000] [expr $cmy * 786 /1000] [expr $cmx * 323 /1000] [expr $cmy * 786 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 323 /1000] [expr $cmy * 786 /1000] [expr $cmx * 329 /1000] [expr $cmy * 785 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 329 /1000] [expr $cmy * 785 /1000] [expr $cmx * 335 /1000] [expr $cmy * 785 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 335 /1000] [expr $cmy * 785 /1000] [expr $cmx * 340 /1000] [expr $cmy * 785 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 340 /1000] [expr $cmy * 785 /1000] [expr $cmx * 346 /1000] [expr $cmy * 784 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 346 /1000] [expr $cmy * 784 /1000] [expr $cmx * 352 /1000] [expr $cmy * 784 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 352 /1000] [expr $cmy * 784 /1000] [expr $cmx * 358 /1000] [expr $cmy * 785 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 358 /1000] [expr $cmy * 785 /1000] [expr $cmx * 364 /1000] [expr $cmy * 785 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 364 /1000] [expr $cmy * 785 /1000] [expr $cmx * 371 /1000] [expr $cmy * 785 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 371 /1000] [expr $cmy * 785 /1000] [expr $cmx * 377 /1000] [expr $cmy * 786 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 377 /1000] [expr $cmy * 786 /1000] [expr $cmx * 384 /1000] [expr $cmy * 787 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 384 /1000] [expr $cmy * 787 /1000] [expr $cmx * 391 /1000] [expr $cmy * 788 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 391 /1000] [expr $cmy * 788 /1000] [expr $cmx * 398 /1000] [expr $cmy * 789 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 398 /1000] [expr $cmy * 789 /1000] [expr $cmx * 405 /1000] [expr $cmy * 790 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 405 /1000] [expr $cmy * 790 /1000] [expr $cmx * 413 /1000] [expr $cmy * 792 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 413 /1000] [expr $cmy * 792 /1000] [expr $cmx * 421 /1000] [expr $cmy * 794 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 421 /1000] [expr $cmy * 794 /1000] [expr $cmx * 429 /1000] [expr $cmy * 797 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 429 /1000] [expr $cmy * 797 /1000] [expr $cmx * 438 /1000] [expr $cmy * 800 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 438 /1000] [expr $cmy * 800 /1000] [expr $cmx * 448 /1000] [expr $cmy * 804 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 448 /1000] [expr $cmy * 804 /1000] [expr $cmx * 457 /1000] [expr $cmy * 808 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 457 /1000] [expr $cmy * 808 /1000] [expr $cmx * 468 /1000] [expr $cmy * 813 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 468 /1000] [expr $cmy * 813 /1000] [expr $cmx * 479 /1000] [expr $cmy * 819 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 479 /1000] [expr $cmy * 819 /1000] [expr $cmx * 492 /1000] [expr $cmy * 826 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 492 /1000] [expr $cmy * 826 /1000] [expr $cmx * 505 /1000] [expr $cmy * 834 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 505 /1000] [expr $cmy * 834 /1000] [expr $cmx * 520 /1000] [expr $cmy * 844 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 520 /1000] [expr $cmy * 844 /1000] [expr $cmx * 536 /1000] [expr $cmy * 855 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 536 /1000] [expr $cmy * 855 /1000] [expr $cmx * 542 /1000] [expr $cmy * 860 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 457 /1000] [expr $cmy * 510 /1000] [expr $cmx * 463 /1000] [expr $cmy * 515 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 463 /1000] [expr $cmy * 515 /1000] [expr $cmx * 479 /1000] [expr $cmy * 526 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 479 /1000] [expr $cmy * 526 /1000] [expr $cmx * 494 /1000] [expr $cmy * 536 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 494 /1000] [expr $cmy * 536 /1000] [expr $cmx * 507 /1000] [expr $cmy * 544 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 507 /1000] [expr $cmy * 544 /1000] [expr $cmx * 520 /1000] [expr $cmy * 551 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 520 /1000] [expr $cmy * 551 /1000] [expr $cmx * 531 /1000] [expr $cmy * 557 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 531 /1000] [expr $cmy * 557 /1000] [expr $cmx * 542 /1000] [expr $cmy * 562 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 542 /1000] [expr $cmy * 562 /1000] [expr $cmx * 551 /1000] [expr $cmy * 566 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 551 /1000] [expr $cmy * 566 /1000] [expr $cmx * 561 /1000] [expr $cmy * 570 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 561 /1000] [expr $cmy * 570 /1000] [expr $cmx * 570 /1000] [expr $cmy * 573 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 570 /1000] [expr $cmy * 573 /1000] [expr $cmx * 578 /1000] [expr $cmy * 576 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 578 /1000] [expr $cmy * 576 /1000] [expr $cmx * 586 /1000] [expr $cmy * 578 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 586 /1000] [expr $cmy * 578 /1000] [expr $cmx * 594 /1000] [expr $cmy * 580 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 594 /1000] [expr $cmy * 580 /1000] [expr $cmx * 601 /1000] [expr $cmy * 581 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 601 /1000] [expr $cmy * 581 /1000] [expr $cmx * 608 /1000] [expr $cmy * 582 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 608 /1000] [expr $cmy * 582 /1000] [expr $cmx * 615 /1000] [expr $cmy * 583 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 615 /1000] [expr $cmy * 583 /1000] [expr $cmx * 622 /1000] [expr $cmy * 584 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 622 /1000] [expr $cmy * 584 /1000] [expr $cmx * 628 /1000] [expr $cmy * 585 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 628 /1000] [expr $cmy * 585 /1000] [expr $cmx * 635 /1000] [expr $cmy * 585 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 635 /1000] [expr $cmy * 585 /1000] [expr $cmx * 641 /1000] [expr $cmy * 585 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 641 /1000] [expr $cmy * 585 /1000] [expr $cmx * 647 /1000] [expr $cmy * 586 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 647 /1000] [expr $cmy * 586 /1000] [expr $cmx * 653 /1000] [expr $cmy * 586 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 653 /1000] [expr $cmy * 586 /1000] [expr $cmx * 659 /1000] [expr $cmy * 585 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 659 /1000] [expr $cmy * 585 /1000] [expr $cmx * 664 /1000] [expr $cmy * 585 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 664 /1000] [expr $cmy * 585 /1000] [expr $cmx * 670 /1000] [expr $cmy * 585 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 670 /1000] [expr $cmy * 585 /1000] [expr $cmx * 676 /1000] [expr $cmy * 584 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 676 /1000] [expr $cmy * 584 /1000] [expr $cmx * 681 /1000] [expr $cmy * 584 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 681 /1000] [expr $cmy * 584 /1000] [expr $cmx * 687 /1000] [expr $cmy * 583 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 687 /1000] [expr $cmy * 583 /1000] [expr $cmx * 692 /1000] [expr $cmy * 583 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 692 /1000] [expr $cmy * 583 /1000] [expr $cmx * 697 /1000] [expr $cmy * 582 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 697 /1000] [expr $cmy * 582 /1000] [expr $cmx * 703 /1000] [expr $cmy * 581 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 285 /1000] [expr $cmy * 574 /1000] [expr $cmx * 288 /1000] [expr $cmy * 579 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 288 /1000] [expr $cmy * 579 /1000] [expr $cmx * 295 /1000] [expr $cmy * 594 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 295 /1000] [expr $cmy * 594 /1000] [expr $cmx * 301 /1000] [expr $cmy * 607 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 301 /1000] [expr $cmy * 607 /1000] [expr $cmx * 305 /1000] [expr $cmy * 619 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 305 /1000] [expr $cmy * 619 /1000] [expr $cmx * 308 /1000] [expr $cmy * 629 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 308 /1000] [expr $cmy * 629 /1000] [expr $cmx * 311 /1000] [expr $cmy * 638 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 311 /1000] [expr $cmy * 638 /1000] [expr $cmx * 312 /1000] [expr $cmy * 647 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 312 /1000] [expr $cmy * 647 /1000] [expr $cmx * 313 /1000] [expr $cmy * 654 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 313 /1000] [expr $cmy * 654 /1000] [expr $cmx * 313 /1000] [expr $cmy * 661 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 313 /1000] [expr $cmy * 661 /1000] [expr $cmx * 313 /1000] [expr $cmy * 668 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 313 /1000] [expr $cmy * 668 /1000] [expr $cmx * 313 /1000] [expr $cmy * 674 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 313 /1000] [expr $cmy * 674 /1000] [expr $cmx * 312 /1000] [expr $cmy * 679 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 312 /1000] [expr $cmy * 679 /1000] [expr $cmx * 310 /1000] [expr $cmy * 685 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 310 /1000] [expr $cmy * 685 /1000] [expr $cmx * 309 /1000] [expr $cmy * 689 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 309 /1000] [expr $cmy * 689 /1000] [expr $cmx * 307 /1000] [expr $cmy * 694 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 307 /1000] [expr $cmy * 694 /1000] [expr $cmx * 305 /1000] [expr $cmy * 698 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 305 /1000] [expr $cmy * 698 /1000] [expr $cmx * 302 /1000] [expr $cmy * 702 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 302 /1000] [expr $cmy * 702 /1000] [expr $cmx * 300 /1000] [expr $cmy * 706 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 300 /1000] [expr $cmy * 706 /1000] [expr $cmx * 297 /1000] [expr $cmy * 710 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 297 /1000] [expr $cmy * 710 /1000] [expr $cmx * 295 /1000] [expr $cmy * 714 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 295 /1000] [expr $cmy * 714 /1000] [expr $cmx * 292 /1000] [expr $cmy * 717 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 292 /1000] [expr $cmy * 717 /1000] [expr $cmx * 289 /1000] [expr $cmy * 720 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 289 /1000] [expr $cmy * 720 /1000] [expr $cmx * 285 /1000] [expr $cmy * 724 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 285 /1000] [expr $cmy * 724 /1000] [expr $cmx * 282 /1000] [expr $cmy * 727 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 282 /1000] [expr $cmy * 727 /1000] [expr $cmx * 279 /1000] [expr $cmy * 730 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 279 /1000] [expr $cmy * 730 /1000] [expr $cmx * 276 /1000] [expr $cmy * 733 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 276 /1000] [expr $cmy * 733 /1000] [expr $cmx * 272 /1000] [expr $cmy * 735 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 272 /1000] [expr $cmy * 735 /1000] [expr $cmx * 269 /1000] [expr $cmy * 738 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 269 /1000] [expr $cmy * 738 /1000] [expr $cmx * 265 /1000] [expr $cmy * 741 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 265 /1000] [expr $cmy * 741 /1000] [expr $cmx * 261 /1000] [expr $cmy * 743 /1000] -fill green -width 1.000000 -capstyle round
$can create line [expr $cmx * 261 /1000] [expr $cmy * 743 /1000] [expr $cmx * 258 /1000] [expr $cmy * 746 /1000] -fill green -width 1.000000 -capstyle round
eval $can create text [expr $cmx * 836 /1000] [expr $cmy * 569 /1000] -text \{   1e+03\} -fill brown -anchor e [expr [info exists font]?"-font \$font":{}]
$can create line [expr $cmx * 852 /1000] [expr $cmy * 569 /1000] [expr $cmx * 934 /1000] [expr $cmy * 569 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 735 /1000] [expr $cmy * 617 /1000] [expr $cmx * 731 /1000] [expr $cmy * 619 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 731 /1000] [expr $cmy * 619 /1000] [expr $cmx * 727 /1000] [expr $cmy * 621 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 727 /1000] [expr $cmy * 621 /1000] [expr $cmx * 723 /1000] [expr $cmy * 624 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 723 /1000] [expr $cmy * 624 /1000] [expr $cmx * 719 /1000] [expr $cmy * 626 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 719 /1000] [expr $cmy * 626 /1000] [expr $cmx * 715 /1000] [expr $cmy * 629 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 715 /1000] [expr $cmy * 629 /1000] [expr $cmx * 712 /1000] [expr $cmy * 631 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 712 /1000] [expr $cmy * 631 /1000] [expr $cmx * 708 /1000] [expr $cmy * 634 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 708 /1000] [expr $cmy * 634 /1000] [expr $cmx * 704 /1000] [expr $cmy * 636 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 704 /1000] [expr $cmy * 636 /1000] [expr $cmx * 701 /1000] [expr $cmy * 639 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 701 /1000] [expr $cmy * 639 /1000] [expr $cmx * 697 /1000] [expr $cmy * 642 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 697 /1000] [expr $cmy * 642 /1000] [expr $cmx * 694 /1000] [expr $cmy * 644 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 694 /1000] [expr $cmy * 644 /1000] [expr $cmx * 691 /1000] [expr $cmy * 647 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 691 /1000] [expr $cmy * 647 /1000] [expr $cmx * 687 /1000] [expr $cmy * 650 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 687 /1000] [expr $cmy * 650 /1000] [expr $cmx * 684 /1000] [expr $cmy * 654 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 684 /1000] [expr $cmy * 654 /1000] [expr $cmx * 681 /1000] [expr $cmy * 657 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 681 /1000] [expr $cmy * 657 /1000] [expr $cmx * 678 /1000] [expr $cmy * 660 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 678 /1000] [expr $cmy * 660 /1000] [expr $cmx * 675 /1000] [expr $cmy * 664 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 675 /1000] [expr $cmy * 664 /1000] [expr $cmx * 673 /1000] [expr $cmy * 668 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 673 /1000] [expr $cmy * 668 /1000] [expr $cmx * 670 /1000] [expr $cmy * 672 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 670 /1000] [expr $cmy * 672 /1000] [expr $cmx * 668 /1000] [expr $cmy * 676 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 668 /1000] [expr $cmy * 676 /1000] [expr $cmx * 666 /1000] [expr $cmy * 681 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 666 /1000] [expr $cmy * 681 /1000] [expr $cmx * 665 /1000] [expr $cmy * 685 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 665 /1000] [expr $cmy * 685 /1000] [expr $cmx * 663 /1000] [expr $cmy * 691 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 663 /1000] [expr $cmy * 691 /1000] [expr $cmx * 663 /1000] [expr $cmy * 696 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 663 /1000] [expr $cmy * 696 /1000] [expr $cmx * 662 /1000] [expr $cmy * 702 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 662 /1000] [expr $cmy * 702 /1000] [expr $cmx * 662 /1000] [expr $cmy * 709 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 662 /1000] [expr $cmy * 709 /1000] [expr $cmx * 663 /1000] [expr $cmy * 717 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 663 /1000] [expr $cmy * 717 /1000] [expr $cmx * 664 /1000] [expr $cmy * 725 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 664 /1000] [expr $cmy * 725 /1000] [expr $cmx * 667 /1000] [expr $cmy * 734 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 667 /1000] [expr $cmy * 734 /1000] [expr $cmx * 670 /1000] [expr $cmy * 745 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 670 /1000] [expr $cmy * 745 /1000] [expr $cmx * 675 /1000] [expr $cmy * 756 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 675 /1000] [expr $cmy * 756 /1000] [expr $cmx * 681 /1000] [expr $cmy * 770 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 681 /1000] [expr $cmy * 770 /1000] [expr $cmx * 689 /1000] [expr $cmy * 786 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 689 /1000] [expr $cmy * 786 /1000] [expr $cmx * 698 /1000] [expr $cmy * 802 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 290 /1000] [expr $cmy * 782 /1000] [expr $cmx * 295 /1000] [expr $cmy * 781 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 295 /1000] [expr $cmy * 781 /1000] [expr $cmx * 300 /1000] [expr $cmy * 780 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 300 /1000] [expr $cmy * 780 /1000] [expr $cmx * 305 /1000] [expr $cmy * 779 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 305 /1000] [expr $cmy * 779 /1000] [expr $cmx * 310 /1000] [expr $cmy * 778 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 310 /1000] [expr $cmy * 778 /1000] [expr $cmx * 315 /1000] [expr $cmy * 777 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 315 /1000] [expr $cmy * 777 /1000] [expr $cmx * 321 /1000] [expr $cmy * 776 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 321 /1000] [expr $cmy * 776 /1000] [expr $cmx * 326 /1000] [expr $cmy * 775 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 326 /1000] [expr $cmy * 775 /1000] [expr $cmx * 331 /1000] [expr $cmy * 774 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 331 /1000] [expr $cmy * 774 /1000] [expr $cmx * 337 /1000] [expr $cmy * 774 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 337 /1000] [expr $cmy * 774 /1000] [expr $cmx * 342 /1000] [expr $cmy * 773 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 342 /1000] [expr $cmy * 773 /1000] [expr $cmx * 348 /1000] [expr $cmy * 773 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 348 /1000] [expr $cmy * 773 /1000] [expr $cmx * 353 /1000] [expr $cmy * 772 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 353 /1000] [expr $cmy * 772 /1000] [expr $cmx * 359 /1000] [expr $cmy * 772 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 359 /1000] [expr $cmy * 772 /1000] [expr $cmx * 365 /1000] [expr $cmy * 772 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 365 /1000] [expr $cmy * 772 /1000] [expr $cmx * 371 /1000] [expr $cmy * 772 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 371 /1000] [expr $cmy * 772 /1000] [expr $cmx * 377 /1000] [expr $cmy * 772 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 377 /1000] [expr $cmy * 772 /1000] [expr $cmx * 383 /1000] [expr $cmy * 772 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 383 /1000] [expr $cmy * 772 /1000] [expr $cmx * 390 /1000] [expr $cmy * 773 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 390 /1000] [expr $cmy * 773 /1000] [expr $cmx * 396 /1000] [expr $cmy * 773 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 396 /1000] [expr $cmy * 773 /1000] [expr $cmx * 403 /1000] [expr $cmy * 774 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 403 /1000] [expr $cmy * 774 /1000] [expr $cmx * 410 /1000] [expr $cmy * 776 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 410 /1000] [expr $cmy * 776 /1000] [expr $cmx * 417 /1000] [expr $cmy * 777 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 417 /1000] [expr $cmy * 777 /1000] [expr $cmx * 425 /1000] [expr $cmy * 779 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 425 /1000] [expr $cmy * 779 /1000] [expr $cmx * 433 /1000] [expr $cmy * 781 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 433 /1000] [expr $cmy * 781 /1000] [expr $cmx * 442 /1000] [expr $cmy * 784 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 442 /1000] [expr $cmy * 784 /1000] [expr $cmx * 451 /1000] [expr $cmy * 787 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 451 /1000] [expr $cmy * 787 /1000] [expr $cmx * 461 /1000] [expr $cmy * 792 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 461 /1000] [expr $cmy * 792 /1000] [expr $cmx * 471 /1000] [expr $cmy * 796 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 471 /1000] [expr $cmy * 796 /1000] [expr $cmx * 482 /1000] [expr $cmy * 802 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 482 /1000] [expr $cmy * 802 /1000] [expr $cmx * 495 /1000] [expr $cmy * 809 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 495 /1000] [expr $cmy * 809 /1000] [expr $cmx * 508 /1000] [expr $cmy * 818 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 508 /1000] [expr $cmy * 818 /1000] [expr $cmx * 524 /1000] [expr $cmy * 828 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 524 /1000] [expr $cmy * 828 /1000] [expr $cmx * 541 /1000] [expr $cmy * 841 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 541 /1000] [expr $cmy * 841 /1000] [expr $cmx * 558 /1000] [expr $cmy * 854 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 441 /1000] [expr $cmy * 516 /1000] [expr $cmx * 458 /1000] [expr $cmy * 529 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 458 /1000] [expr $cmy * 529 /1000] [expr $cmx * 475 /1000] [expr $cmy * 542 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 475 /1000] [expr $cmy * 542 /1000] [expr $cmx * 491 /1000] [expr $cmy * 552 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 491 /1000] [expr $cmy * 552 /1000] [expr $cmx * 504 /1000] [expr $cmy * 561 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 504 /1000] [expr $cmy * 561 /1000] [expr $cmx * 517 /1000] [expr $cmy * 568 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 517 /1000] [expr $cmy * 568 /1000] [expr $cmx * 528 /1000] [expr $cmy * 573 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 528 /1000] [expr $cmy * 573 /1000] [expr $cmx * 538 /1000] [expr $cmy * 578 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 538 /1000] [expr $cmy * 578 /1000] [expr $cmx * 548 /1000] [expr $cmy * 583 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 548 /1000] [expr $cmy * 583 /1000] [expr $cmx * 557 /1000] [expr $cmy * 586 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 557 /1000] [expr $cmy * 586 /1000] [expr $cmx * 566 /1000] [expr $cmy * 589 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 566 /1000] [expr $cmy * 589 /1000] [expr $cmx * 574 /1000] [expr $cmy * 591 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 574 /1000] [expr $cmy * 591 /1000] [expr $cmx * 582 /1000] [expr $cmy * 593 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 582 /1000] [expr $cmy * 593 /1000] [expr $cmx * 589 /1000] [expr $cmy * 594 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 589 /1000] [expr $cmy * 594 /1000] [expr $cmx * 596 /1000] [expr $cmy * 596 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 596 /1000] [expr $cmy * 596 /1000] [expr $cmx * 603 /1000] [expr $cmy * 597 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 603 /1000] [expr $cmy * 597 /1000] [expr $cmx * 609 /1000] [expr $cmy * 597 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 609 /1000] [expr $cmy * 597 /1000] [expr $cmx * 616 /1000] [expr $cmy * 598 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 616 /1000] [expr $cmy * 598 /1000] [expr $cmx * 622 /1000] [expr $cmy * 598 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 622 /1000] [expr $cmy * 598 /1000] [expr $cmx * 628 /1000] [expr $cmy * 598 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 628 /1000] [expr $cmy * 598 /1000] [expr $cmx * 634 /1000] [expr $cmy * 598 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 634 /1000] [expr $cmy * 598 /1000] [expr $cmx * 640 /1000] [expr $cmy * 598 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 640 /1000] [expr $cmy * 598 /1000] [expr $cmx * 646 /1000] [expr $cmy * 598 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 646 /1000] [expr $cmy * 598 /1000] [expr $cmx * 651 /1000] [expr $cmy * 597 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 651 /1000] [expr $cmy * 597 /1000] [expr $cmx * 657 /1000] [expr $cmy * 597 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 657 /1000] [expr $cmy * 597 /1000] [expr $cmx * 662 /1000] [expr $cmy * 596 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 662 /1000] [expr $cmy * 596 /1000] [expr $cmx * 668 /1000] [expr $cmy * 596 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 668 /1000] [expr $cmy * 596 /1000] [expr $cmx * 673 /1000] [expr $cmy * 595 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 673 /1000] [expr $cmy * 595 /1000] [expr $cmx * 678 /1000] [expr $cmy * 594 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 678 /1000] [expr $cmy * 594 /1000] [expr $cmx * 684 /1000] [expr $cmy * 593 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 684 /1000] [expr $cmy * 593 /1000] [expr $cmx * 689 /1000] [expr $cmy * 592 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 689 /1000] [expr $cmy * 592 /1000] [expr $cmx * 694 /1000] [expr $cmy * 591 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 694 /1000] [expr $cmy * 591 /1000] [expr $cmx * 699 /1000] [expr $cmy * 590 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 699 /1000] [expr $cmy * 590 /1000] [expr $cmx * 704 /1000] [expr $cmy * 589 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 704 /1000] [expr $cmy * 589 /1000] [expr $cmx * 709 /1000] [expr $cmy * 588 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 301 /1000] [expr $cmy * 568 /1000] [expr $cmx * 310 /1000] [expr $cmy * 584 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 310 /1000] [expr $cmy * 584 /1000] [expr $cmx * 318 /1000] [expr $cmy * 600 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 318 /1000] [expr $cmy * 600 /1000] [expr $cmx * 324 /1000] [expr $cmy * 614 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 324 /1000] [expr $cmy * 614 /1000] [expr $cmx * 329 /1000] [expr $cmy * 625 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 329 /1000] [expr $cmy * 625 /1000] [expr $cmx * 332 /1000] [expr $cmy * 636 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 332 /1000] [expr $cmy * 636 /1000] [expr $cmx * 335 /1000] [expr $cmy * 645 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 335 /1000] [expr $cmy * 645 /1000] [expr $cmx * 336 /1000] [expr $cmy * 653 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 336 /1000] [expr $cmy * 653 /1000] [expr $cmx * 337 /1000] [expr $cmy * 661 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 337 /1000] [expr $cmy * 661 /1000] [expr $cmx * 337 /1000] [expr $cmy * 668 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 337 /1000] [expr $cmy * 668 /1000] [expr $cmx * 336 /1000] [expr $cmy * 674 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 336 /1000] [expr $cmy * 674 /1000] [expr $cmx * 336 /1000] [expr $cmy * 679 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 336 /1000] [expr $cmy * 679 /1000] [expr $cmx * 334 /1000] [expr $cmy * 685 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 334 /1000] [expr $cmy * 685 /1000] [expr $cmx * 333 /1000] [expr $cmy * 689 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 333 /1000] [expr $cmy * 689 /1000] [expr $cmx * 331 /1000] [expr $cmy * 694 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 331 /1000] [expr $cmy * 694 /1000] [expr $cmx * 329 /1000] [expr $cmy * 698 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 329 /1000] [expr $cmy * 698 /1000] [expr $cmx * 326 /1000] [expr $cmy * 702 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 326 /1000] [expr $cmy * 702 /1000] [expr $cmx * 324 /1000] [expr $cmy * 706 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 324 /1000] [expr $cmy * 706 /1000] [expr $cmx * 321 /1000] [expr $cmy * 710 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 321 /1000] [expr $cmy * 710 /1000] [expr $cmx * 318 /1000] [expr $cmy * 713 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 318 /1000] [expr $cmy * 713 /1000] [expr $cmx * 315 /1000] [expr $cmy * 716 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 315 /1000] [expr $cmy * 716 /1000] [expr $cmx * 312 /1000] [expr $cmy * 720 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 312 /1000] [expr $cmy * 720 /1000] [expr $cmx * 308 /1000] [expr $cmy * 723 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 308 /1000] [expr $cmy * 723 /1000] [expr $cmx * 305 /1000] [expr $cmy * 726 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 305 /1000] [expr $cmy * 726 /1000] [expr $cmx * 302 /1000] [expr $cmy * 728 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 302 /1000] [expr $cmy * 728 /1000] [expr $cmx * 298 /1000] [expr $cmy * 731 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 298 /1000] [expr $cmy * 731 /1000] [expr $cmx * 295 /1000] [expr $cmy * 734 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 295 /1000] [expr $cmy * 734 /1000] [expr $cmx * 291 /1000] [expr $cmy * 736 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 291 /1000] [expr $cmy * 736 /1000] [expr $cmx * 287 /1000] [expr $cmy * 739 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 287 /1000] [expr $cmy * 739 /1000] [expr $cmx * 284 /1000] [expr $cmy * 741 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 284 /1000] [expr $cmy * 741 /1000] [expr $cmx * 280 /1000] [expr $cmy * 744 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 280 /1000] [expr $cmy * 744 /1000] [expr $cmx * 276 /1000] [expr $cmy * 746 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 276 /1000] [expr $cmy * 746 /1000] [expr $cmx * 272 /1000] [expr $cmy * 749 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 272 /1000] [expr $cmy * 749 /1000] [expr $cmx * 268 /1000] [expr $cmy * 751 /1000] -fill brown -width 1.000000 -capstyle round
$can create line [expr $cmx * 268 /1000] [expr $cmy * 751 /1000] [expr $cmx * 264 /1000] [expr $cmy * 753 /1000] -fill brown -width 1.000000 -capstyle round
eval $can create text [expr $cmx * 836 /1000] [expr $cmy * 594 /1000] -text \{     500\} -fill magenta -anchor e [expr [info exists font]?"-font \$font":{}]
$can create line [expr $cmx * 852 /1000] [expr $cmy * 594 /1000] [expr $cmx * 934 /1000] [expr $cmy * 594 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 728 /1000] [expr $cmy * 610 /1000] [expr $cmx * 724 /1000] [expr $cmy * 612 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 724 /1000] [expr $cmy * 612 /1000] [expr $cmx * 720 /1000] [expr $cmy * 614 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 720 /1000] [expr $cmy * 614 /1000] [expr $cmx * 716 /1000] [expr $cmy * 616 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 716 /1000] [expr $cmy * 616 /1000] [expr $cmx * 712 /1000] [expr $cmy * 618 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 712 /1000] [expr $cmy * 618 /1000] [expr $cmx * 708 /1000] [expr $cmy * 620 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 708 /1000] [expr $cmy * 620 /1000] [expr $cmx * 703 /1000] [expr $cmy * 622 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 703 /1000] [expr $cmy * 622 /1000] [expr $cmx * 699 /1000] [expr $cmy * 624 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 699 /1000] [expr $cmy * 624 /1000] [expr $cmx * 695 /1000] [expr $cmy * 626 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 695 /1000] [expr $cmy * 626 /1000] [expr $cmx * 691 /1000] [expr $cmy * 628 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 691 /1000] [expr $cmy * 628 /1000] [expr $cmx * 687 /1000] [expr $cmy * 630 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 687 /1000] [expr $cmy * 630 /1000] [expr $cmx * 683 /1000] [expr $cmy * 633 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 683 /1000] [expr $cmy * 633 /1000] [expr $cmx * 679 /1000] [expr $cmy * 635 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 679 /1000] [expr $cmy * 635 /1000] [expr $cmx * 675 /1000] [expr $cmy * 637 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 675 /1000] [expr $cmy * 637 /1000] [expr $cmx * 672 /1000] [expr $cmy * 640 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 672 /1000] [expr $cmy * 640 /1000] [expr $cmx * 668 /1000] [expr $cmy * 642 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 668 /1000] [expr $cmy * 642 /1000] [expr $cmx * 664 /1000] [expr $cmy * 645 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 664 /1000] [expr $cmy * 645 /1000] [expr $cmx * 661 /1000] [expr $cmy * 647 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 661 /1000] [expr $cmy * 647 /1000] [expr $cmx * 657 /1000] [expr $cmy * 650 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 657 /1000] [expr $cmy * 650 /1000] [expr $cmx * 654 /1000] [expr $cmy * 653 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 654 /1000] [expr $cmy * 653 /1000] [expr $cmx * 650 /1000] [expr $cmy * 656 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 650 /1000] [expr $cmy * 656 /1000] [expr $cmx * 647 /1000] [expr $cmy * 659 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 647 /1000] [expr $cmy * 659 /1000] [expr $cmx * 644 /1000] [expr $cmy * 662 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 644 /1000] [expr $cmy * 662 /1000] [expr $cmx * 641 /1000] [expr $cmy * 666 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 641 /1000] [expr $cmy * 666 /1000] [expr $cmx * 638 /1000] [expr $cmy * 669 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 638 /1000] [expr $cmy * 669 /1000] [expr $cmx * 636 /1000] [expr $cmy * 673 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 636 /1000] [expr $cmy * 673 /1000] [expr $cmx * 634 /1000] [expr $cmy * 678 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 634 /1000] [expr $cmy * 678 /1000] [expr $cmx * 632 /1000] [expr $cmy * 682 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 632 /1000] [expr $cmy * 682 /1000] [expr $cmx * 630 /1000] [expr $cmy * 687 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 630 /1000] [expr $cmy * 687 /1000] [expr $cmx * 629 /1000] [expr $cmy * 692 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 629 /1000] [expr $cmy * 692 /1000] [expr $cmx * 629 /1000] [expr $cmy * 699 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 629 /1000] [expr $cmy * 699 /1000] [expr $cmx * 629 /1000] [expr $cmy * 705 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 629 /1000] [expr $cmy * 705 /1000] [expr $cmx * 630 /1000] [expr $cmy * 713 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 630 /1000] [expr $cmy * 713 /1000] [expr $cmx * 632 /1000] [expr $cmy * 722 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 632 /1000] [expr $cmy * 722 /1000] [expr $cmx * 635 /1000] [expr $cmy * 732 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 635 /1000] [expr $cmy * 732 /1000] [expr $cmx * 640 /1000] [expr $cmy * 744 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 640 /1000] [expr $cmy * 744 /1000] [expr $cmx * 647 /1000] [expr $cmy * 758 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 647 /1000] [expr $cmy * 758 /1000] [expr $cmx * 656 /1000] [expr $cmy * 776 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 656 /1000] [expr $cmy * 776 /1000] [expr $cmx * 670 /1000] [expr $cmy * 798 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 670 /1000] [expr $cmy * 798 /1000] [expr $cmx * 678 /1000] [expr $cmy * 809 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 283 /1000] [expr $cmy * 775 /1000] [expr $cmx * 288 /1000] [expr $cmy * 773 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 288 /1000] [expr $cmy * 773 /1000] [expr $cmx * 293 /1000] [expr $cmy * 772 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 293 /1000] [expr $cmy * 772 /1000] [expr $cmx * 298 /1000] [expr $cmy * 771 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 298 /1000] [expr $cmy * 771 /1000] [expr $cmx * 303 /1000] [expr $cmy * 769 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 303 /1000] [expr $cmy * 769 /1000] [expr $cmx * 307 /1000] [expr $cmy * 768 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 307 /1000] [expr $cmy * 768 /1000] [expr $cmx * 312 /1000] [expr $cmy * 767 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 312 /1000] [expr $cmy * 767 /1000] [expr $cmx * 317 /1000] [expr $cmy * 765 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 317 /1000] [expr $cmy * 765 /1000] [expr $cmx * 322 /1000] [expr $cmy * 764 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 322 /1000] [expr $cmy * 764 /1000] [expr $cmx * 327 /1000] [expr $cmy * 763 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 327 /1000] [expr $cmy * 763 /1000] [expr $cmx * 332 /1000] [expr $cmy * 762 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 332 /1000] [expr $cmy * 762 /1000] [expr $cmx * 337 /1000] [expr $cmy * 761 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 337 /1000] [expr $cmy * 761 /1000] [expr $cmx * 342 /1000] [expr $cmy * 760 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 342 /1000] [expr $cmy * 760 /1000] [expr $cmx * 347 /1000] [expr $cmy * 759 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 347 /1000] [expr $cmy * 759 /1000] [expr $cmx * 352 /1000] [expr $cmy * 758 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 352 /1000] [expr $cmy * 758 /1000] [expr $cmx * 358 /1000] [expr $cmy * 757 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 358 /1000] [expr $cmy * 757 /1000] [expr $cmx * 363 /1000] [expr $cmy * 756 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 363 /1000] [expr $cmy * 756 /1000] [expr $cmx * 368 /1000] [expr $cmy * 756 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 368 /1000] [expr $cmy * 756 /1000] [expr $cmx * 374 /1000] [expr $cmy * 755 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 374 /1000] [expr $cmy * 755 /1000] [expr $cmx * 379 /1000] [expr $cmy * 755 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 379 /1000] [expr $cmy * 755 /1000] [expr $cmx * 385 /1000] [expr $cmy * 754 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 385 /1000] [expr $cmy * 754 /1000] [expr $cmx * 391 /1000] [expr $cmy * 754 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 391 /1000] [expr $cmy * 754 /1000] [expr $cmx * 397 /1000] [expr $cmy * 754 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 397 /1000] [expr $cmy * 754 /1000] [expr $cmx * 403 /1000] [expr $cmy * 754 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 403 /1000] [expr $cmy * 754 /1000] [expr $cmx * 409 /1000] [expr $cmy * 754 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 409 /1000] [expr $cmy * 754 /1000] [expr $cmx * 416 /1000] [expr $cmy * 755 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 416 /1000] [expr $cmy * 755 /1000] [expr $cmx * 422 /1000] [expr $cmy * 756 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 422 /1000] [expr $cmy * 756 /1000] [expr $cmx * 429 /1000] [expr $cmy * 757 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 429 /1000] [expr $cmy * 757 /1000] [expr $cmx * 437 /1000] [expr $cmy * 759 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 437 /1000] [expr $cmy * 759 /1000] [expr $cmx * 445 /1000] [expr $cmy * 761 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 445 /1000] [expr $cmy * 761 /1000] [expr $cmx * 453 /1000] [expr $cmy * 763 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 453 /1000] [expr $cmy * 763 /1000] [expr $cmx * 462 /1000] [expr $cmy * 767 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 462 /1000] [expr $cmy * 767 /1000] [expr $cmx * 472 /1000] [expr $cmy * 771 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 472 /1000] [expr $cmy * 771 /1000] [expr $cmx * 483 /1000] [expr $cmy * 777 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 483 /1000] [expr $cmy * 777 /1000] [expr $cmx * 495 /1000] [expr $cmy * 784 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 495 /1000] [expr $cmy * 784 /1000] [expr $cmx * 509 /1000] [expr $cmy * 792 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 509 /1000] [expr $cmy * 792 /1000] [expr $cmx * 525 /1000] [expr $cmy * 803 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 525 /1000] [expr $cmy * 803 /1000] [expr $cmx * 544 /1000] [expr $cmy * 818 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 544 /1000] [expr $cmy * 818 /1000] [expr $cmx * 567 /1000] [expr $cmy * 836 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 567 /1000] [expr $cmy * 836 /1000] [expr $cmx * 578 /1000] [expr $cmy * 846 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 421 /1000] [expr $cmy * 524 /1000] [expr $cmx * 432 /1000] [expr $cmy * 534 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 432 /1000] [expr $cmy * 534 /1000] [expr $cmx * 455 /1000] [expr $cmy * 552 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 455 /1000] [expr $cmy * 552 /1000] [expr $cmx * 474 /1000] [expr $cmy * 567 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 474 /1000] [expr $cmy * 567 /1000] [expr $cmx * 490 /1000] [expr $cmy * 578 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 490 /1000] [expr $cmy * 578 /1000] [expr $cmx * 504 /1000] [expr $cmy * 586 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 504 /1000] [expr $cmy * 586 /1000] [expr $cmx * 516 /1000] [expr $cmy * 593 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 516 /1000] [expr $cmy * 593 /1000] [expr $cmx * 527 /1000] [expr $cmy * 599 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 527 /1000] [expr $cmy * 599 /1000] [expr $cmx * 537 /1000] [expr $cmy * 603 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 537 /1000] [expr $cmy * 603 /1000] [expr $cmx * 546 /1000] [expr $cmy * 607 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 546 /1000] [expr $cmy * 607 /1000] [expr $cmx * 554 /1000] [expr $cmy * 609 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 554 /1000] [expr $cmy * 609 /1000] [expr $cmx * 562 /1000] [expr $cmy * 611 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 562 /1000] [expr $cmy * 611 /1000] [expr $cmx * 570 /1000] [expr $cmy * 613 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 570 /1000] [expr $cmy * 613 /1000] [expr $cmx * 577 /1000] [expr $cmy * 614 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 577 /1000] [expr $cmy * 614 /1000] [expr $cmx * 583 /1000] [expr $cmy * 615 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 583 /1000] [expr $cmy * 615 /1000] [expr $cmx * 590 /1000] [expr $cmy * 616 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 590 /1000] [expr $cmy * 616 /1000] [expr $cmx * 596 /1000] [expr $cmy * 616 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 596 /1000] [expr $cmy * 616 /1000] [expr $cmx * 602 /1000] [expr $cmy * 616 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 602 /1000] [expr $cmy * 616 /1000] [expr $cmx * 608 /1000] [expr $cmy * 616 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 608 /1000] [expr $cmy * 616 /1000] [expr $cmx * 614 /1000] [expr $cmy * 616 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 614 /1000] [expr $cmy * 616 /1000] [expr $cmx * 620 /1000] [expr $cmy * 615 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 620 /1000] [expr $cmy * 615 /1000] [expr $cmx * 625 /1000] [expr $cmy * 615 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 625 /1000] [expr $cmy * 615 /1000] [expr $cmx * 631 /1000] [expr $cmy * 614 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 631 /1000] [expr $cmy * 614 /1000] [expr $cmx * 636 /1000] [expr $cmy * 614 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 636 /1000] [expr $cmy * 614 /1000] [expr $cmx * 641 /1000] [expr $cmy * 613 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 641 /1000] [expr $cmy * 613 /1000] [expr $cmx * 647 /1000] [expr $cmy * 612 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 647 /1000] [expr $cmy * 612 /1000] [expr $cmx * 652 /1000] [expr $cmy * 611 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 652 /1000] [expr $cmy * 611 /1000] [expr $cmx * 657 /1000] [expr $cmy * 610 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 657 /1000] [expr $cmy * 610 /1000] [expr $cmx * 662 /1000] [expr $cmy * 609 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 662 /1000] [expr $cmy * 609 /1000] [expr $cmx * 667 /1000] [expr $cmy * 608 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 667 /1000] [expr $cmy * 608 /1000] [expr $cmx * 672 /1000] [expr $cmy * 607 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 672 /1000] [expr $cmy * 607 /1000] [expr $cmx * 677 /1000] [expr $cmy * 606 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 677 /1000] [expr $cmy * 606 /1000] [expr $cmx * 682 /1000] [expr $cmy * 605 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 682 /1000] [expr $cmy * 605 /1000] [expr $cmx * 687 /1000] [expr $cmy * 603 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 687 /1000] [expr $cmy * 603 /1000] [expr $cmx * 692 /1000] [expr $cmy * 602 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 692 /1000] [expr $cmy * 602 /1000] [expr $cmx * 696 /1000] [expr $cmy * 601 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 696 /1000] [expr $cmy * 601 /1000] [expr $cmx * 701 /1000] [expr $cmy * 599 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 701 /1000] [expr $cmy * 599 /1000] [expr $cmx * 706 /1000] [expr $cmy * 598 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 706 /1000] [expr $cmy * 598 /1000] [expr $cmx * 711 /1000] [expr $cmy * 597 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 711 /1000] [expr $cmy * 597 /1000] [expr $cmx * 716 /1000] [expr $cmy * 595 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 321 /1000] [expr $cmy * 561 /1000] [expr $cmx * 329 /1000] [expr $cmy * 572 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 329 /1000] [expr $cmy * 572 /1000] [expr $cmx * 343 /1000] [expr $cmy * 594 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 343 /1000] [expr $cmy * 594 /1000] [expr $cmx * 352 /1000] [expr $cmy * 611 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 352 /1000] [expr $cmy * 611 /1000] [expr $cmx * 359 /1000] [expr $cmy * 626 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 359 /1000] [expr $cmy * 626 /1000] [expr $cmx * 364 /1000] [expr $cmy * 638 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 364 /1000] [expr $cmy * 638 /1000] [expr $cmx * 367 /1000] [expr $cmy * 648 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 367 /1000] [expr $cmy * 648 /1000] [expr $cmx * 369 /1000] [expr $cmy * 657 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 369 /1000] [expr $cmy * 657 /1000] [expr $cmx * 370 /1000] [expr $cmy * 665 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 370 /1000] [expr $cmy * 665 /1000] [expr $cmx * 370 /1000] [expr $cmy * 671 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 370 /1000] [expr $cmy * 671 /1000] [expr $cmx * 370 /1000] [expr $cmy * 678 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 370 /1000] [expr $cmy * 678 /1000] [expr $cmx * 369 /1000] [expr $cmy * 683 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 369 /1000] [expr $cmy * 683 /1000] [expr $cmx * 367 /1000] [expr $cmy * 688 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 367 /1000] [expr $cmy * 688 /1000] [expr $cmx * 365 /1000] [expr $cmy * 692 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 365 /1000] [expr $cmy * 692 /1000] [expr $cmx * 363 /1000] [expr $cmy * 697 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 363 /1000] [expr $cmy * 697 /1000] [expr $cmx * 361 /1000] [expr $cmy * 701 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 361 /1000] [expr $cmy * 701 /1000] [expr $cmx * 358 /1000] [expr $cmy * 704 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 358 /1000] [expr $cmy * 704 /1000] [expr $cmx * 355 /1000] [expr $cmy * 708 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 355 /1000] [expr $cmy * 708 /1000] [expr $cmx * 352 /1000] [expr $cmy * 711 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 352 /1000] [expr $cmy * 711 /1000] [expr $cmx * 349 /1000] [expr $cmy * 714 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 349 /1000] [expr $cmy * 714 /1000] [expr $cmx * 345 /1000] [expr $cmy * 717 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 345 /1000] [expr $cmy * 717 /1000] [expr $cmx * 342 /1000] [expr $cmy * 720 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 342 /1000] [expr $cmy * 720 /1000] [expr $cmx * 338 /1000] [expr $cmy * 723 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 338 /1000] [expr $cmy * 723 /1000] [expr $cmx * 335 /1000] [expr $cmy * 725 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 335 /1000] [expr $cmy * 725 /1000] [expr $cmx * 331 /1000] [expr $cmy * 728 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 331 /1000] [expr $cmy * 728 /1000] [expr $cmx * 327 /1000] [expr $cmy * 730 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 327 /1000] [expr $cmy * 730 /1000] [expr $cmx * 324 /1000] [expr $cmy * 733 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 324 /1000] [expr $cmy * 733 /1000] [expr $cmx * 320 /1000] [expr $cmy * 735 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 320 /1000] [expr $cmy * 735 /1000] [expr $cmx * 316 /1000] [expr $cmy * 737 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 316 /1000] [expr $cmy * 737 /1000] [expr $cmx * 312 /1000] [expr $cmy * 740 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 312 /1000] [expr $cmy * 740 /1000] [expr $cmx * 308 /1000] [expr $cmy * 742 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 308 /1000] [expr $cmy * 742 /1000] [expr $cmx * 304 /1000] [expr $cmy * 744 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 304 /1000] [expr $cmy * 744 /1000] [expr $cmx * 300 /1000] [expr $cmy * 746 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 300 /1000] [expr $cmy * 746 /1000] [expr $cmx * 296 /1000] [expr $cmy * 748 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 296 /1000] [expr $cmy * 748 /1000] [expr $cmx * 291 /1000] [expr $cmy * 750 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 291 /1000] [expr $cmy * 750 /1000] [expr $cmx * 287 /1000] [expr $cmy * 752 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 287 /1000] [expr $cmy * 752 /1000] [expr $cmx * 283 /1000] [expr $cmy * 754 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 283 /1000] [expr $cmy * 754 /1000] [expr $cmx * 279 /1000] [expr $cmy * 756 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 279 /1000] [expr $cmy * 756 /1000] [expr $cmx * 275 /1000] [expr $cmy * 758 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 275 /1000] [expr $cmy * 758 /1000] [expr $cmx * 271 /1000] [expr $cmy * 760 /1000] -fill magenta -width 1.000000 -capstyle round
$can create line [expr $cmx * 851 /1000] [expr $cmy * 745 /1000] [expr $cmx * 594 /1000] [expr $cmy * 460 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 148 /1000] [expr $cmy * 625 /1000] [expr $cmx * 594 /1000] [expr $cmy * 460 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 148 /1000] [expr $cmy * 625 /1000] [expr $cmx * 405 /1000] [expr $cmy * 910 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 851 /1000] [expr $cmy * 745 /1000] [expr $cmx * 405 /1000] [expr $cmy * 910 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 148 /1000] [expr $cmy * 625 /1000] [expr $cmx * 148 /1000] [expr $cmy * 232 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 405 /1000] [expr $cmy * 910 /1000] [expr $cmx * 405 /1000] [expr $cmy * 517 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 851 /1000] [expr $cmy * 745 /1000] [expr $cmx * 851 /1000] [expr $cmy * 352 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 594 /1000] [expr $cmy * 460 /1000] [expr $cmx * 594 /1000] [expr $cmy * 67 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 405 /1000] [expr $cmy * 910 /1000] [expr $cmx * 392 /1000] [expr $cmy * 897 /1000] -fill black -width 1.000000 -capstyle round
eval $can create text [expr $cmx * 415 /1000] [expr $cmy * 929 /1000] -text \{-10\} -fill black -anchor center [expr [info exists font]?"-font \$font":{}]
$can create line [expr $cmx * 148 /1000] [expr $cmy * 625 /1000] [expr $cmx * 160 /1000] [expr $cmy * 639 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 517 /1000] [expr $cmy * 869 /1000] [expr $cmx * 504 /1000] [expr $cmy * 856 /1000] -fill black -width 1.000000 -capstyle round
eval $can create text [expr $cmx * 527 /1000] [expr $cmy * 888 /1000] -text \{-5\} -fill black -anchor center [expr [info exists font]?"-font \$font":{}]
$can create line [expr $cmx * 260 /1000] [expr $cmy * 583 /1000] [expr $cmx * 272 /1000] [expr $cmy * 597 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 628 /1000] [expr $cmy * 828 /1000] [expr $cmx * 615 /1000] [expr $cmy * 815 /1000] -fill black -width 1.000000 -capstyle round
eval $can create text [expr $cmx * 638 /1000] [expr $cmy * 847 /1000] -text \{ 0\} -fill black -anchor center [expr [info exists font]?"-font \$font":{}]
$can create line [expr $cmx * 371 /1000] [expr $cmy * 542 /1000] [expr $cmx * 383 /1000] [expr $cmy * 556 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 739 /1000] [expr $cmy * 787 /1000] [expr $cmx * 726 /1000] [expr $cmy * 774 /1000] -fill black -width 1.000000 -capstyle round
eval $can create text [expr $cmx * 749 /1000] [expr $cmy * 806 /1000] -text \{ 5\} -fill black -anchor center [expr [info exists font]?"-font \$font":{}]
$can create line [expr $cmx * 482 /1000] [expr $cmy * 501 /1000] [expr $cmx * 494 /1000] [expr $cmy * 515 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 851 /1000] [expr $cmy * 745 /1000] [expr $cmx * 838 /1000] [expr $cmy * 732 /1000] -fill black -width 1.000000 -capstyle round
eval $can create text [expr $cmx * 861 /1000] [expr $cmy * 764 /1000] -text \{ 10\} -fill black -anchor center [expr [info exists font]?"-font \$font":{}]
$can create line [expr $cmx * 594 /1000] [expr $cmy * 460 /1000] [expr $cmx * 606 /1000] [expr $cmy * 474 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 148 /1000] [expr $cmy * 625 /1000] [expr $cmx * 164 /1000] [expr $cmy * 619 /1000] -fill black -width 1.000000 -capstyle round
eval $can create text [expr $cmx * 132 /1000] [expr $cmy * 634 /1000] -text \{-10\} -fill black -anchor e [expr [info exists font]?"-font \$font":{}]
$can create line [expr $cmx * 594 /1000] [expr $cmy * 460 /1000] [expr $cmx * 577 /1000] [expr $cmy * 467 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 213 /1000] [expr $cmy * 696 /1000] [expr $cmx * 229 /1000] [expr $cmy * 690 /1000] -fill black -width 1.000000 -capstyle round
eval $can create text [expr $cmx * 197 /1000] [expr $cmy * 705 /1000] -text \{-5\} -fill black -anchor e [expr [info exists font]?"-font \$font":{}]
$can create line [expr $cmx * 658 /1000] [expr $cmy * 531 /1000] [expr $cmx * 641 /1000] [expr $cmy * 538 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 277 /1000] [expr $cmy * 767 /1000] [expr $cmx * 293 /1000] [expr $cmy * 761 /1000] -fill black -width 1.000000 -capstyle round
eval $can create text [expr $cmx * 261 /1000] [expr $cmy * 776 /1000] -text \{ 0\} -fill black -anchor e [expr [info exists font]?"-font \$font":{}]
$can create line [expr $cmx * 722 /1000] [expr $cmy * 603 /1000] [expr $cmx * 705 /1000] [expr $cmy * 610 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 341 /1000] [expr $cmy * 839 /1000] [expr $cmx * 357 /1000] [expr $cmy * 833 /1000] -fill black -width 1.000000 -capstyle round
eval $can create text [expr $cmx * 325 /1000] [expr $cmy * 848 /1000] -text \{ 5\} -fill black -anchor e [expr [info exists font]?"-font \$font":{}]
$can create line [expr $cmx * 786 /1000] [expr $cmy * 674 /1000] [expr $cmx * 769 /1000] [expr $cmy * 681 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 405 /1000] [expr $cmy * 910 /1000] [expr $cmx * 421 /1000] [expr $cmy * 904 /1000] -fill black -width 1.000000 -capstyle round
eval $can create text [expr $cmx * 389 /1000] [expr $cmy * 919 /1000] -text \{ 10\} -fill black -anchor e [expr [info exists font]?"-font \$font":{}]
$can create line [expr $cmx * 851 /1000] [expr $cmy * 745 /1000] [expr $cmx * 834 /1000] [expr $cmy * 752 /1000] -fill black -width 1.000000 -capstyle round
$can create line [expr $cmx * 148 /1000] [expr $cmy * 494 /1000] [expr $cmx * 166 /1000] [expr $cmy * 494 /1000] -fill black -width 1.000000 -capstyle round
eval $can create text [expr $cmx * 112 /1000] [expr $cmy * 494 /1000] -text \{ 0\} -fill black -anchor e [expr [info exists font]?"-font \$font":{}]
$can create line [expr $cmx * 148 /1000] [expr $cmy * 441 /1000] [expr $cmx * 166 /1000] [expr $cmy * 441 /1000] -fill black -width 1.000000 -capstyle round
eval $can create text [expr $cmx * 112 /1000] [expr $cmy * 441 /1000] -text \{ 2000\} -fill black -anchor e [expr [info exists font]?"-font \$font":{}]
$can create line [expr $cmx * 148 /1000] [expr $cmy * 389 /1000] [expr $cmx * 166 /1000] [expr $cmy * 389 /1000] -fill black -width 1.000000 -capstyle round
eval $can create text [expr $cmx * 112 /1000] [expr $cmy * 389 /1000] -text \{ 4000\} -fill black -anchor e [expr [info exists font]?"-font \$font":{}]
$can create line [expr $cmx * 148 /1000] [expr $cmy * 336 /1000] [expr $cmx * 166 /1000] [expr $cmy * 336 /1000] -fill black -width 1.000000 -capstyle round
eval $can create text [expr $cmx * 112 /1000] [expr $cmy * 336 /1000] -text \{ 6000\} -fill black -anchor e [expr [info exists font]?"-font \$font":{}]
$can create line [expr $cmx * 148 /1000] [expr $cmy * 284 /1000] [expr $cmx * 166 /1000] [expr $cmy * 284 /1000] -fill black -width 1.000000 -capstyle round
eval $can create text [expr $cmx * 112 /1000] [expr $cmy * 284 /1000] -text \{ 8000\} -fill black -anchor e [expr [info exists font]?"-font \$font":{}]
$can create line [expr $cmx * 148 /1000] [expr $cmy * 232 /1000] [expr $cmx * 166 /1000] [expr $cmy * 232 /1000] -fill black -width 1.000000 -capstyle round
eval $can create text [expr $cmx * 112 /1000] [expr $cmy * 232 /1000] -text \{ 10000\} -fill black -anchor e [expr [info exists font]?"-font \$font":{}]
}
#############################################################################
## Procedure:  gnuplot_axisranges

proc {gnuplot_axisranges} {} {
return {-10.000000 10.000000 -1000.000000 1000.000000 -10.000000 10.000000 -1000.000000 1000.000000}
}
#############################################################################
## Procedure:  gnuplot_plotarea

proc {gnuplot_plotarea} {} {
return {124 955 32 950}
}
#############################################################################
## Procedure:  gnuplot_saving

proc {gnuplot_saving} {} {
global widget
global STAT
set safile [ tk_getSaveFile ]
set STAT $safile
update
exec cp /tmp/unignuplot.gnup $safile
}
#############################################################################
## Procedure:  labeling

proc {labeling} {x y ltext} {
global widget
global STAT 
global mlabels
#set mlabels ""
set xpos [expr $x / 460.0 ]
set ypos [expr  (($y - 356) / 356.0)* -1 ]
append mlabels "set label \"$ltext\" at screen $xpos, $ypos center;"
set STAT $mlabels
update
}
#############################################################################
## Procedure:  labels

proc {labels} {} {
global widget
Window show $widget(Toplevel2)
}
#############################################################################
## Procedure:  linet

proc {linet} {lin} {
#This function  make's available the line type
#direct to ploting
#
#

global widget
global linetype 
global expresion
global STAT
set linetype " w $lin "
plot $expresion
set STAT "Line type selected \[ $lin \]"
}
#############################################################################
## Procedure:  openfile

proc {openfile} {} {
global widget

set opfile [ tk_getOpenFile ]
}
#############################################################################
## Procedure:  plot

proc {plot} {expresion} {
global widget
global CMD
global STAT
global RVIEW

global plottype
global linetype
global smooth
global mlabels
global ranges
global LABEL
global marks
global ISOSAMPLES
global ZOOM
global UCONTOUR
global CNTRPARAM

set CMD "$plottype $expresion $smooth $linetype;"

set CONST "set term tkcanvas;
set output 'out.tk';
"


set FP [open "| gnuplot" w+]
puts $FP $CONST
puts $FP $LABEL
puts $FP $mlabels
puts $FP $ranges
puts $FP $marks
puts $FP $RVIEW 
puts $FP $ISOSAMPLES
puts $FP $ZOOM
puts $FP $UCONTOUR
puts $FP $CNTRPARAM

puts $FP $CMD

puts $FP  "save \'/tmp/unignuplot.gnup\'"

close $FP
source out.tk
set STAT "Now... Ploting..."
update
gnuplot $widget(Canvas1)
}
#############################################################################
## Procedure:  print

proc {print} {} {
global widget
global CMD
global STAT
global RVIEW
global expresion
global plottype
global linetype
global smooth
global mlabels
global ranges
global LABEL
global marks
global ISOSAMPLES
global ZOOM
global PRINTER_DEV

set CMD "$plottype $expresion $smooth $linetype;"

set CONST "set term postscript color;
set output 'out.ps';
"


set FP [open "| gnuplot" w+]
puts $FP $CONST
puts $FP $LABEL
puts $FP $mlabels
puts $FP $ranges
puts $FP $marks
puts $FP $RVIEW 
puts $FP $ISOSAMPLES
puts $FP $ZOOM
puts $FP $CMD

close $FP
[exec lpr -P$PRINTER_DEV out.ps]
}
#############################################################################
## Procedure:  rang

proc {rang} {} {
global widget
global ranges
set ranges ""
set ranges "set xrange\[$Xmin:$Xmax\];
set yrange\[$Ymin:$Ymax\];
set zrange\[$Zmin:$Zmax\];
"
}
#############################################################################
## Procedure:  rcfile

proc {rcfile} {sf} {
global widget


global LANG
global L_PATH
global PRINTER_DEV
global CENTRY CCANVAS CFRAME CBUTTON CTOPLEVEL CSCALE

set WMESS  "##Don't edit this file by hand
##File genetad by the UniGNUPlot config-dialog
##Any change made by hand will be override
##by the config-dialog
##Plese refer to File->configure to activate changes
"

set CENTRY $CENTRY
set CCANVAS $CCANVAS
set CFRAME  $CFRAME
set CTOPLEVEL $CTOPLEVEL
set CBUTTON $CBUTTON
set CSCALE $CSCALE

set fd [open $sf w+]
puts $fd "
$WMESS
set L_PATH \"lang/\"
set LANG \"$LANG\"
set PRINTER_DEV \"$PRINTER_DEV\"

set CENTRY $CENTRY
set CCANVAS $CCANVAS
set CFRAME $CFRAME
set CTOPLEVEL $CTOPLEVEL
set CBUTTON $CBUTTON
set CSCALE $CSCALE
"

close $fd
}
#############################################################################
## Procedure:  rotate

proc {rotate} {wn value} {
global widget
global RVIEW
global expresion
global X11
set RVIEW "set view $value;\n"

XTERM
}
#############################################################################
## Procedure:  rotate2

proc {rotate2} {wn value} {
global widget
global RVIEW
global expresion
global X11
set RVIEW "set view ,$value;\n"

XTERM
}
#############################################################################
## Procedure:  savefile

proc {savefile} {} {
global widget
set safile [ tk_getSaveFile ]
}
#############################################################################
## Procedure:  main

proc {main} {argc argv} {
source ugpconf
source .ugpcolor
}

#############################################################################
## Initialization Procedure:  init

proc {init} {argc argv} {
source .unignuplotrc
}

init $argc $argv

#################################
# VTCL GENERATED GUI PROCEDURES
#

proc vTclWindow. {base} {
    if {$base == ""} {
        set base .
    }
    ###################
    # CREATING WIDGETS
    ###################
    wm focusmodel $base passive
    wm geometry $base 1x1+0+0; update
    wm maxsize $base 1265 994
    wm minsize $base 1 1
    wm overrideredirect $base 0
    wm resizable $base 1 1
    wm withdraw $base
    wm title $base "vtcl.tcl"
    bindtags $base "$base Vtcl.tcl all"
    vTcl:FireEvent $base <<Create>>
    wm protocol $base WM_DELETE_WINDOW "vTcl:FireEvent $base <<DeleteWindow>>"

    ###################
    # SETTING GEOMETRY
    ###################

    vTcl:FireEvent $base <<Ready>>
}

proc vTclWindow.top43 {base} {
    if {$base == ""} {
        set base .top43
    }
    if {[winfo exists $base]} {
        wm deiconify $base; return
    }

    global widget
    vTcl:DefineAlias "$base" "Toplevel1" vTcl:Toplevel:WidgetProc "" 1
    vTcl:DefineAlias "$base.fra44" "Frame1" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra44.but46" "Button1" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra44.cpd47" "Frame2" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra44.cpd47.01" "Label1" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra44.cpd47.02" "Entry1" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra44.men45" "Menubutton1" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra48" "Frame3" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra48.can49" "Canvas1" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra48.sca50" "Scale1" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra48.sca51" "Scale2" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra52" "Frame4" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra54" "Frame5" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra54.but47" "Button22" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra54.but59" "Button3" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra54.fra43" "Frame6" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra54.fra43.but52" "Button8" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra54.fra43.but53" "Button4" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra54.fra43.cpd46" "Frame11" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra54.fra43.cpd46.01" "Label5" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra54.fra43.cpd46.02" "Entry2" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra54.fra43.fra47" "Frame12" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra54.fra43.fra47.01" "Label6" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra54.fra43.fra47.02" "Entry3" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra54.fra43.fra48" "Frame13" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra54.fra43.fra48.01" "Label7" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra54.fra43.fra48.02" "Entry4" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra54.fra43.fra49" "Frame14" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra54.fra43.fra49.01" "Label8" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra54.fra43.fra49.02" "Entry5" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra54.fra43.fra50" "Frame15" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra54.fra43.fra50.01" "Label9" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra54.fra43.fra50.02" "Entry6" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra54.fra43.fra51" "Frame16" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra54.fra43.fra51.01" "Label10" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra54.fra43.fra51.02" "Entry7" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra54.fra44" "Frame26" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra54.fra44.lab50" "Label19" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra54.fra44.lab51" "Label20" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra54.fra44.sca48" "Scale3" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra54.fra44.sca49" "Scale4" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra54.lab46" "Label17" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra54.lab52" "Label11" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra54.men43" "Menubutton5" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra54.men43.m" "Menu1" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra54.men44" "Menubutton6" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra54.men45" "Menubutton7" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra54.men57" "Menubutton3" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra54.men58" "Menubutton4" vTcl:WidgetProc "Toplevel1" 1

    ###################
    # CREATING WIDGETS
    ###################
    vTcl:toplevel $base -class Toplevel \
        -background #0880bd -highlightthickness 2 
    wm focusmodel $base passive
    wm geometry $base 734x497+145+175; update
    wm maxsize $base 1009 738
    wm minsize $base 1 1
    wm overrideredirect $base 0
    wm resizable $base 1 1
    wm deiconify $base
    wm title $base "UniGNUPlot 2.0.0C"
    bindtags $base "$base Toplevel all _TopLevel"
    vTcl:FireEvent $base <<Create>>
    wm protocol $base WM_DELETE_WINDOW "vTcl:FireEvent $base <<DeleteWindow>>"

    frame $base.fra44 \
        -background #0888b5 -borderwidth 2 -height 45 -highlightcolor #0000ff \
        -highlightthickness 2 -relief groove -width 720 
    menubutton $base.fra44.men45 \
        -activeforeground #000000 -background #0a72b4 \
        -disabledforeground #a1a1a1 -font {Helvetica -12 italic} \
        -foreground #0000ff -highlightthickness 2 -menu "$base.fra44.men45.m" \
        -padx 5 -pady 4 -relief raised -text File -textvariable FILE 
    bind $base.fra44.men45 <Double-Button-1> {
        # TODO: your event handler here
# 

set LANG [$widget(Listbox2) get active]
    }
    menu $base.fra44.men45.m \
        -disabledforeground #a1a1a1 -tearoff 0 
    $base.fra44.men45.m add command \
        -command {# TODO: Your menu handler here
openfile} \
        -font [vTcl:font:get_font "vTcl:font1"] -label Open 
    $base.fra44.men45.m add command \
        -command {# TODO: Your menu handler here
# 
savefile} \
        -font [vTcl:font:get_font "vTcl:font1"] -label Save 
    $base.fra44.men45.m add command \
        -command {# TODO: Your menu handler here
# 
gnuplot_saving} \
        -font [vTcl:font:get_font "vTcl:font1"] \
        -label {Save GNUPlot Complete Settings} 
    $base.fra44.men45.m add command \
        \
        -command {# TODO: Your menu handler here
# 
Window show $widget(Toplevel6)
$widget(Listbox2) delete 0 end
foreach i [exec ls lang/ ] {
$widget(Listbox2) insert end $i
}

set tv [$widget(Listbox2) size]
set ne 0
while { $ne < $tv } {
set localvar [$widget(Listbox2) get $ne]
if { $LANG == $localvar } {
 $widget(Listbox2) itemconfigure $ne -background steelblue

}
incr ne
}} \
        -font [vTcl:font:get_font "vTcl:font1"] -label Configuration 
    $base.fra44.men45.m add command \
        \
        -command {# TODO: Your menu handler here
# 
#    
$widget(Listbox1) delete 0 end
foreach i [exec cat terms ] {
$widget(Listbox1) insert end $i
}

Window show $widget(Toplevel5)} \
        -font [vTcl:font:get_font "vTcl:font1"] -label Export 
    $base.fra44.men45.m add command \
        -command {# TODO: Your menu handler 
# 
print} \
        -font [vTcl:font:get_font "vTcl:font1"] -label Print 
    $base.fra44.men45.m add separator
    $base.fra44.men45.m add command \
        -command {# TODO: Your menu handler 
# 
exit} \
        -font [vTcl:font:get_font "vTcl:font1"] -label Exit 
    button $base.fra44.but46 \
        -background #0a72b4 -command about -disabledforeground #a1a1a1 \
        -font {Helvetica -12 italic} -foreground #0000ff \
        -highlightcolor #000099 -highlightthickness 2 -text About \
        -textvariable ABOUT 
    frame $base.fra44.cpd47 \
        -background #0888b5 -borderwidth 1 -height 34 -highlightthickness 2 \
        -relief raised -width 464 
    label $base.fra44.cpd47.01 \
        -activebackground #d6d6cbcba5a5 -activeforeground #0000ff -anchor w \
        -background #d6d6cbcba5a5 -disabledforeground #a1a1a1 \
        -font {Helvetica -12 } -foreground #0000ff -highlightthickness 2 \
        -relief groove -text {Expression } -textvariable EXPRESION 
    entry $base.fra44.cpd47.02 \
        -background #fee8fe -cursor {} -highlightthickness 0 \
        -insertbackground black -textvariable expresion 
    bind $base.fra44.cpd47.02 <Key><Key-Return> {
        # TODO: your event handler here
 plot $expresion
    }
    frame $base.fra48 \
        -background #0888b5 -borderwidth 2 -height 390 -highlightthickness 2 \
        -relief groove -width 495 
    canvas $base.fra48.can49 \
        -background #9a9ebd -borderwidth 2 -closeenough 1.0 -height 356 \
        -highlightthickness 2 -insertbackground black -relief ridge \
        -selectbackground #c1c2c1 -selectforeground black -width 460 
    bind $base.fra48.can49 <Button-3> {
        # TODO: your event handler here
# 
# 
global expresion
global mlabels
global STAT
set mlabels ""
set STAT "User free Labels erased..."
update
plot $expresion
    }
    bind $base.fra48.can49 <ButtonRelease-1> {
        # TODO: your event handler here
# 
$widget(Canvas1) configure -cursor ""
    }
    bind $base.fra48.can49 <Control-Button-1> {
        # TODO: your event handler here
# 
global ZOOM XZOOM
global expresion
$widget(Canvas1) configure -cursor circle
set ZOOM "set view ,,$XZOOM;\n"
set XZOOM [expr $XZOOM + .05]
plot $expresion
    }
    bind $base.fra48.can49 <Double-Button-1> {
        # TODO: your event handler here
global xp
global yp
set xp %x
set yp %y
Window show $widget(Toplevel3)
    }
    bind $base.fra48.can49 <Shift-Button-1> {
        # TODO: your event handler here
# 
global ZOOM XZOOM expresion

$widget(Canvas1) configure -cursor circle
set ZOOM "set view ,,$XZOOM;\n"

if { $XZOOM > 1 } {
set XZOOM [expr $XZOOM - .05 ]
}

plot $expresion
    }
    scale $base.fra48.sca50 \
        -background #d6d6cbcba5a5 -bigincrement 0.0 \
        -command {rotate $widget(Scale1)} -from 0.0 -highlightthickness 2 \
        -relief raised -resolution 5.0 -showvalue 0 -tickinterval 0.0 \
        -to 180.0 -troughcolor #64bebe -variable SCX 
    scale $base.fra48.sca51 \
        -background #d6d6cbcba5a5 -bigincrement 0.0 \
        -command {rotate2 $widget(Scale2)} -from 0.0 -highlightthickness 2 \
        -orient horizontal -relief raised -resolution 5.0 -showvalue 0 \
        -tickinterval 0.0 -to 360.0 -troughcolor #64bebe \
        -variable "$base\::sca51" 
    frame $base.fra52 \
        -background #0888b5 -borderwidth 2 -height 45 -highlightthickness 2 \
        -relief groove -width 495 
    label $base.fra52.lab53 \
        -activebackground #ffffe666ed4f -background #ffffe666ed4f \
        -borderwidth 0 -disabledforeground #a1a1a1 -font {Helvetica -10} \
        -highlightthickness 1 -text {Now... Ploting...} -textvariable STAT 
    frame $base.fra54 \
        -background #0888b5 -borderwidth 2 -height 440 -highlightthickness 2 \
        -relief groove -width 225 
    menubutton $base.fra54.men57 \
        -activeforeground #000099 -background #0a72b4 \
        -disabledforeground #a1a1a1 -font {Helvetica -12 italic} \
        -foreground #0000ff -highlightthickness 2 -menu "$base.fra54.men57.m" \
        -padx 5 -pady 4 -relief raised -text {Plot type} \
        -textvariable PLOTTYPE 
    menu $base.fra54.men57.m \
        -disabledforeground #a1a1a1 -tearoff 0 
    $base.fra54.men57.m add command \
        \
        -command {# TODO: Your menu handler here
# 
# 

set plottype "set nopolar; plot "
plot $expresion} \
        -font [vTcl:font:get_font "vTcl:font1"] -label 2D 
    $base.fra54.men57.m add command \
        \
        -command {# TODO: Your menu handler here
# 
global smooth
set smooth ""
set plottype "splot "
plot $expresion} \
        -font [vTcl:font:get_font "vTcl:font1"] -label 3D 
    $base.fra54.men57.m add command \
        \
        -command {# TODO: Your menu handler heres
 
set plottype "set polar; 
plot "} \
        -font [vTcl:font:get_font "vTcl:font1"] -label Polar 
    $base.fra54.men57.m add command \
        \
        -command {# TODO: Your menu handler here
# 
set plottype "set parametric;
plot "} \
        -font [vTcl:font:get_font "vTcl:font1"] -label Parametric 
    menubutton $base.fra54.men58 \
        -activeforeground #000099 -background #0a72b4 \
        -disabledforeground #a1a1a1 -font {Helvetica -12 italic} \
        -foreground #0000ff -highlightthickness 2 -menu "$base.fra54.men58.m" \
        -padx 5 -pady 4 -relief raised -text Marks -textvariable MARKS 
    menu $base.fra54.men58.m \
        -disabledforeground #a1a1a1 -tearoff 0 
    $base.fra54.men58.m add separator
    $base.fra54.men58.m add checkbutton \
        -variable SAX \
        -command {# TODO: Your menu handler here
#
axis $SAX "set xzeroaxis;" "set noxzeroaxis;"} \
        -font [vTcl:font:get_font "vTcl:font1"] -label {Show X Axis} 
    $base.fra54.men58.m add checkbutton \
        -variable SAY \
        -command {# TODO: Your menu handler here
# 
axis $SAY "set yzeroaxis;" "set noyzeroaxis;"} \
        -font [vTcl:font:get_font "vTcl:font1"] -label {Show Y Axis} 
    $base.fra54.men58.m add separator
    $base.fra54.men58.m add checkbutton \
        -variable SXM \
        -command {# TODO: Your menu handler here
# 
axis $SXM "set xtics;" "set noxtics;"} \
        -font [vTcl:font:get_font "vTcl:font1"] -label {Show X Marks} 
    $base.fra54.men58.m add checkbutton \
        -variable SYM \
        -command {# TODO: Your menu handler here
# 
axis $SYM "set ytics;" "set noytics;"} \
        -font [vTcl:font:get_font "vTcl:font1"] -label {Show Y Marks} 
    $base.fra54.men58.m add checkbutton \
        -variable SZM \
        -command {# TODO: Your menu handler here
# 
axis $SZM "set ztics;" "set noztics;"} \
        -font [vTcl:font:get_font "vTcl:font1"] -label {Show Z Marks} 
    $base.fra54.men58.m add checkbutton \
        -variable SG \
        -command {# TODO: Your menu handler here
# 
axis $SG "set grid;" "set nogrid;"} \
        -font [vTcl:font:get_font "vTcl:font1"] -label {Show Grid} 
    $base.fra54.men58.m add separator
    $base.fra54.men58.m add checkbutton \
        -variable SB \
        -command {# TODO: Your menu handler here
# 
axis $SB "set border;" "set noborder;"} \
        -font [vTcl:font:get_font "vTcl:font1"] -label {Show Border} 
    $base.fra54.men58.m add checkbutton \
        -variable HE \
        -command {# TODO: Your menu handler here
# 
axis $HE "set nokey;" "set key;"} \
        -font [vTcl:font:get_font "vTcl:font1"] -label {Hide Expresion} 
    button $base.fra54.but59 \
        -activeforeground #000099 -background #0a72b4 -command labels \
        -disabledforeground #a1a1a1 -font {Helvetica -12 italic} \
        -foreground #0000ff -height 25 -highlightthickness 2 -text Etiqueta \
        -textvariable LABELS -width 67 
    frame $base.fra54.fra43 \
        -background #0888b5 -borderwidth 2 -height 150 -highlightthickness 2 \
        -relief groove -width 215 
    frame $base.fra54.fra43.cpd46 \
        -background #d6d6cbcba5a5 -borderwidth 1 -height 34 \
        -highlightthickness 2 -relief raised -width 82 
    label $base.fra54.fra43.cpd46.01 \
        -anchor w -background #d6d6cbcba5a5 -disabledforeground #a1a1a1 \
        -font {Helvetica -10} -highlightthickness 2 -relief groove -text Xmin 
    entry $base.fra54.fra43.cpd46.02 \
        -background #fee8fe -cursor {} -highlightthickness 0 \
        -insertbackground black -textvariable Xmin 
    frame $base.fra54.fra43.fra47 \
        -background #d6d6cbcba5a5 -borderwidth 1 -height 34 \
        -highlightthickness 2 -relief raised -width 82 
    label $base.fra54.fra43.fra47.01 \
        -anchor w -background #d6d6cbcba5a5 -disabledforeground #a1a1a1 \
        -font {Helvetica -10} -highlightthickness 2 -relief groove -text Xmax 
    entry $base.fra54.fra43.fra47.02 \
        -background #fee8fe -cursor {} -highlightthickness 0 \
        -insertbackground black -textvariable Xmax 
    frame $base.fra54.fra43.fra48 \
        -background #d6d6cbcba5a5 -borderwidth 1 -height 34 \
        -highlightthickness 2 -relief raised -width 82 
    label $base.fra54.fra43.fra48.01 \
        -anchor w -background #d6d6cbcba5a5 -disabledforeground #a1a1a1 \
        -font {Helvetica -10} -highlightthickness 2 -relief groove -text Ymin 
    entry $base.fra54.fra43.fra48.02 \
        -background #fee8fe -cursor {} -highlightthickness 0 \
        -insertbackground black -textvariable Ymin 
    frame $base.fra54.fra43.fra49 \
        -background #d6d6cbcba5a5 -borderwidth 1 -height 34 \
        -highlightthickness 2 -relief raised -width 82 
    label $base.fra54.fra43.fra49.01 \
        -anchor w -background #d6d6cbcba5a5 -disabledforeground #a1a1a1 \
        -font {Helvetica -10} -highlightthickness 2 -relief groove -text Ymax 
    entry $base.fra54.fra43.fra49.02 \
        -background #fee8fe -cursor {} -highlightthickness 0 \
        -insertbackground black -textvariable Ymax 
    frame $base.fra54.fra43.fra50 \
        -background #d6d6cbcba5a5 -borderwidth 1 -height 34 \
        -highlightthickness 2 -relief raised -width 82 
    label $base.fra54.fra43.fra50.01 \
        -anchor w -background #d6d6cbcba5a5 -disabledforeground #a1a1a1 \
        -font {Helvetica -10} -highlightthickness 2 -relief groove -text Zmin 
    entry $base.fra54.fra43.fra50.02 \
        -background #fee8fe -cursor {} -highlightthickness 0 \
        -insertbackground black -textvariable Zmin 
    frame $base.fra54.fra43.fra51 \
        -background #d6d6cbcba5a5 -borderwidth 1 -height 34 \
        -highlightthickness 2 -relief raised -width 82 
    label $base.fra54.fra43.fra51.01 \
        -anchor w -background #d6d6cbcba5a5 -disabledforeground #a1a1a1 \
        -font {Helvetica -10} -highlightthickness 2 -relief groove -text Zmax 
    entry $base.fra54.fra43.fra51.02 \
        -background #fee8fe -cursor {} -highlightthickness 0 \
        -insertbackground black -textvariable Zmax 
    button $base.fra54.fra43.but53 \
        -background #0a72b4 \
        -command {set Xmin "*"
set Xmax "*"
set Ymin "*"
set Ymax "*"
set Zmin "*"
set Zmax "*"} \
        -disabledforeground #a1a1a1 -font {Helvetica -12 italic} \
        -foreground #0000ff -highlightthickness 2 -text Reset \
        -textvariable RESET_VALUES 
    button $base.fra54.fra43.but52 \
        -background #0a72b4 \
        -command {global ranges
global expresion
set ranges ""
set ranges "set xrange\[$Xmin:$Xmax\];
set yrange\[$Ymin:$Ymax\];
set zrange\[$Zmin:$Zmax\];
"

plot $expresion} \
        -disabledforeground #a1a1a1 -font {Helvetica -12 italic} \
        -foreground #0000ff -highlightthickness 2 -text Set -textvariable SET 
    label $base.fra54.lab52 \
        -background #d6d6cbd3aacb -disabledforeground #a1a1a1 \
        -font {Helvetica -12} -foreground #0000ff -highlightcolor #000000 \
        -highlightthickness 2 -relief groove -text Ranges \
        -textvariable RANGES_LAB 
    menubutton $base.fra54.men43 \
        -activeforeground #000099 -background #0a72b4 \
        -disabledforeground #a1a1a1 -font {Helvetica -12 italic} \
        -foreground #0000ff -highlightthickness 2 -menu "$base.fra54.men43.m" \
        -padx 5 -pady 4 -relief raised -text Marks 
    menu $base.fra54.men43.m \
        -activebackground #f6f7f6 -activeforeground black \
        -disabledforeground #a1a1a1 -foreground black -tearoff 0 
    $base.fra54.men43.m add separator
    $base.fra54.men43.m add checkbutton \
        -variable SAX -command {# TODO: Your menu handler here} \
        -font [vTcl:font:get_font "vTcl:font1"] -label {Show X Axis} 
    $base.fra54.men43.m add checkbutton \
        -variable SAY -command {# TODO: Your menu handler here} \
        -font [vTcl:font:get_font "vTcl:font1"] -label {Show Y Axis} 
    $base.fra54.men43.m add separator
    $base.fra54.men43.m add checkbutton \
        -variable SXM -command {# TODO: Your menu handler here} \
        -font [vTcl:font:get_font "vTcl:font1"] -label {Show X Marks} 
    $base.fra54.men43.m add checkbutton \
        -variable SYM -command {# TODO: Your menu handler here} \
        -font [vTcl:font:get_font "vTcl:font1"] -label {Show Y Marks} 
    $base.fra54.men43.m add checkbutton \
        -variable SZM -command {# TODO: Your menu handler here} \
        -font [vTcl:font:get_font "vTcl:font1"] -label {Show Z Marks} 
    $base.fra54.men43.m add checkbutton \
        -variable SG -command {# TODO: Your menu handler here} \
        -font [vTcl:font:get_font "vTcl:font1"] -label {Show Grid} 
    $base.fra54.men43.m add separator
    $base.fra54.men43.m add checkbutton \
        -variable SB -command {# TODO: Your menu handler here} \
        -font [vTcl:font:get_font "vTcl:font1"] -label {Show Border} 
    $base.fra54.men43.m add checkbutton \
        -variable HE -command {# TODO: Your menu handler here} \
        -font [vTcl:font:get_font "vTcl:font1"] -label {Hide Expresion} 
    menubutton $base.fra54.men44 \
        -activeforeground #000099 -background #0a72b4 \
        -disabledforeground #a1a1a1 -font {Helvetica -12 italic} \
        -foreground #0000ff -highlightthickness 2 -menu "$base.fra54.men44.m" \
        -padx 5 -pady 4 -relief raised -text {Line type} \
        -textvariable LINETYPE 
    menu $base.fra54.men44.m \
        -disabledforeground #a1a1a1 -tearoff 0 
    $base.fra54.men44.m add command \
        -command {# TODO: Your menu handler here
# 
# 
linet "lines"} \
        -font [vTcl:font:get_font "vTcl:font1"] -label Lines 
    $base.fra54.men44.m add command \
        -command {# TODO: Your menu handler here
# 
linet "points"} \
        -font [vTcl:font:get_font "vTcl:font1"] -label points 
    $base.fra54.men44.m add command \
        -command {# TODO: Your menu handler here
# 
linet "linespoints"} \
        -font [vTcl:font:get_font "vTcl:font1"] -label {Lines & points} 
    $base.fra54.men44.m add command \
        -command {# TODO: Your menu handler here
# 
linet "impulses"} \
        -font [vTcl:font:get_font "vTcl:font1"] -label Impulses 
    $base.fra54.men44.m add command \
        -command {# TODO: Your menu handler here
# 
linet "dots"} \
        -font [vTcl:font:get_font "vTcl:font1"] -label Dots 
    $base.fra54.men44.m add command \
        -command {# TODO: Your menu handler 
# 
linet "steps"} \
        -font [vTcl:font:get_font "vTcl:font1"] -label Steps 
    $base.fra54.men44.m add command \
        -command {# TODO: Your menu handler here
# 
linet "fsteps"} \
        -font [vTcl:font:get_font "vTcl:font1"] -label Fsteps 
    $base.fra54.men44.m add command \
        -command {# TODO: Your menu handler here
# 
linet "histeps"} \
        -font [vTcl:font:get_font "vTcl:font1"] -label HiSteps 
    $base.fra54.men44.m add command \
        -command {# TODO: Your menu handler here
# 
linet "errorbars"} \
        -font [vTcl:font:get_font "vTcl:font1"] -label {Error Bars} 
    $base.fra54.men44.m add command \
        -command {# TODO: Your menu handler here
# 
linet "xerrorbars"} \
        -font [vTcl:font:get_font "vTcl:font1"] -label {X Error Bars} 
    $base.fra54.men44.m add command \
        -command {# TODO: Your menu handler here
# 
linet "yerrorbars"} \
        -font [vTcl:font:get_font "vTcl:font1"] -label {Y Error Bars} 
    $base.fra54.men44.m add command \
        -command {# TODO: Your menu handler here
# 
linet "xyerrorbars"} \
        -font [vTcl:font:get_font "vTcl:font1"] -label {XY Error Bars} 
    $base.fra54.men44.m add command \
        -command {linet "boxes"} -font [vTcl:font:get_font "vTcl:font1"] \
        -label Boxes 
    $base.fra54.men44.m add command \
        -command {# TODO: Your menu handler 
# 
linet "boxerrorbars"} \
        -font [vTcl:font:get_font "vTcl:font1"] -label {Box Error Bars} 
    $base.fra54.men44.m add command \
        -command {# TODO: Your menu handler here
# 
linet "boxxyerrorbars"} \
        -font [vTcl:font:get_font "vTcl:font1"] -label {Box XY Error Bars} 
    $base.fra54.men44.m add command \
        -command {# TODO: Your menu handler here
# 
linet "financebars"} \
        -font [vTcl:font:get_font "vTcl:font1"] -label {Finance Bars} 
    $base.fra54.men44.m add command \
        -command {# TODO: Your menu handler here
# 
linet "candlesticks"} \
        -font [vTcl:font:get_font "vTcl:font1"] -label CandleSticks 
    $base.fra54.men44.m add command \
        -command {# TODO: Your menu handler here
# 
linet "vector"} \
        -font [vTcl:font:get_font "vTcl:font1"] -label Vector 
    menubutton $base.fra54.men45 \
        -activeforeground #000099 -background #0a72b4 \
        -disabledforeground #a1a1a1 -font {Helvetica -12 italic} \
        -foreground #0000ff -highlightthickness 2 -menu "$base.fra54.men45.m" \
        -padx 5 -pady 4 -relief raised -text Smooth -textvariable SMOOTH 
    menu $base.fra54.men45.m \
        -disabledforeground #a1a1a1 -tearoff 0 
    $base.fra54.men45.m add command \
        \
        -command {# TODO: Your menu handler here
# 
# 
global smooth
set smooth " smooth unique "} \
        -font [vTcl:font:get_font "vTcl:font1"] -label unique -state active 
    $base.fra54.men45.m add command \
        \
        -command {# TODO: Your menu handler here
# 
set smooth " smooth csplines "} \
        -font [vTcl:font:get_font "vTcl:font1"] -label csplines 
    $base.fra54.men45.m add command \
        \
        -command {# TODO: Your menu handler here
# 
set smooth " smooth acsplines "} \
        -font [vTcl:font:get_font "vTcl:font1"] -label acsplines 
    $base.fra54.men45.m add command \
        \
        -command {# TODO: Your menu handler here
# 
set smooth " smooth bezier "} \
        -font [vTcl:font:get_font "vTcl:font1"] -label bezier 
    $base.fra54.men45.m add command \
        \
        -command {# TODO: Your menu handler 
# 
set smooth " smooth sbezier "} \
        -font [vTcl:font:get_font "vTcl:font1"] -label sbezier 
    $base.fra54.men45.m add command \
        -command {# TODO: Your menu handler here
# 
set smooth ""} \
        -label {No smooth} 
    frame $base.fra54.fra44 \
        -background #0888b5 -borderwidth 2 -height 130 -highlightthickness 2 \
        -relief groove -width 205 
    scale $base.fra54.fra44.sca48 \
        -background #d6d6cbd3aacb -bigincrement 0.0 \
        -command {ISOX $widget(Scale3)} -font {Helvetica -10} -from 2.0 \
        -highlightthickness 2 -orient horizontal -relief raised \
        -resolution 1.0 -tickinterval 0.0 -to 100.0 -troughcolor #64bebe \
        -variable testx 
    scale $base.fra54.fra44.sca49 \
        -background #d6d6cbd3aacb -bigincrement 0.0 \
        -command {ISOY $widget(Scale4)} -font {Helvetica -10} -from 2.0 \
        -highlightthickness 2 -orient horizontal -relief raised \
        -resolution 1.0 -tickinterval 0.0 -to 100.0 -troughcolor #64bebe \
        -variable "$base\::sca49" 
    label $base.fra54.fra44.lab50 \
        -background #d6d6cbd3aacb -disabledforeground #a1a1a1 \
        -font {Helvetica -10} -highlightthickness 2 -text {X Resolution} \
        -textvariable XR 
    label $base.fra54.fra44.lab51 \
        -background #d6d6cbd3aacb -disabledforeground #a1a1a1 \
        -font {Helvetica -10} -highlightthickness 2 -text {Y Resolution} \
        -textvariable YR -width 80 
    label $base.fra54.lab46 \
        -activebackground #d6d6cbd3aacb -background #d6d6cbd3aacb \
        -disabledforeground #a1a1a1 -font {Helvetica -12} -foreground #0000ff \
        -highlightthickness 2 -relief groove -text Mesh -textvariable MESH 
    button $base.fra54.but47 \
        -activeforeground blue -command {Window show $widget(Toplevel7)} \
        -disabledforeground #a1a1a1 -font {Helvetica -12 italic} \
        -foreground blue -text Smooth -textvariable CONTOUR 
    ###################
    # SETTING GEOMETRY
    ###################
    place $base.fra44 \
        -x 4 -y 5 -width 720 -height 45 -anchor nw -bordermode ignore 
    place $base.fra44.men45 \
        -x 10 -y 10 -width 65 -height 25 -anchor nw -bordermode ignore 
    place $base.fra44.but46 \
        -x 585 -y 10 -width 94 -height 25 -anchor nw -bordermode ignore 
    place $base.fra44.cpd47 \
        -x 113 -y 5 -width 464 -height 34 -anchor nw -bordermode ignore 
    pack $base.fra44.cpd47.01 \
        -in $base.fra44.cpd47 -anchor center -expand 0 -fill none -padx 2 \
        -pady 2 -side left 
    pack $base.fra44.cpd47.02 \
        -in $base.fra44.cpd47 -anchor center -expand 1 -fill x -padx 2 \
        -pady 2 -side right 
    place $base.fra48 \
        -x 5 -y 50 -width 495 -height 390 -anchor nw -bordermode ignore 
    place $base.fra48.can49 \
        -x 5 -y 5 -width 460 -height 356 -anchor nw -bordermode ignore 
    place $base.fra48.sca50 \
        -x 465 -y 2 -width 22 -height 363 -anchor nw -bordermode ignore 
    place $base.fra48.sca51 \
        -x 10 -y 360 -width 458 -height 22 -anchor nw -bordermode ignore 
    place $base.fra52 \
        -x 5 -y 445 -width 495 -height 45 -anchor nw -bordermode ignore 
    place $base.fra52.lab53 \
        -x 10 -y 10 -width 470 -height 22 -anchor nw -bordermode ignore 
    place $base.fra54 \
        -x 500 -y 50 -width 225 -height 440 -anchor nw -bordermode ignore 
    place $base.fra54.men57 \
        -x 81 -y 5 -width 102 -height 25 -anchor nw -bordermode ignore 
    place $base.fra54.men58 \
        -x 80 -y 55 -width 92 -height 25 -anchor nw -bordermode ignore 
    place $base.fra54.but59 \
        -x 5 -y 5 -width 67 -height 25 -anchor nw -bordermode ignore 
    place $base.fra54.fra43 \
        -x 5 -y 285 -width 215 -height 150 -anchor nw -bordermode ignore 
    place $base.fra54.fra43.cpd46 \
        -x 0 -y 15 -width 82 -height 34 -anchor nw 
    pack $base.fra54.fra43.cpd46.01 \
        -in $base.fra54.fra43.cpd46 -anchor center -expand 0 -fill none \
        -padx 2 -pady 2 -side left 
    pack $base.fra54.fra43.cpd46.02 \
        -in $base.fra54.fra43.cpd46 -anchor center -expand 1 -fill x -padx 2 \
        -pady 2 -side right 
    place $base.fra54.fra43.fra47 \
        -x 115 -y 19 -width 82 -height 34 -anchor nw -bordermode ignore 
    pack $base.fra54.fra43.fra47.01 \
        -in $base.fra54.fra43.fra47 -anchor center -expand 0 -fill none \
        -padx 2 -pady 2 -side left 
    pack $base.fra54.fra43.fra47.02 \
        -in $base.fra54.fra43.fra47 -anchor center -expand 1 -fill x -padx 2 \
        -pady 2 -side right 
    place $base.fra54.fra43.fra48 \
        -x 5 -y 54 -width 82 -height 34 -anchor nw -bordermode ignore 
    pack $base.fra54.fra43.fra48.01 \
        -in $base.fra54.fra43.fra48 -anchor center -expand 0 -fill none \
        -padx 2 -pady 2 -side left 
    pack $base.fra54.fra43.fra48.02 \
        -in $base.fra54.fra43.fra48 -anchor center -expand 1 -fill x -padx 2 \
        -pady 2 -side right 
    place $base.fra54.fra43.fra49 \
        -x 110 -y 50 -width 82 -height 34 -anchor nw 
    pack $base.fra54.fra43.fra49.01 \
        -in $base.fra54.fra43.fra49 -anchor center -expand 0 -fill none \
        -padx 2 -pady 2 -side left 
    pack $base.fra54.fra43.fra49.02 \
        -in $base.fra54.fra43.fra49 -anchor center -expand 1 -fill x -padx 2 \
        -pady 2 -side right 
    place $base.fra54.fra43.fra50 \
        -x 5 -y 89 -width 82 -height 34 -anchor nw -bordermode ignore 
    pack $base.fra54.fra43.fra50.01 \
        -in $base.fra54.fra43.fra50 -anchor center -expand 0 -fill none \
        -padx 2 -pady 2 -side left 
    pack $base.fra54.fra43.fra50.02 \
        -in $base.fra54.fra43.fra50 -anchor center -expand 1 -fill x -padx 2 \
        -pady 2 -side right 
    place $base.fra54.fra43.fra51 \
        -x 110 -y 85 -width 82 -height 34 -anchor nw 
    pack $base.fra54.fra43.fra51.01 \
        -in $base.fra54.fra43.fra51 -anchor center -expand 0 -fill none \
        -padx 2 -pady 2 -side left 
    pack $base.fra54.fra43.fra51.02 \
        -in $base.fra54.fra43.fra51 -anchor center -expand 1 -fill x -padx 2 \
        -pady 2 -side right 
    place $base.fra54.fra43.but53 \
        -x 4 -y 125 -width 138 -height 25 -anchor nw -bordermode ignore 
    place $base.fra54.fra43.but52 \
        -x 143 -y 125 -width 68 -height 25 -anchor nw -bordermode ignore 
    place $base.fra54.lab52 \
        -x 65 -y 275 -width 72 -height 24 -anchor nw -bordermode ignore 
    place $base.fra54.men43 \
        -x 130 -y -35 -width 57 -height 25 -anchor nw -bordermode ignore 
    place $base.fra54.men44 \
        -x 80 -y 30 -width 100 -height 25 -anchor nw -bordermode ignore 
    place $base.fra54.men45 \
        -x 6 -y 35 -width 70 -height 30 -anchor nw -bordermode ignore 
    place $base.fra54.fra44 \
        -x 10 -y 140 -width 205 -height 130 -anchor nw -bordermode ignore 
    place $base.fra54.fra44.sca48 \
        -x 10 -y 30 -width 188 -height 35 -anchor nw -bordermode ignore 
    place $base.fra54.fra44.sca49 \
        -x 10 -y 85 -width 188 -height 35 -anchor nw -bordermode ignore 
    place $base.fra54.fra44.lab50 \
        -x 13 -y 14 -width 80 -height 19 -anchor nw -bordermode ignore 
    place $base.fra54.fra44.lab51 \
        -x 13 -y 68 -width 80 -height 19 -anchor nw -bordermode ignore 
    place $base.fra54.lab46 \
        -x 95 -y 130 -anchor nw -bordermode ignore 
    place $base.fra54.but47 \
        -x 5 -y 70 -width 70 -height 23 -anchor nw -bordermode ignore 

    vTcl:FireEvent $base <<Ready>>
}

proc vTclWindow.top44 {base} {
    if {$base == ""} {
        set base .top44
    }
    if {[winfo exists $base]} {
        wm deiconify $base; return
    }

    global widget
    vTcl:DefineAlias "$base" "Toplevel4" vTcl:Toplevel:WidgetProc "" 1
    vTcl:DefineAlias "$base.fra45" "Frame24" vTcl:WidgetProc "Toplevel4" 1
    vTcl:DefineAlias "$base.fra45.mes46" "Message1" vTcl:WidgetProc "Toplevel4" 1
    vTcl:DefineAlias "$base.fra47" "Frame25" vTcl:WidgetProc "Toplevel4" 1
    vTcl:DefineAlias "$base.fra47.but48" "Button9" vTcl:WidgetProc "Toplevel4" 1

    ###################
    # CREATING WIDGETS
    ###################
    vTcl:toplevel $base -class Toplevel \
        -background #0880bd -highlightthickness 2 
    wm withdraw $base
    wm focusmodel $base passive
    wm geometry $base 381x308+207+220; update
    wm maxsize $base 1009 738
    wm minsize $base 1 1
    wm overrideredirect $base 0
    wm resizable $base 1 1
    wm title $base "About UniGNUPlot"
    bindtags $base "$base Toplevel all _TopLevel"
    vTcl:FireEvent $base <<Create>>
    wm protocol $base WM_DELETE_WINDOW "vTcl:FireEvent $base <<DeleteWindow>>"

    frame $base.fra45 \
        -background #d6d6cbcba5a5 -borderwidth 2 -height 225 \
        -highlightthickness 2 -relief groove -width 325 
    message $base.fra45.mes46 \
        -background #d6d6cbcba5a5 -font [vTcl:font:get_font "vTcl:font5"] \
        -foreground #000099 -highlightcolor black -highlightthickness 2 \
        -justify center -padx 5 -pady 2 \
        -text {UniGNUPlot under GPL license 
Programmed by: Cederik De Len
Linux OpenSource  Mxico
Version 2.0.0C Multilanguage
http://unicalculus.sourceforge.net
torvalds@users.sourceforge.net
November 2002} \
        -textvariable CREDITS -width 286 
    frame $base.fra47 \
        -background #d6d6cbcba5a5 -borderwidth 2 -height 40 \
        -highlightthickness 2 -relief groove -width 320 
    button $base.fra47.but48 \
        -background #0a72b4 -command {Window hide $widget(Toplevel4)} \
        -disabledforeground #a1a1a1 -font {Helvetica -12} \
        -highlightthickness 2 -text Close -textvariable CLOSE 
    ###################
    # SETTING GEOMETRY
    ###################
    place $base.fra45 \
        -x 30 -y 25 -width 325 -height 225 -anchor nw -bordermode ignore 
    place $base.fra45.mes46 \
        -x 20 -y 10 -width 286 -height 201 -anchor nw -bordermode ignore 
    place $base.fra47 \
        -x 35 -y 255 -width 320 -height 40 -anchor nw -bordermode ignore 
    place $base.fra47.but48 \
        -x 96 -y 6 -width 133 -height 30 -anchor nw -bordermode ignore 

    vTcl:FireEvent $base <<Ready>>
}

proc vTclWindow.top45 {base} {
    if {$base == ""} {
        set base .top45
    }
    if {[winfo exists $base]} {
        wm deiconify $base; return
    }

    global widget
    vTcl:DefineAlias "$base" "Toplevel3" vTcl:Toplevel:WidgetProc "" 1
    vTcl:DefineAlias "$base.fra46" "Frame23" vTcl:WidgetProc "Toplevel3" 1
    vTcl:DefineAlias "$base.fra46.ent47" "Entry12" vTcl:WidgetProc "Toplevel3" 1

    ###################
    # CREATING WIDGETS
    ###################
    vTcl:toplevel $base -class Toplevel \
        -highlightthickness 2 
    wm withdraw $base
    wm focusmodel $base passive
    wm geometry $base 273x81+228+453; update
    wm maxsize $base 1009 738
    wm minsize $base 1 1
    wm overrideredirect $base 0
    wm resizable $base 1 1
    wm title $base "Labeling"
    bindtags $base "$base Toplevel all _TopLevel"
    vTcl:FireEvent $base <<Create>>
    wm protocol $base WM_DELETE_WINDOW "vTcl:FireEvent $base <<DeleteWindow>>"

    frame $base.fra46 \
        -background #d6d6cbcba5a5 -borderwidth 2 -height 65 \
        -highlightthickness 2 -relief groove -width 260 
    entry $base.fra46.ent47 \
        -background #ffffe7e7efef -highlightthickness 2 \
        -insertbackground black -textvariable labeling_text 
    bindtags $base.fra46.ent47 "$base.fra46.ent47 Entry $base all _vTclBalloon"
    bind $base.fra46.ent47 <<SetBalloon>> {
        set ::vTcl::balloon::%W {Enter Text for label}
    }
    bind $base.fra46.ent47 <Key><Key-Return> {
        # TODO: your event handler here
# 
global ltext
global STAT
global xp
global yp
global expresion
set ltext $labeling_text
Window hide $widget(Toplevel3)
update
labeling $xp $yp $ltext
plot $expresion
    }
    ###################
    # SETTING GEOMETRY
    ###################
    place $base.fra46 \
        -x 7 -y 10 -width 260 -height 65 -anchor nw -bordermode ignore 
    place $base.fra46.ent47 \
        -x 15 -y 15 -width 220 -height 34 -anchor nw -bordermode ignore 

    vTcl:FireEvent $base <<Ready>>
}

proc vTclWindow.top46 {base} {
    if {$base == ""} {
        set base .top46
    }
    if {[winfo exists $base]} {
        wm deiconify $base; return
    }

    global widget
    vTcl:DefineAlias "$base" "Toplevel2" vTcl:Toplevel:WidgetProc "" 1
    vTcl:DefineAlias "$base.fra47" "Frame17" vTcl:WidgetProc "Toplevel2" 1
    vTcl:DefineAlias "$base.fra47.cpd48" "Frame18" vTcl:WidgetProc "Toplevel2" 1
    vTcl:DefineAlias "$base.fra47.cpd48.01" "Label12" vTcl:WidgetProc "Toplevel2" 1
    vTcl:DefineAlias "$base.fra47.cpd48.02" "Entry8" vTcl:WidgetProc "Toplevel2" 1
    vTcl:DefineAlias "$base.fra47.cpd49" "Frame19" vTcl:WidgetProc "Toplevel2" 1
    vTcl:DefineAlias "$base.fra47.cpd49.01" "Label13" vTcl:WidgetProc "Toplevel2" 1
    vTcl:DefineAlias "$base.fra47.cpd49.02" "Entry9" vTcl:WidgetProc "Toplevel2" 1
    vTcl:DefineAlias "$base.fra47.cpd50" "Frame20" vTcl:WidgetProc "Toplevel2" 1
    vTcl:DefineAlias "$base.fra47.cpd50.01" "Label14" vTcl:WidgetProc "Toplevel2" 1
    vTcl:DefineAlias "$base.fra47.cpd50.02" "Entry10" vTcl:WidgetProc "Toplevel2" 1
    vTcl:DefineAlias "$base.fra47.cpd51" "Frame21" vTcl:WidgetProc "Toplevel2" 1
    vTcl:DefineAlias "$base.fra47.cpd51.01" "Label15" vTcl:WidgetProc "Toplevel2" 1
    vTcl:DefineAlias "$base.fra47.cpd51.02" "Entry11" vTcl:WidgetProc "Toplevel2" 1
    vTcl:DefineAlias "$base.fra47.fra52" "Frame22" vTcl:WidgetProc "Toplevel2" 1
    vTcl:DefineAlias "$base.fra47.fra52.but53" "Button5" vTcl:WidgetProc "Toplevel2" 1
    vTcl:DefineAlias "$base.fra47.fra52.but54" "Button6" vTcl:WidgetProc "Toplevel2" 1
    vTcl:DefineAlias "$base.fra47.fra52.but55" "Button7" vTcl:WidgetProc "Toplevel2" 1

    ###################
    # CREATING WIDGETS
    ###################
    vTcl:toplevel $base -class Toplevel \
        -background #0880bd -highlightthickness 2 
    wm withdraw $base
    wm focusmodel $base passive
    wm geometry $base 600x234+87+308; update
    wm maxsize $base 1009 738
    wm minsize $base 1 1
    wm overrideredirect $base 0
    wm resizable $base 1 1
    wm title $base "Labels"
    bindtags $base "$base Toplevel all _TopLevel"
    vTcl:FireEvent $base <<Create>>
    wm protocol $base WM_DELETE_WINDOW "vTcl:FireEvent $base <<DeleteWindow>>"

    frame $base.fra47 \
        -background #d6d6cbcba5a5 -borderwidth 2 -height 215 \
        -highlightthickness 2 -relief groove -width 560 
    frame $base.fra47.cpd48 \
        -background #d6d6cbcba5a5 -borderwidth 1 -height 34 \
        -highlightthickness 2 -relief raised -width 528 
    label $base.fra47.cpd48.01 \
        -activebackground #d6d6cbcba5a5 -anchor w -background #d6d6cbcba5a5 \
        -disabledforeground #a1a1a1 -highlightthickness 2 -relief groove \
        -text {Main Title} 
    entry $base.fra47.cpd48.02 \
        -background #ffffe7e7efef -cursor {} -highlightthickness 0 \
        -insertbackground black -textvariable TITLE 
    frame $base.fra47.cpd49 \
        -background #d6d6cbcba5a5 -borderwidth 1 -height 34 \
        -highlightthickness 2 -relief raised -width 527 
    label $base.fra47.cpd49.01 \
        -anchor w -background #d6d6cbcba5a5 -disabledforeground #a1a1a1 \
        -highlightthickness 2 -relief groove -text {X Axis Label} 
    entry $base.fra47.cpd49.02 \
        -background #ffffe7e7efef -cursor {} -highlightthickness 0 \
        -insertbackground black -textvariable XLABEL 
    frame $base.fra47.cpd50 \
        -background #d6d6cbcba5a5 -borderwidth 1 -height 34 \
        -highlightthickness 2 -relief raised -width 527 
    label $base.fra47.cpd50.01 \
        -anchor w -background #d6d6cbcba5a5 -disabledforeground #a1a1a1 \
        -highlightthickness 2 -relief groove -text {Y Axis Label} 
    entry $base.fra47.cpd50.02 \
        -background #ffffe7e7efef -cursor {} -highlightthickness 0 \
        -insertbackground black -textvariable YLABEL 
    frame $base.fra47.cpd51 \
        -background #d6d6cbcba5a5 -borderwidth 1 -height 34 \
        -highlightthickness 2 -relief raised -width 526 
    label $base.fra47.cpd51.01 \
        -anchor w -background #d6d6cbcba5a5 -disabledforeground #a1a1a1 \
        -highlightthickness 2 -relief groove -text {Z Axis Label} 
    entry $base.fra47.cpd51.02 \
        -background #ffffe7e7efef -cursor {} -highlightthickness 0 \
        -insertbackground black -textvariable ZLABEL 
    frame $base.fra47.fra52 \
        -background #d6d6cbcba5a5 -borderwidth 2 -height 45 \
        -highlightthickness 2 -relief groove -width 525 
    button $base.fra47.fra52.but53 \
        -activeforeground #000000 -background #0a72b4 \
        -command {Window hide $widget(Toplevel2)} -disabledforeground #a1a1a1 \
        -font {Helvetica -12 italic} -foreground #0000ff \
        -highlightthickness 2 -text Close -textvariable CLOSE 
    button $base.fra47.fra52.but54 \
        -activeforeground #000099 -background #0a72b4 \
        -command {global LABEL
set LABEL ""
set TITLE ""
set XLABEL ""
set YLABEL ""
set ZLABEL ""} \
        -disabledforeground #a1a1a1 -font {Helvetica -12 italic} \
        -foreground #0000ff -highlightthickness 2 -text Reset \
        -textvariable RESET_VALUES 
    button $base.fra47.fra52.but55 \
        -activeforeground #000099 -background #0a72b4 \
        -command {global LABEL
global expresion

set LABEL ""
set LABEL "set title \"$TITLE\";
set xlabel \"$XLABEL\";
set ylabel \"$YLABEL\"; 
set zlabel \"$ZLABEL\";"

plot $expresion} \
        -disabledforeground #a1a1a1 -font {Helvetica -12 italic} \
        -foreground #0000ff -highlightthickness 2 -text Set -textvariable SET 
    ###################
    # SETTING GEOMETRY
    ###################
    place $base.fra47 \
        -x 20 -y 10 -width 560 -height 215 -anchor nw -bordermode ignore 
    place $base.fra47.cpd48 \
        -x 9 -y 9 -width 528 -height 34 -anchor nw 
    pack $base.fra47.cpd48.01 \
        -in $base.fra47.cpd48 -anchor center -expand 0 -fill none -padx 2 \
        -pady 2 -side left 
    pack $base.fra47.cpd48.02 \
        -in $base.fra47.cpd48 -anchor center -expand 1 -fill x -padx 2 \
        -pady 2 -side right 
    place $base.fra47.cpd49 \
        -x 12 -y 49 -width 527 -height 34 -anchor nw -bordermode ignore 
    pack $base.fra47.cpd49.01 \
        -in $base.fra47.cpd49 -anchor center -expand 0 -fill none -padx 2 \
        -pady 2 -side left 
    pack $base.fra47.cpd49.02 \
        -in $base.fra47.cpd49 -anchor center -expand 1 -fill x -padx 2 \
        -pady 2 -side right 
    place $base.fra47.cpd50 \
        -x 12 -y 84 -width 527 -height 34 -anchor nw -bordermode ignore 
    pack $base.fra47.cpd50.01 \
        -in $base.fra47.cpd50 -anchor center -expand 0 -fill none -padx 2 \
        -pady 2 -side left 
    pack $base.fra47.cpd50.02 \
        -in $base.fra47.cpd50 -anchor center -expand 1 -fill x -padx 2 \
        -pady 2 -side right 
    place $base.fra47.cpd51 \
        -x 12 -y 119 -width 526 -height 34 -anchor nw -bordermode ignore 
    pack $base.fra47.cpd51.01 \
        -in $base.fra47.cpd51 -anchor center -expand 0 -fill none -padx 2 \
        -pady 2 -side left 
    pack $base.fra47.cpd51.02 \
        -in $base.fra47.cpd51 -anchor center -expand 1 -fill x -padx 2 \
        -pady 2 -side right 
    place $base.fra47.fra52 \
        -x 12 -y 159 -width 525 -height 45 -anchor nw -bordermode ignore 
    place $base.fra47.fra52.but53 \
        -x 340 -y 10 -width 60 -height 25 -anchor nw -bordermode ignore 
    place $base.fra47.fra52.but54 \
        -x 416 -y 11 -width 95 -height 25 -anchor nw -bordermode ignore 
    place $base.fra47.fra52.but55 \
        -x 11 -y 10 -width 88 -height 25 -anchor nw -bordermode ignore 

    vTcl:FireEvent $base <<Ready>>
}

proc vTclWindow.top47 {base} {
    if {$base == ""} {
        set base .top47
    }
    if {[winfo exists $base]} {
        wm deiconify $base; return
    }

    global widget
    vTcl:DefineAlias "$base" "Toplevel5" vTcl:Toplevel:WidgetProc "" 1
    vTcl:DefineAlias "$base.but63" "Button11" vTcl:WidgetProc "Toplevel5" 1
    vTcl:DefineAlias "$base.fra48" "Frame27" vTcl:WidgetProc "Toplevel5" 1
    vTcl:DefineAlias "$base.fra48.fra51" "Frame28" vTcl:WidgetProc "Toplevel5" 1
    vTcl:DefineAlias "$base.fra48.fra51.but52" "Button10" vTcl:WidgetProc "Toplevel5" 1
    vTcl:DefineAlias "$base.fra48.fra51.cpd53" "Frame29" vTcl:WidgetProc "Toplevel5" 1
    vTcl:DefineAlias "$base.fra48.fra51.cpd53.01" "Label22" vTcl:WidgetProc "Toplevel5" 1
    vTcl:DefineAlias "$base.fra48.fra51.cpd53.02" "Entry13" vTcl:WidgetProc "Toplevel5" 1
    vTcl:DefineAlias "$base.fra48.fra62" "Frame30" vTcl:WidgetProc "Toplevel5" 1
    vTcl:DefineAlias "$base.fra48.fra62.but64" "Button12" vTcl:WidgetProc "Toplevel5" 1
    vTcl:DefineAlias "$base.fra48.fra62.but65" "Button13" vTcl:WidgetProc "Toplevel5" 1
    vTcl:DefineAlias "$base.fra48.lab66" "Label23" vTcl:WidgetProc "Toplevel5" 1
    vTcl:DefineAlias "$base.fra48.lis50" "Listbox1" vTcl:WidgetProc "Toplevel5" 1
    vTcl:DefineAlias "$base.lab49" "Label21" vTcl:WidgetProc "Toplevel5" 1

    ###################
    # CREATING WIDGETS
    ###################
    vTcl:toplevel $base -class Toplevel \
        -background #0880bd -highlightthickness 2 
    wm withdraw $base
    wm focusmodel $base passive
    wm geometry $base 494x448+100+167; update
    wm maxsize $base 1009 738
    wm minsize $base 1 1
    wm overrideredirect $base 0
    wm resizable $base 1 1
    wm title $base "Export to graph file"
    bindtags $base "$base Toplevel all _TopLevel"
    vTcl:FireEvent $base <<Create>>
    wm protocol $base WM_DELETE_WINDOW "vTcl:FireEvent $base <<DeleteWindow>>"

    frame $base.fra48 \
        -background #d6d6cbcbadad -borderwidth 2 -height 390 \
        -highlightthickness 2 -relief groove -width 475 
    listbox $base.fra48.lis50 \
        -background #ca3ddfbeffff -font {Helvetica -12} -foreground #000099 \
        -highlightbackground #adc0b846d7d7 -highlightthickness 2 \
        -selectbackground #adc0b846d7d7 -selectforeground #0000ff \
        -listvariable "$base\::lis50" 
    bindtags $base.fra48.lis50 "$base.fra48.lis50 Listbox $base all _vTclBalloon"
    bind $base.fra48.lis50 <<SetBalloon>> {
        set ::vTcl::balloon::%W {Double click to select module}
    }
    bind $base.fra48.lis50 <ButtonRelease-1> {
        # TODO: your event handler here
set term_hlp ""

set search [$widget(Listbox1) get active]
set term_hlp [exec grep  $search term_help]
update idletasks
    }
    bind $base.fra48.lis50 <Double-Button-1> {
        # TODO: your event handler here
# 
# 
global termtype
set termtype [$widget(Listbox1) get active]
append file_export "." $termtype
    }
    frame $base.fra48.fra51 \
        -background #d6d6cbcbadad -borderwidth 2 -height 95 \
        -highlightthickness 2 -relief groove -width 285 
    button $base.fra48.fra51.but52 \
        -background #0a72b4 \
        -command {global termtype
export $termtype $file_export} \
        -disabledforeground #a1a1a1 -font {Helvetica -12} \
        -highlightthickness 2 -text Export 
    frame $base.fra48.fra51.cpd53 \
        -background #d6d6cbcbadad -borderwidth 1 -height 39 \
        -highlightthickness 2 -relief raised -width 261 
    label $base.fra48.fra51.cpd53.01 \
        -anchor w -background #d6d6cbcbadad -disabledforeground #a1a1a1 \
        -font {Helvetica -12 italic} -highlightthickness 2 -relief groove \
        -text {File name} 
    entry $base.fra48.fra51.cpd53.02 \
        -background #ffffc957a666 -cursor {} -highlightthickness 0 \
        -insertbackground black -textvariable file_export 
    bindtags $base.fra48.fra51.cpd53.02 "$base.fra48.fra51.cpd53.02 Entry $base all _vTclBalloon"
    bind $base.fra48.fra51.cpd53.02 <<SetBalloon>> {
        set ::vTcl::balloon::%W {Enter the name of the file -just name-}
    }
    frame $base.fra48.fra62 \
        -background #d6d6cbcbadad -borderwidth 2 -height 75 \
        -highlightthickness 2 -relief groove -width 60 
    button $base.fra48.fra62.but64 \
        -background #0a72b4 \
        -command {$widget(Listbox1) yview scroll -1 pages
$widget(Listbox1) activate @0,0} \
        -disabledforeground #a1a1a1 -font {Helvetica -10 } \
        -highlightthickness 2 -text {Pg Up} 
    button $base.fra48.fra62.but65 \
        -background #0a72b4 \
        -command {$widget(Listbox1) yview scroll 1 pages
$widget(Listbox1) activate @0,0} \
        -disabledforeground #a1a1a1 -font {Helvetica -10} \
        -highlightthickness 2 -text {Pg Dn} 
    label $base.fra48.lab66 \
        -background #d6d6cbcbadad -disabledforeground #a1a1a1 \
        -font {Helvetica -10} -highlightthickness 2 \
        -text {            corel  EPS format for CorelDRAW} \
        -textvariable term_hlp 
    label $base.lab49 \
        -background #d6d6cbcbadad -disabledforeground #a1a1a1 \
        -font {Helvetica -12 } -highlightthickness 2 -text {Export module} 
    button $base.but63 \
        -background #0a72b4 -command {Window hide $widget(Toplevel5)} \
        -disabledforeground #a1a1a1 -font {Helvetica -12} \
        -highlightthickness 2 -text Close 
    ###################
    # SETTING GEOMETRY
    ###################
    place $base.fra48 \
        -x 10 -y 20 -width 475 -height 390 -anchor nw -bordermode ignore 
    place $base.fra48.lis50 \
        -x 5 -y 30 -width 155 -height 308 -anchor nw -bordermode ignore 
    place $base.fra48.fra51 \
        -x 170 -y 40 -width 285 -height 95 -anchor nw -bordermode ignore 
    place $base.fra48.fra51.but52 \
        -x 50 -y 55 -width 198 -height 30 -anchor nw -bordermode ignore 
    place $base.fra48.fra51.cpd53 \
        -x 5 -y 5 -width 261 -height 39 -anchor nw 
    pack $base.fra48.fra51.cpd53.01 \
        -in $base.fra48.fra51.cpd53 -anchor center -expand 0 -fill none \
        -padx 2 -pady 2 -side left 
    pack $base.fra48.fra51.cpd53.02 \
        -in $base.fra48.fra51.cpd53 -anchor center -expand 1 -fill x -padx 2 \
        -pady 2 -side right 
    place $base.fra48.fra62 \
        -x 160 -y 160 -width 60 -height 75 -anchor nw -bordermode ignore 
    place $base.fra48.fra62.but64 \
        -x 5 -y 5 -width 48 -height 25 -anchor nw -bordermode ignore 
    place $base.fra48.fra62.but65 \
        -x 6 -y 45 -width 48 -height 25 -anchor nw -bordermode ignore 
    place $base.fra48.lab66 \
        -x 15 -y 350 -width 447 -height 24 -anchor nw -bordermode ignore 
    place $base.lab49 \
        -x 55 -y 15 -width 172 -height 24 -anchor nw -bordermode ignore 
    place $base.but63 \
        -x 360 -y 412 -width 62 -height 30 -anchor nw -bordermode ignore 

    vTcl:FireEvent $base <<Ready>>
}

proc vTclWindow.top48 {base} {
    if {$base == ""} {
        set base .top48
    }
    if {[winfo exists $base]} {
        wm deiconify $base; return
    }

    global widget
    vTcl:DefineAlias "$base" "Toplevel6" vTcl:Toplevel:WidgetProc "" 1
    vTcl:DefineAlias "$base.but43" "Button20" vTcl:WidgetProc "Toplevel6" 1
    vTcl:DefineAlias "$base.but44" "Button21" vTcl:WidgetProc "Toplevel6" 1
    vTcl:DefineAlias "$base.but46" "Button16" vTcl:WidgetProc "Toplevel6" 1
    vTcl:DefineAlias "$base.but47" "Button17" vTcl:WidgetProc "Toplevel6" 1
    vTcl:DefineAlias "$base.but48" "Button18" vTcl:WidgetProc "Toplevel6" 1
    vTcl:DefineAlias "$base.but49" "Button19" vTcl:WidgetProc "Toplevel6" 1
    vTcl:DefineAlias "$base.but50" "Button14" vTcl:WidgetProc "Toplevel6" 1
    vTcl:DefineAlias "$base.cpd43" "Frame32" vTcl:WidgetProc "Toplevel6" 1
    vTcl:DefineAlias "$base.cpd43.01" "Label25" vTcl:WidgetProc "Toplevel6" 1
    vTcl:DefineAlias "$base.cpd43.02" "Entry14" vTcl:WidgetProc "Toplevel6" 1
    vTcl:DefineAlias "$base.cpd49" "Frame31" vTcl:WidgetProc "Toplevel6" 1
    vTcl:DefineAlias "$base.cpd49.01" "Listbox2" vTcl:WidgetProc "Toplevel6" 1
    vTcl:DefineAlias "$base.cpd49.02" "Scrollbar1" vTcl:WidgetProc "Toplevel6" 1
    vTcl:DefineAlias "$base.cpd49.03" "Scrollbar2" vTcl:WidgetProc "Toplevel6" 1
    vTcl:DefineAlias "$base.lab45" "Label26" vTcl:WidgetProc "Toplevel6" 1
    vTcl:DefineAlias "$base.lab51" "Label24" vTcl:WidgetProc "Toplevel6" 1

    ###################
    # CREATING WIDGETS
    ###################
    vTcl:toplevel $base -class Toplevel \
        -background #0880bd -highlightthickness 2 
    wm withdraw $base
    wm focusmodel $base passive
    wm geometry $base 408x387+257+175; update
    wm maxsize $base 1265 994
    wm minsize $base 1 1
    wm overrideredirect $base 0
    wm resizable $base 1 1
    wm title $base "Configuration"
    bindtags $base "$base Toplevel all _TopLevel"
    vTcl:FireEvent $base <<Create>>
    wm protocol $base WM_DELETE_WINDOW "vTcl:FireEvent $base <<DeleteWindow>>"

    frame $base.cpd49 \
        -background steelblue3 -borderwidth 1 -height 242 \
        -highlightthickness 2 -relief raised -width 149 
    listbox $base.cpd49.01 \
        -background #ffffff \
        -font -Adobe-Helvetica-Medium-R-Normal-*-*-120-*-*-*-*-*-* \
        -highlightbackground blue -highlightcolor red -highlightthickness 2 \
        -selectbackground blue -xscrollcommand "$base.cpd49.02 set" \
        -yscrollcommand "$base.cpd49.03 set" 
    bindtags $base.cpd49.01 "$base.cpd49.01 Listbox $base all _vTclBalloon"
    bind $base.cpd49.01 <<SetBalloon>> {
        set ::vTcl::balloon::%W {Dbl. Click to change}
    }
    bind $base.cpd49.01 <Double-Button-1> {
        # TODO: your event handler here
#
set LANG [$widget(Listbox2) get active]
    }
    scrollbar $base.cpd49.02 \
        -command "$base.cpd49.01 xview" -highlightthickness 2 \
        -orient horizontal 
    scrollbar $base.cpd49.03 \
        -activebackground steelblue -command "$base.cpd49.01 yview" \
        -highlightthickness 2 
    button $base.but50 \
        -activebackground steelblue3 -background #0a72b4 \
        -command {Window hide $widget(Toplevel6)
rcfile ugpconf

source .ugpcolor} \
        -disabledforeground #a1a1a1 -font {Helvetica -12 italic} \
        -highlightthickness 2 -text Ok -textvariable L_OK 
    label $base.lab51 \
        -background #d6d6cbcba5a5 -disabledforeground #a1a1a1 \
        -highlightthickness 2 -text {Select Language} \
        -textvariable L_LANGUAGE 
    frame $base.cpd43 \
        -background #0888b5 -borderwidth 1 -height 30 -highlightthickness 2 \
        -relief raised -width 30 
    label $base.cpd43.01 \
        -anchor w -background #d6d6cbcba5a5 -disabledforeground #a1a1a1 \
        -font {Helvetica -10} -highlightthickness 2 -relief groove \
        -text {Printer name} -textvariable L_PRINTER 
    entry $base.cpd43.02 \
        -background #ffffff -cursor {} -highlightthickness 0 \
        -insertbackground black -textvariable PRINTER_DEV 
    bindtags $base.cpd43.02 "$base.cpd43.02 Entry $base all _vTclBalloon"
    bind $base.cpd43.02 <<SetBalloon>> {
        set ::vTcl::balloon::%W {In the name of the printer -to print-}
    }
    label $base.lab45 \
        -background #d6d6cbcba5a5 -disabledforeground #a1a1a1 \
        -highlightthickness 2 -text {Color Scheme} -textvariable L_COLORS 
    button $base.but46 \
        -command {global CBUTTON
set CBUTTON [tk_chooseColor]} \
        -disabledforeground #a1a1a1 -font {Helvetica -10} \
        -highlightthickness 2 -text {Button Color} -textvariable C_BUTTON 
    button $base.but47 \
        -command {global CFRAME
set CFRAME [tk_chooseColor]} \
        -disabledforeground #a1a1a1 -font {Helvetica -10} -height 25 \
        -highlightthickness 2 -text {Frame Color} -textvariable C_FRAME \
        -width 78 
    button $base.but48 \
        -command {global CENTRY
set CENTRY [tk_chooseColor]} \
        -disabledforeground #a1a1a1 -font {Helvetica -10} -height 25 \
        -highlightthickness 2 -text {Entry Color} -textvariable C_ENTRY \
        -width 78 
    button $base.but49 \
        -command {global CCANVAS
set CCANVAS [tk_chooseColor]} \
        -disabledforeground #a1a1a1 -font {Helvetica -10} -height 25 \
        -highlightthickness 2 -text {Canvas Color} -textvariable C_CANVAS \
        -width 78 
    button $base.but43 \
        -command {global CTOPLEVEL
set CTOPLEVEL [tk_chooseColor]} \
        -disabledforeground #a1a1a1 -font {Helvetica -10} -height 25 \
        -highlightthickness 2 -text {Main Windows Color} \
        -textvariable C_TOPLEVEL -width 108 
    button $base.but44 \
        -command {global CSCALE
set CSCALE [tk_chooseColor]} \
        -disabledforeground #a1a1a1 -font {Helvetica -10} -height 25 \
        -highlightthickness 2 -text {Scale Color} -textvariable C_SCALE \
        -width 78 
    ###################
    # SETTING GEOMETRY
    ###################
    place $base.cpd49 \
        -x 7 -y 47 -width 149 -height 242 -anchor nw 
    grid columnconf $base.cpd49 0 -weight 1
    grid rowconf $base.cpd49 0 -weight 1
    grid $base.cpd49.01 \
        -in $base.cpd49 -column 0 -row 0 -columnspan 1 -rowspan 1 \
        -sticky nesw 
    grid $base.cpd49.02 \
        -in $base.cpd49 -column 0 -row 1 -columnspan 1 -rowspan 1 -sticky ew 
    grid $base.cpd49.03 \
        -in $base.cpd49 -column 1 -row 0 -columnspan 1 -rowspan 1 -sticky ns 
    place $base.but50 \
        -x 15 -y 330 -width 118 -height 30 -anchor nw -bordermode ignore 
    place $base.lab51 \
        -x 15 -y 25 -width 132 -height 24 -anchor nw -bordermode ignore 
    place $base.cpd43 \
        -x 175 -y 25 -anchor nw 
    pack $base.cpd43.01 \
        -in $base.cpd43 -anchor center -expand 0 -fill none -padx 2 -pady 2 \
        -side left 
    pack $base.cpd43.02 \
        -in $base.cpd43 -anchor center -expand 1 -fill x -padx 2 -pady 2 \
        -side right 
    place $base.lab45 \
        -x 250 -y 70 -anchor nw -bordermode ignore 
    place $base.but46 \
        -x 170 -y 110 -width 78 -height 25 -anchor nw -bordermode ignore 
    place $base.but47 \
        -x 170 -y 135 -width 78 -height 25 -anchor nw -bordermode ignore 
    place $base.but48 \
        -x 255 -y 110 -width 78 -height 25 -anchor nw -bordermode ignore 
    place $base.but49 \
        -x 255 -y 135 -width 78 -height 25 -anchor nw -bordermode ignore 
    place $base.but43 \
        -x 255 -y 159 -width 108 -height 25 -anchor nw -bordermode ignore 
    place $base.but44 \
        -x 170 -y 160 -width 78 -height 25 -anchor nw -bordermode ignore 

    vTcl:FireEvent $base <<Ready>>
}

proc vTclWindow.top49 {base} {
    if {$base == ""} {
        set base .top49
    }
    if {[winfo exists $base]} {
        wm deiconify $base; return
    }

    global widget
    vTcl:DefineAlias "$base" "Toplevel7" vTcl:Toplevel:WidgetProc "" 1
    vTcl:DefineAlias "$base.but51" "Button23" vTcl:WidgetProc "Toplevel7" 1
    vTcl:DefineAlias "$base.che50" "Checkbutton1" vTcl:WidgetProc "Toplevel7" 1
    vTcl:DefineAlias "$base.lab55" "Label27" vTcl:WidgetProc "Toplevel7" 1
    vTcl:DefineAlias "$base.mes56" "Message2" vTcl:WidgetProc "Toplevel7" 1
    vTcl:DefineAlias "$base.sca54" "Scale5" vTcl:WidgetProc "Toplevel7" 1

    ###################
    # CREATING WIDGETS
    ###################
    vTcl:toplevel $base -class Toplevel
    wm withdraw $base
    wm focusmodel $base passive
    wm geometry $base 445x243+262+324; update
    wm maxsize $base 1265 994
    wm minsize $base 1 1
    wm overrideredirect $base 0
    wm resizable $base 1 1
    wm title $base "Contour params"
    bindtags $base "$base Toplevel all _TopLevel"
    vTcl:FireEvent $base <<Create>>
    wm protocol $base WM_DELETE_WINDOW "vTcl:FireEvent $base <<DeleteWindow>>"

    checkbutton $base.che50 \
        -disabledforeground #a1a1a1 -font {Helvetica -12} -text check \
        -textvariable L_SET_CONTOUR -variable S_CONTOUR 
    button $base.but51 \
        \
        -command {Window hide $widget(Toplevel7)
if {$S_CONTOUR == 1} {
set UCONTOUR "set contour;"
set CNTRPARAM "set cntrparam levels $CONTOUR_SCALE;"
} else {
set UCONTOUR "set nocontour;"
set CNTRPARAM "set cntrparam;"
}} \
        -disabledforeground #a1a1a1 -font {Helvetica -12 italic} -text Ok \
        -textvariable L_OK 
    scale $base.sca54 \
        -bigincrement 0.0 -from 0.0 -orient horizontal -resolution 1.0 \
        -tickinterval 0.0 -to 1000.0 -variable CONTOUR_SCALE 
    label $base.lab55 \
        -disabledforeground #a1a1a1 -font {Helvetica -12} -text label \
        -textvariable L_CONTOUR_LEVELS 
    message $base.mes56 \
        -highlightcolor black -padx 5 -pady 2 \
        -text {Functions not well tested and many options are not set yet...} \
        -width 382 
    ###################
    # SETTING GEOMETRY
    ###################
    place $base.che50 \
        -x 10 -y 15 -width 125 -height 22 -anchor nw -bordermode ignore 
    place $base.but51 \
        -x 340 -y 205 -width 100 -height 28 -anchor nw -bordermode ignore 
    place $base.sca54 \
        -x 45 -y 70 -width 381 -height 43 -anchor nw -bordermode ignore 
    place $base.lab55 \
        -x 130 -y 50 -width 228 -height 20 -anchor nw -bordermode ignore 
    place $base.mes56 \
        -x 50 -y 135 -width 382 -height 47 -anchor nw -bordermode ignore 

    vTcl:FireEvent $base <<Ready>>
}

#############################################################################
## Binding tag:  _TopLevel

bind "_TopLevel" <<Create>> {
    if {![info exists _topcount]} {set _topcount 0}; incr _topcount
}
bind "_TopLevel" <<DeleteWindow>> {
    destroy %W; if {$_topcount == 0} {exit}
}
bind "_TopLevel" <Destroy> {
    if {[winfo toplevel %W] == "%W"} {incr _topcount -1}
}
#############################################################################
## Binding tag:  _vTclBalloon


if {![info exists vTcl(sourcing)]} {
bind "_vTclBalloon" <<KillBalloon>> {
    namespace eval ::vTcl::balloon {
        after cancel $id
        if {[winfo exists .vTcl.balloon]} {
            destroy .vTcl.balloon
        }
        set set 0
    }
}
bind "_vTclBalloon" <<vTclBalloon>> {
    if {$::vTcl::balloon::first != 1} {break}

    namespace eval ::vTcl::balloon {
        set first 2
        if {![winfo exists .vTcl]} {
            toplevel .vTcl; wm withdraw .vTcl
        }
        if {![winfo exists .vTcl.balloon]} {
            toplevel .vTcl.balloon -bg black
        }
        wm overrideredirect .vTcl.balloon 1
        label .vTcl.balloon.l  -text ${%W} -relief flat  -bg #ffffaa -fg black -padx 2 -pady 0 -anchor w
        pack .vTcl.balloon.l -side left -padx 1 -pady 1
        wm geometry  .vTcl.balloon  +[expr {[winfo rootx %W]+[winfo width %W]/2}]+[expr {[winfo rooty %W]+[winfo height %W]+4}]
        set set 1
    }
}
bind "_vTclBalloon" <Button> {
    namespace eval ::vTcl::balloon {
        set first 0
    }
    vTcl:FireEvent %W <<KillBalloon>>
}
bind "_vTclBalloon" <Enter> {
    namespace eval ::vTcl::balloon {
        ## self defining balloon?
        if {![info exists %W]} {
            vTcl:FireEvent %W <<SetBalloon>>
        }
        set set 0
        set first 1
        set id [after 500 {vTcl:FireEvent %W <<vTclBalloon>>}]
    }
}
bind "_vTclBalloon" <Leave> {
    namespace eval ::vTcl::balloon {
        set first 0
    }
    vTcl:FireEvent %W <<KillBalloon>>
}
bind "_vTclBalloon" <Motion> {
    namespace eval ::vTcl::balloon {
        if {!$set} {
            after cancel $id
            set id [after 500 {vTcl:FireEvent %W <<vTclBalloon>>}]
        }
    }
}
}

Window show .
Window show .top43
Window show .top44
Window show .top45
Window show .top46
Window show .top47
Window show .top48
Window show .top49

main $argc $argv
